if (!Object.keys) {
	Object.keys = (function() {
		var hasOwnProperty = Object.prototype.hasOwnProperty,
			hasDontEnumBug = !({
				toString: null
			}).propertyIsEnumerable('toString'),
			dontEnums = ['toString', 'toLocaleString', 'valueOf', 'hasOwnProperty', 'isPrototypeOf', 'propertyIsEnumerable', 'constructor'];

		return function(obj) {
			if (typeof obj !== 'object' && typeof obj !== 'function' || obj === null) throw new TypeError('Object.keys called on non-object');

			var result = [];

			for (var prop in obj) {
				if (hasOwnProperty.call(obj, prop)) result.push(prop);
			}

			if (hasDontEnumBug) {
				for (var i = 0; i < dontEnums.length; i++) {
					if (hasOwnProperty.call(obj, dontEnums[i])) result.push(dontEnums[i]);
				}
			}

			return result;
		};
	})();
}

// Taken from underscore.js
if (!Array.range) {
	Array.range = function(start, stop, step) {
		if (arguments.length <= 1) {
			stop = start || 0;
			start = 0;
		}
		step = arguments[2] || 1;
		
		var range = new Array(Math.max(Math.ceil(Math.abs(stop - start) / step), 0));
		
		for(var i = 0; i < range.length; i++) {
			range[i] = start;
			start += step;
		}
		
		return range;
	};
}

// fix for IE missing window.location.origin
if (!window.location.origin) {
  window.location.origin = window.location.protocol + "//" + window.location.hostname + (window.location.port ? ':' + window.location.port: '');
}

//	this file is the entry point for the application. 
//	The Gruntfile loads start.js, then all js files in src/javascript/, then end.js

// 'app' is the top level - all views, models, routers, etc are contained in 'app'.
var app = app || { view: {}, collection: {}, model: {}, router: {}, event: {}, config: {}, graphs: {}, utils: {}};

// load the config.js file
/**
 * Intercept clicks of Download buttons so we can see if they have agreed to the User Agreement
 * @param event
 */
app.utils.interceptDownload = function(event) {
    console.log('download intercepted');
    console.log(event);
    // if the project has not added a User Agreement, then we won't prompt them, so this function exits here
    if (!app.config.userAgreement) {
        return this;
    }

    // a User Agreement exists, so prevent the file from automatically downloading until we have them ack the form
    event.preventDefault();

    // if they haven't accepted the User Agreement, there won't be a cookie
    if (!Cookies.get(app.config.title + '_agreement')) {
        // the template ID is the script ID set in main.scala.html for the user_agreement.scala.html form
        var template = $("#user-agreement-template").html();

        // the user-agreement ID is set in the bottom of index.scala.html. It is the hidden modal that we will
        // activate when we want to prompt for the agreement
        // we will pass in the original URL that the user wanted to download
        $("#user-agreement").html(_.template(template, {url: event.currentTarget.href}));

        // the user-agreement-modal ID is found in user_agreement.scala.html.
        // We must call .modal to register the modal, and we are calling show at the same time
        $("#user-agreement-modal").modal('show');

    } else {
        // if the user has already agreed to the user agreement, then we will trigger a click
        // of the link to start the download. We don't use the original element, since that
        // has the class of 'download' on it and it would recursively call interceptDownload since
        // the event bus is setup to listen for clicks of 'a.download' links.
        // We set the target attribute to open in a new window, and the download attribute
        // so it will suppress the new tab and just directly download the file.
        // (the download 'attribute' is not the same as the download 'class')
        var passThroughLink = document.createElement('a');
        passThroughLink.href = event.currentTarget.href;
        passThroughLink.target = "_blank";
        passThroughLink.download = true;
        passThroughLink.click();
    }
};

app.utils.setCookie = function() {
    // this gets called by an 'onclick' attribute in user_agreement.scala.html
    Cookies.set(app.config.title + '_agreement', Date.now());
    app.utils.closeModals();
};

app.utils.closeModals = function() {
    // this is called by app.utils.setCookie
    $(".modal").modal('hide');
};
// customize this file to suit your branch
app.config = {
    features: {
        boxWhiskerRaw: true
    },
    landingPage:"welcome",
    // clowderDevUrl: "",
    alert: false,
    disclaimer_head:"VBD Disclaimer",
    disclaimer_text: "<p class='about_text03' style='width:100%;'> <b> Vector Borne Disease<sup>SM</sup> application</b> is an interactive geospatially referenced database that aggregates water quality data from several sources. Currently, GLTG<sup>SM</sup> includes sites with five or more years of discreet nutrient data in the main stem of the Mississippi River, continuous water quality monitoring sites in the Mississippi River watershed with nutrient data, and selected small watersheds (HUC-8 or smaller). GLTG will display additional parameters as they are available.</p><br/>     <p class='about_text03' style='width:100%; font-style:italic;'><b>Great Lakes to Gulf</b> includes as many sites as possible that fit the above criteria from data sources considered reputable. However, data on Great Lakes to Gulf should not be considered comprehensive, and data sources and sites may be added or removed from the application. While efforts have been made to ensure site data is identical to the primary source data from which it is pulled, users should utilize original source data for work with legal implications. </p><br/>     <p class='about_text03' style='width:100%;'><b>Data housing and display:</b> Currently Great Lakes to Gulf displays only data retrieved from primary sources without transforming the data or performing calculations. Two exceptions to this rule are (1) the calculated loads where discharge and concentration are measured at the same location, and (2) in long data ranges with many points, data are displayed as an average for a specified time period. Where these exceptions occur, they are noted. </p><br/>      <p class='about_text03' style='width:100%;'><b>Data quality:</b> Great Lakes to Gulf is wholly reliant on the quality of the primary source data that is queried by the application. All quality assurance and quality control schemes are the responsibility of the data owner. To learn more about each data source’s quality control information, click the “i” button next to the source and follow the links to the primary source metadata. Questions regarding data should be directed to the original source.</p><br/>         <p class='about_text03' style='width:100%;'><b>Update frequency:</b> For each data source displayed on Great Lakes to  Gulf, the data are provided in one of several ways, with a corresponding update schedule.</p>         <p class='about_text03' style='width:100%;'><i>Web Service Data - </i> For sites with a web service for data retrieval (API) GLTG queries that web service every 15 minutes for updates. Updates to data displayed on GLTG occur only as frequently as provided by the web service.</p>         <p class='about_text03' style='width:100%;'><i>Manual Input - </i>For data that is uploaded to GLTG manually (through spreadsheets or other files that must be manually retrieved), GLTG staff request updated datasets no less frequently then every six months. Updates to data occur only as frequently as provided by the data owner.</p></br>     <p class='about_text03' style='width:100%;'><b>Questions:</b> If you have questions or comments, or if there are additional datasets that you believe are relevant to GLTG and are not displayed, please send an email to Marcus Slavenas <a href='slavenas@illinois.edu'>gltg@lc.edu</a>   </p>",
    title: "Vector Borne Disease",
    // googleAnalytics: "UA-8681001-7",
    metadata: {
        title: "Vector Borne Disease",
        keywords: "mosquito, west nile, vector borne",
        description: "Vector Borne Disease",
        url: "#"
    },
    binning: {
        time: "smart",
        depth: 1
    },
    areas: {
        title: "Areas",
        noneFound: "No areas have been specified.",
        shapeOptions: {
          color: '#20201F'
        },
        zoomInOnClick: true,
        items: [
            // override this array in ./config/areas.js
        ]
    },
    layers: {
        title: "Layers",
        noneFound: "No layers have been specified.",
        items: [
            // override this array in ./config/layers.js
        ]
    },
    basins: {
        title: "Basins",
        noneFound: "No basins have been specified.",
        items: [
            // override this array in ./config/basins.js
        ]
    },
    parameters: {
        title: "Parameters",
        noneFound: "No parameters have been specified.",
        defaults: {
            detailView: 'ignore',
            searchView: 'ignore',
            exploreView: 'ignore'
        },
        items: [
            // override this array in ./config/parameters.js
        ]
    },
    sources: {
        title: "Data Sources",
        noneFound: "No data sources have been specified.",
        items: [
            // override this array in ./config/sources.js
        ]
    },
    sensors: {
        title: "Sensors",
        noneFound: "No sensors have been specified.",
        items: [
            // override this array in ./config/sensors.js
        ]
    },
    graphs: {
        timeSeries: {
            showUnits: {
                sideBar: false,
                graphTitle: true,
                graphXAxis: true,
                graphYAxis: true,
                graphTooltip: true
            },
            showSource: true,
            showLine: false
        },
        depthProfile: {
            showUnits: {
                sideBar: false,
                graphXAxis: true,
                graphYAxis: true

            }
        }
    },
    search_link: {
        url: "#search",
        // url: "http://gltg-dev.ncsa.illinois.edu/#search",
        title: "Download"
    }
};
// load the env file from /src/javascript/envs/{env}.js

// @formatter:off
app.config.areas.groups = [
    {
        title: "Climate Divisions",
        items: [
            { "type": "Feature", "properties": { "id": "01", "title": "Northwest Illinois" }, "geometry": { "type": "Polygon", "coordinates": [[[-90.63377380348665,42.510402679194954],[-89.84799194290873,42.510925293468205],[-88.93792724612902,42.50559997559698],[-88.93810272199447,42.155017852973145],[-88.94409179683274,41.89202499431758],[-88.92308807397563,41.714027404827355],[-88.91509246831195,41.628028869144],[-89.16110229461805,41.628028869144],[-89.16208648678337,41.58602905228661],[-89.16709136945632,41.30703353901847],[-89.16109466576121,41.107028961258436],[-89.33909606967985,41.1030311584266],[-89.33410644582587,41.14702987725257],[-89.46409606926774,41.14803314155996],[-89.6371078493324,41.149028778115834],[-89.63809967035453,41.240036010900546],[-89.85511779810199,41.240036010900546],[-89.85610961912413,41.15003204352853],[-89.98712921118822,41.149032592544245],[-90.43813324021362,41.15102767897909],[-90.43914032005473,41.06503295882946],[-90.79414367690772,41.064029693416764],[-90.96737670929471,41.07022094733],[-91.07075500441005,41.31859970058293],[-91.07294464106303,41.364871979013536],[-91.06800842252277,41.37660598758662],[-91.05932617221627,41.39723586993173],[-91.0217895505112,41.4265136716223],[-90.95459747328044,41.4481201172759],[-90.59348297103747,41.48495864884227],[-90.5089950562211,41.503936767626605],[-90.45085906980886,41.53019714311694],[-90.39089202843665,41.578983306721916],[-90.34310913134969,41.638698578133834],[-90.18782043469639,41.92552948001916],[-90.16012573243391,42.06448364247105],[-90.17715454124028,42.12174987841288],[-90.30837249795093,42.25569915819182],[-90.47535705557725,42.38673019354115],[-90.63377380348665,42.510402679194954]]]}},
            { "type": "Feature", "properties": { "id": "02", "title": "Northeast Illinois" }, "geometry": { "type": "Polygon", "coordinates": [[[-88.93792724593281,42.50559997572234],[-88.7782287597862,42.504009246620654],[-87.79486846890205,42.48988342303662],[-87.5289230347061,41.724990844638214],[-87.53105163551344,41.28898239139207],[-88.02205657973244,41.28402710002169],[-88.02306366006324,41.199028014729045],[-88.24507141133006,41.199028014729045],[-88.24707031269025,41.10902404806344],[-88.58907318109573,41.10302734398289],[-88.92707824678084,41.1010284426227],[-88.92808532711165,40.92402648930427],[-89.04309082050057,40.92402648930427],[-89.04808807348147,41.10103225723828],[-89.1610946655102,41.10702896131884],[-89.16709136959076,41.30703353916129],[-89.16208648653958,41.586029052690854],[-89.16110229474137,41.62802886978735],[-88.91509246785088,41.62802886978735],[-88.92308807413075,41.714027404501415],[-88.94409179645545,41.89202499430392],[-88.93810272244518,42.15501785310525],[-88.93792724593281,42.50559997572234]]]}},
            { "type": "Feature", "properties": { "id": "03", "title": "East Illinois" }, "geometry": { "type": "Polygon", "coordinates": [[[-88.9280853272515,40.924026489131855],[-88.92707824688958,41.10102844234291],[-88.58907318145131,41.1030273436568],[-88.24707031261745,41.109024047598446],[-88.24507141130357,41.199028015425775],[-88.02306365971027,41.199028015425775],[-88.02205657934836,41.28402709949562],[-87.53105163587557,41.28898239132253],[-87.53498077422985,40.471023559737745],[-87.53784942659088,39.862876891975496],[-87.63002777126827,39.875034331989234],[-87.94403076153002,39.876033782646175],[-88.47106933581968,39.87602996817759],[-88.47607421880934,39.79002380374584],[-88.75107574433547,39.79002761821442],[-88.7400817871091,40.05202865626313],[-88.73908996615714,40.09302902231264],[-88.6880722044233,40.08803176902793],[-88.68207550048166,40.11102676384256],[-88.6880722044233,40.139034271351825],[-88.57907104517692,40.27702713012229],[-88.46406555151611,40.27702713012229],[-88.45806884757447,40.38702774079342],[-88.46307373056415,40.60203170808316],[-88.57806396481502,40.6030311587401],[-88.57907104517692,40.64702987676044],[-88.58906555174634,40.7450294498433],[-88.9330825805362,40.747028351157184],[-88.9280853272515,40.924026489131855]]]}},
            { "type": "Feature", "properties": { "id": "04", "title": "Central Illinois" }, "geometry": { "type": "Polygon", "coordinates": [[[-89.98712921137604,41.14903259308032],[-89.85610961908125,41.15003204379754],[-89.85511779812344,41.240036010813895],[-89.63809967046575,41.240036010813895],[-89.63710784950794,41.14902877771322],[-89.46409606952093,41.14803314236311],[-89.33410644503138,41.14702987627879],[-89.33909606885804,41.10303115836753],[-89.16109466504436,41.10702896123639],[-89.04808807396286,41.1010322569331],[-89.04309082037679,40.92402648944433],[-88.92808532688605,40.92402648944433],[-88.93308258047212,40.747028350740166],[-88.58906555169192,40.74502944930573],[-88.57907104451978,40.64702987655166],[-88.57806396501795,40.6030311586404],[-88.46307373007123,40.60203170792318],[-88.45806884770055,40.387027740243944],[-88.46406555200383,40.27702713009869],[-88.57907104451978,40.27702713009869],[-88.68807220492262,40.139034271086814],[-88.68207550061933,40.111026763676186],[-88.68807220492262,40.088031768395645],[-88.7390899661578,40.093029021981714],[-88.74008178711561,40.0520286562221],[-88.75107574500497,39.790027618479954],[-88.76807403598222,39.732028960768275],[-88.81307983437011,39.732028960768275],[-88.81408691387193,39.64603424077249],[-89.02607727085551,39.65203094507577],[-89.14109039313085,39.65203475946808],[-89.14109039313085,39.77603149404664],[-89.18109893793267,39.79504013061004],[-89.22008514371385,39.825035095303384],[-89.22009277347325,39.91503524792744],[-89.40409851037482,39.917045593513585],[-89.49010467549714,39.93504714960035],[-89.48410797119384,39.98004531822883],[-89.58210754394791,39.98104095455374],[-89.68911743170094,39.97404861490034],[-89.69612121550605,39.917049407905886],[-89.7521209717833,39.917049407905886],[-89.98812103233385,39.90003967277692],[-89.98812103233385,40.123039245219076],[-90.02211761428836,40.10104370163055],[-90.16912841805858,40.06104660000565],[-90.19212341333912,40.06604003919942],[-90.22212219242478,40.05104064965659],[-90.26112365674996,40.061042785613346],[-90.28613281298375,40.05104064965659],[-90.30212402348438,40.084045409678495],[-90.32412719683231,40.112045288304515],[-90.36112976069788,40.11804199260781],[-90.3371276859155,40.13603973430227],[-90.29713439965772,40.14704132097624],[-90.22312927290139,40.14704132097624],[-90.19813537618643,40.18704223601865],[-90.18212890616698,40.204036712603596],[-90.13212585419302,40.22103500358085],[-90.10212707510738,40.266040801968735],[-90.078125000325,40.282039642228774],[-90.0511245724162,40.34703445398615],[-90.02112579333055,40.375041961396775],[-89.96312713659368,40.410034179676195],[-89.9181289669904,40.426033019936234],[-89.8851242069685,40.45903778093294],[-89.86911773694905,40.50603485099584],[-89.86812591599124,40.6160354611411],[-89.99312591567933,40.6160354611411],[-89.98812103233385,40.71303558317796],[-89.98612213089942,40.97903060939666],[-89.98712921137604,41.14903259308032]]]}},
            { "type": "Feature", "properties": { "id": "05", "title": "Wast Illinois" }, "geometry": { "type": "Polygon", "coordinates": [[[-89.98712921115394,41.14903259252488],[-89.98612213146212,40.97903060908295],[-89.98812103243057,40.71303558366898],[-89.99312591567856,40.616035461195494],[-89.86812591556415,40.616035461195494],[-89.86911773684078,40.50603485079058],[-89.8851242062421,40.459037780693606],[-89.91812896713103,40.42603301980468],[-89.96312713625954,40.410034179610946],[-90.0211257933195,40.375041961969785],[-90.05112457273852,40.347034454311625],[-90.07812499989522,40.28203964224283],[-90.10212707559926,40.2660408020491],[-90.13212585420864,40.22103500371298],[-90.18212890658516,40.204036713035016],[-90.19813537598648,40.18704223655604],[-90.22312927215751,40.147041320658275],[-90.29713439942843,40.147041320658275],[-90.33712768530896,40.1360397336953],[-90.36112976101299,40.118041992533115],[-90.38912963865393,40.09004211408255],[-90.41113281257988,40.07204437292037],[-90.44613647443725,40.02104568506824],[-90.49213409405,39.99703979516523],[-90.51013946522941,39.98503875771803],[-90.52513885493892,39.9640426634839],[-90.54213714561688,39.928039551142305],[-90.57013702406745,39.8960418699452],[-90.58414459250032,39.83103942866881],[-90.90914154046709,39.8360443119168],[-90.91613006626834,39.75704193141513],[-91.38449859639955,39.76438140886218],[-91.39706420897271,39.785896301357404],[-91.42842864974658,39.90459060634801],[-91.44874572750226,40.371952056787414],[-91.08747863764131,40.7513961794517],[-91.01272583021394,40.85075378455667],[-90.96286010762233,40.945438384635644],[-90.9528427127284,40.99618911716861],[-90.9637451175637,41.06145095798038],[-90.96737670862997,41.070220947070936],[-90.79414367683141,41.06402969329961],[-90.4391403194284,41.06503295879245],[-90.43813323973659,41.15102767929435],[-89.98712921115394,41.14903259252488]]]}},
            { "type": "Feature", "properties": { "id": "06", "title": "West Southwest Illinois" }, "geometry": { "type": "Polygon", "coordinates": [[[-90.36112976067609,40.11804199196644],[-90.32412719776003,40.11204528849423],[-90.30212402295204,40.08404541021403],[-90.28613281288744,40.051040649210094],[-90.26112365691581,40.06104278583405],[-90.22212219243967,40.051040649210094],[-90.19212341259939,40.06604003852621],[-90.16912841825096,40.06104660084983],[-90.02211761495067,40.101043701090234],[-89.98812103319825,40.12303924586666],[-89.98812103319825,39.900039672821194],[-89.75212097118872,39.9170494075367],[-89.69612121583637,39.9170494075367],[-89.68911743155255,39.97404861487715],[-89.58210754350844,39.98104095411362],[-89.48410797133981,39.98004531834936],[-89.49010467481202,39.935047149192954],[-89.40409851079586,39.91704559372897],[-89.22009277340302,39.91503524832958],[-89.22008514457951,39.825035095000985],[-89.1810989377504,39.79504013017648],[-89.14109039246264,39.77603149390089],[-89.14109039246264,39.65203476002793],[-89.02607727056272,39.65203094501214],[-89.03208923289002,39.349040985293605],[-89.14009857171416,39.34804153451356],[-89.14108276363912,39.217037201341],[-89.26009368865923,39.216041564368695],[-89.27908325227199,39.010040283407484],[-89.27809143031547,38.731044768817405],[-89.59209442127731,38.73603820770184],[-89.60009765634116,38.6500396725092],[-89.70709228553018,38.6500396725092],[-90.20026397735903,38.65000534099129],[-90.16566467264275,38.71340942345942],[-90.12783813517612,38.80181121805988],[-90.31784820607274,38.92670822196689],[-90.41372680704863,38.96245193477447],[-90.46897125209428,38.949886322576354],[-90.59414672799255,38.878677367744395],[-90.6246414188111,38.87874221818053],[-90.64847564656516,38.90628433201616],[-90.66914367698924,38.94951248123074],[-90.72739410440659,39.19537353515267],[-90.74961853080127,39.24985504106811],[-90.78117370661217,39.29756927434955],[-90.83797454883647,39.352203368815864],[-90.90633392365534,39.40197372406196],[-91.23447418164099,39.59567642218505],[-91.33907318145376,39.686477661177555],[-91.3844985961365,39.76438140817581],[-90.91613006633963,39.75704193149616],[-90.90914154091091,39.8360443112285],[-90.58414459257665,39.83103942850476],[-90.570137024009,39.89604186970102],[-90.5421371457288,39.9280395511014],[-90.5251388548526,39.964042663237414],[-90.51013946553647,39.98503875723379],[-90.49213409384866,39.99703979541783],[-90.44613647512026,40.02104568438559],[-90.41113281255623,40.07204437202999],[-90.38912963895629,40.09004211368624],[-90.36112976067609,40.11804199196644]]]}},
            { "type": "Feature", "properties": { "id": "07", "title": "East Southeast Illinois" }, "geometry": { "type": "Polygon", "coordinates": [[[-88.75107574478912,39.790027618816566],[-88.47607421850898,39.79002380386776],[-88.47106933594804,39.87602996860473],[-87.9440307621332,39.876033782643695],[-87.63002777138291,39.87503433247497],[-87.53784942617706,39.86287689220075],[-87.53836822555053,39.75215911862494],[-87.64853668198211,39.34788131747468],[-87.66300964332817,39.26176834144987],[-87.6662368771151,39.242500305169735],[-87.67047119096836,39.1465187071206],[-87.64216613782294,39.05013656583224],[-87.51727294889142,38.842140198048206],[-87.50284576420151,38.79270935047291],[-87.50573730432971,38.745052337632664],[-87.53958129920477,38.67705917381425],[-87.59291839596239,38.61218643158509],[-87.65206146266922,38.56102371189191],[-87.9560394285024,38.561046600674906],[-88.16104888880697,38.5610427857261],[-88.16304779096411,38.59004592901094],[-88.255050659443,38.59004592901094],[-88.70606231678184,38.590042114062136],[-88.7070541379628,38.46704101599992],[-89.14707946788417,38.46704483003889],[-89.14707183798656,38.49404525712762],[-89.14707183798656,38.73004150398879],[-89.27809143073081,38.731044769106326],[-89.27908325191177,39.01004028293226],[-89.26009368869764,39.216041565327636],[-89.14108276323242,39.21703720054756],[-89.14009857194907,39.348041534406434],[-89.03208923369654,39.349040985485004],[-89.02607727015942,39.65203094508602],[-88.81408691391974,39.646034240434275],[-88.8130798338534,39.73202896123467],[-88.76807403574372,39.73202896123467],[-88.75107574478912,39.790027618816566]]]}},
            { "type": "Feature", "properties": { "id": "08", "title": "Southwest Illinois" }, "geometry": { "type": "Polygon", "coordinates": [[[-90.20026397732298,38.65000534031749],[-89.70709228554723,38.65003967258246],[-89.60009765591093,38.65003967258246],[-89.59209442105659,38.736038207968214],[-89.27809143067121,38.73104476892384],[-89.14707183846174,38.73004150423457],[-89.14707183846174,38.4940452578882],[-89.14707946746681,38.46704483002786],[-89.14707946746681,38.207042694492074],[-89.14707946746681,38.12304306035087],[-89.13508605999952,38.10404586821596],[-89.12408447284281,38.084049225023236],[-89.12908935539478,38.06504440301218],[-89.14208984379604,38.03504562372056],[-89.17609405545292,37.95704269418409],[-89.1540908811395,37.86004257164162],[-89.1540908811395,37.60804367096018],[-89.05007934579542,37.60104751616871],[-88.71206664997592,37.60104751616871],[-88.71306610103375,37.344047546566735],[-88.92121887177669,37.3431472778013],[-88.94808197057714,37.30404663117622],[-88.98607635484694,37.316047668519666],[-89.00608062704474,37.32505035443183],[-89.05108642585832,37.31404495277258],[-89.04880523661784,37.19867324786978],[-89.06605529774168,37.18797302209275],[-89.20089721661284,37.03544616703178],[-89.39206695534666,37.06587600688682],[-89.4098968504725,37.24501800501728],[-89.43573760945776,37.503242492650664],[-89.47026062046284,37.61276626551622],[-89.52189636266078,37.69517898559255],[-89.59221649210635,37.76044845584248],[-89.69206237813898,37.823703765966634],[-90.08300018334417,38.00140762347079],[-90.19960021990981,38.062587737944305],[-90.29122924762211,38.13090896614532],[-90.34384918199666,38.203002929861846],[-90.35728454546387,38.28594589192289],[-90.33438873313226,38.38632202168242],[-90.30602264367809,38.44949340839541],[-90.29033660873284,38.484363555681654],[-90.20026397732298,38.65000534031749]]]}},
            { "type": "Feature", "properties": { "id": "09", "title": "Southeast Illinois" }, "geometry": { "type": "Polygon", "coordinates": [[[-89.1470794678026,38.46704483058873],[-88.70705413805976,38.4670410155199],[-88.70606231704346,38.59004211463203],[-88.2550506594323,38.590045928919565],[-88.16304779074294,38.590045928919565],[-88.16104888921627,38.56104278573593],[-87.95603942904808,38.56104660002347],[-87.65206146266334,38.56102371195435],[-87.89009857142514,38.35407638511048],[-87.94484710699508,38.29516983000338],[-87.9871902465983,38.233482360825526],[-88.01377105702332,38.167694091892656],[-88.02709960901768,38.098033904677266],[-88.0367507932703,37.80665206894988],[-88.04514312747095,37.56899642956933],[-88.0585632325231,37.51939392104662],[-88.08527374278776,37.47889327999247],[-88.11456298800734,37.459674835188636],[-88.1666641236337,37.4460372923079],[-88.41047668485938,37.42574691785519],[-88.45619201638681,37.408615112566956],[-88.47867584212565,37.385440826560504],[-88.49048614517007,37.312602997180356],[-88.46478271463447,37.1187591551459],[-88.46968841578399,37.08929443394844],[-88.48487091075263,37.070842742975955],[-88.52648162823753,37.06475448611949],[-88.58071899380528,37.07622146578322],[-88.8704147339612,37.19657134988294],[-88.93831634554762,37.215396880880306],[-88.98947906487099,37.220222473397264],[-89.02574157697411,37.212978363190516],[-89.0488052369225,37.198673248111284],[-89.05108642541627,37.314044952566576],[-89.00608062715673,37.32505035421648],[-88.98607635473996,37.316047668380776],[-88.94808197014584,37.30404663064573],[-88.92121887197243,37.34314727816436],[-88.7130661013525,37.344047546122894],[-88.71206665019852,37.601047515859385],[-89.05007934568722,37.601047515859385],[-89.15409088146801,37.60804367081205],[-89.15409088146801,37.8600425720537],[-89.17609405541144,37.957042694169076],[-89.14208984373296,38.03504562359674],[-89.12908935562524,38.06504440286552],[-89.12408447284287,38.084049224909606],[-89.13508605942393,38.10404586797],[-89.1470794678026,38.123043060657714],[-89.1470794678026,38.20704269388406],[-89.1470794678026,38.46704483058873]]]}}

        ]
    }





];

app.config.glossary = {
    items: [
        {
            "id": "MRCC",
            "title": "Midwestern Regional Climate Center",
            "description":
                "The Midwestern Regional Climate Center is a cooperative program between the National Centers for Environmental Information (NCEI) and the Illinois State Water Survey in Champaign, Illinois. Our center is a partner in a national climate service program that includes NCEI, five other Regional Climate Centers, and State Climate Offices. The NCEI is part of the Department of Commerce, National Oceanic and Atmospheric Administration (NOAA).",
            "descriptionSources": [
                {
                    "title": "MRCC",
                    "link": "http://mrcc.isws.illinois.edu/about/aboutUs.jsp"
                },
                {
                    "title": "West Nile",
                    "link": "http://mrcc.isws.illinois.edu/research/westnile/index.jsp"
                }
            ]
        }
    ]
};

app.config.layers.items = [  {
  "type": "Feature",
  "geometry": {
    "type": "Point",
    "coordinates": [-88.84902, 40.09147]
  },
  "properties": {
    "title": "US States",
    "id": "gltg:us-states",
    "wms": "https://gltg.ncsa.illinois.edu/geoserver/wms",
    "opacity": 0.5,
    "checked": true,
    "showLayerLegend": false,
    "layerLegendTitle": "",
    "layerLegendContents": ""
  }
}
];

app.config.parameters.items = [

    {
        "id": "is-positive",
        "title": "Positive",
        "unit": "Boolean",
        "categories": ["Infection"],
        "description": "",
        "alternates": [],
        "detailView" : "time", // depth, or ignore
        "searchView": "visible", // only checking if it is != ignore as of 2014-06
        "exploreView" : "visible" // only checking if it is != ignore as of 2014-06
    },
    {
        "id": "pool-size",
        "title": "Pool Size",
        "unit": "Count",
        "categories": ["Vector Poplulation"],
        "description": "",
        "alternates": [],
        "detailView" : "time", // depth, or ignore
        "searchView": "visible", // only checking if it is != ignore as of 2014-06
        "exploreView" : "visible" // only checking if it is != ignore as of 2014-06
    }
];


app.config.sensors.items = [];

app.config.sources.items = [
   {'color': '#176497',
        'description': 'HANCOCK COUNTY HEALTH DEPT',
        'id': 'hancock-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from HANCOCK COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'HANCOCK COUNTY HEALTH DEPT',
        'title': 'HANCOCK COUNTY HEALTH DEPT'}
    ,
   {'color': '#764971',
        'description': 'FRANKLIN-WILLIAMSON B/C HEALTH DEPT',
        'id': 'franklin-williamson-bc-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from FRANKLIN-WILLIAMSON B/C HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'FRANKLIN-WILLIAMSON B/C HEALTH DEPT',
        'title': 'FRANKLIN-WILLIAMSON B/C HEALTH DEPT'}
    ,
   {'color': '#497176',
        'description': 'MARION COUNTY HEALTH DEPT',
        'id': 'marion-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from MARION COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'MARION COUNTY HEALTH DEPT',
        'title': 'MARION COUNTY HEALTH DEPT'}
    ,
   {'color': '#971764',
        'description': 'HAMILTON COUNTY HEALTH DEPT',
        'id': 'hamilton-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from HAMILTON COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'HAMILTON COUNTY HEALTH DEPT',
        'title': 'HAMILTON COUNTY HEALTH DEPT'}
    ,
   {'color': '#717946',
        'description': 'VERMILION COUNTY HEALTH DEPT',
        'id': 'vermilion-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from VERMILION COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'VERMILION COUNTY HEALTH DEPT',
        'title': 'VERMILION COUNTY HEALTH DEPT'}
    ,
   {'color': '#973576',
        'description': 'WAYNE COUNTY HEALTH DEPT',
        'id': 'wayne-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from WAYNE COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'WAYNE COUNTY HEALTH DEPT',
        'title': 'WAYNE COUNTY HEALTH DEPT'}
    ,
   {'color': '#637247',
        'description': 'OGLE COUNTY HEALTH DEPT',
        'id': 'ogle-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from OGLE COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'OGLE COUNTY HEALTH DEPT',
        'title': 'OGLE COUNTY HEALTH DEPT'}
    ,
   {'color': '#274919',
        'description': 'PERRY COUNTY HEALTH DEPT',
        'id': 'perry-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from PERRY COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'PERRY COUNTY HEALTH DEPT',
        'title': 'PERRY COUNTY HEALTH DEPT'}
    ,
   {'color': '#706829',
        'description': 'COOK COUNTY HEALTH DEPT',
        'id': 'cook-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from COOK COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'COOK COUNTY HEALTH DEPT',
        'title': 'COOK COUNTY HEALTH DEPT'}
    ,
    {'color': '#591982',
        'description': 'MONTGOMERY COUNTY HEALTH DEPT',
        'id': 'montgomery-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from MONTGOMERY COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'MONTGOMERY COUNTY HEALTH DEPT',
        'title': 'MONTGOMERY COUNTY HEALTH DEPT'}
    ,
    {'color': '#303378',
        'description': 'CLAY COUNTY HEALTH DEPT',
        'id': 'clay-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from CLAY COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'CLAY COUNTY HEALTH DEPT',
        'title': 'CLAY COUNTY HEALTH DEPT'}
    ,
    {'color': '#797282',
        'description': 'FORD-IROQUOIS HEALTH DEPT',
        'id': 'ford-iroquois-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from FORD-IROQUOIS B/C HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'FORD-IROQUOIS HEALTH DEPT',
        'title': 'FORD-IROQUOIS HEALTH DEPT'}
    ,
    {'color': '#867491',
        'description': 'BOND COUNTY HEALTH DEPT',
        'id': 'bond-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from BOND COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'BOND COUNTY HEALTH DEPT',
        'title': 'BOND COUNTY HEALTH DEPT'}
    ,
    {'color': '#889681',
        'description': 'JEFFERSON COUNTY HEALTH DEPT',
        'id': 'jefferson-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from JEFFERSON COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'JEFFERSON COUNTY HEALTH DEPT',
        'title': 'JEFFERSON COUNTY HEALTH DEPT'}
    ,
    {'color': '#545479',
        'description': 'WILL COUNTY HEALTH DEPT',
        'id': 'will-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from WILL COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'WILL COUNTY HEALTH DEPT',
        'title': 'WILL COUNTY HEALTH DEPT'}
    ,
    {'color': '#169563',
        'description': 'MADISON COUNTY HEALTH DEPT',
        'id': 'madison-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from MADISON COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'MADISON COUNTY HEALTH DEPT',
        'title': 'MADISON COUNTY HEALTH DEPT'}
    ,
    {'color': '#870400',
        'description': 'OAK PARK HEALTH DEPT',
        'id': 'oak-park-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from OAK PARK HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'OAK PARK HEALTH DEPT',
        'title': 'OAK PARK HEALTH DEPT'}
    ,
    {'color': '#601182',
        'description': 'HENRY COUNTY HEALTH DEPT',
        'id': 'henry-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from HENRY COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'HENRY COUNTY HEALTH DEPT',
        'title': 'HENRY COUNTY HEALTH DEPT'}
    ,
    {'color': '#939772',
        'description': 'EVANSTON HEALTH DEPT',
        'id': 'evanston-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from EVANSTON HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'EVANSTON HEALTH DEPT',
        'title': 'EVANSTON HEALTH DEPT'}
    ,
    {'color': '#580279',
        'description': 'SKOKIE HEALTH DEPT',
        'id': 'skokie-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from SKOKIE HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'SKOKIE HEALTH DEPT',
        'title': 'SKOKIE HEALTH DEPT'}
    ,
    {'color': '#569913',
        'description': 'TAZEWELL COUNTY HEALTH DEPT',
        'id': 'tazewell-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from TAZEWELL COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'TAZEWELL COUNTY HEALTH DEPT',
        'title': 'TAZEWELL COUNTY HEALTH DEPT'}
    ,
    {'color': '#349404',
        'description': 'GRUNDY COUNTY HEALTH DEPT',
        'id': 'grundy-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from GRUNDY COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'GRUNDY COUNTY HEALTH DEPT',
        'title': 'GRUNDY COUNTY HEALTH DEPT'}
    ,
    {'color': '#126264',
        'description': 'MACON COUNTY HEALTH DEPT',
        'id': 'macon-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from MACON COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'MACON COUNTY HEALTH DEPT',
        'title': 'MACON COUNTY HEALTH DEPT'}
    ,
    {'color': '#582557',
        'description': 'MCLEAN COUNTY HEALTH DEPT',
        'id': 'mclean-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from MCLEAN COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'MCLEAN COUNTY HEALTH DEPT',
        'title': 'MCLEAN COUNTY HEALTH DEPT'}
    ,
    {'color': '#331443',
        'description': 'MENARD COUNTY HEALTH DEPT',
        'id': 'menard-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from MENARD COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'MENARD COUNTY HEALTH DEPT',
        'title': 'MENARD COUNTY HEALTH DEPT'}
    ,
    {'color': '#406414',
        'description': 'SANGAMON COUNTY HEALTH DEPT',
        'id': 'sangamon-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from SANGAMON COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'SANGAMON COUNTY HEALTH DEPT',
        'title': 'SANGAMON COUNTY HEALTH DEPT'}
    ,
    {'color': '#559564',
        'description': 'CHAMPAIGN COUNTY HEALTH DEPT',
        'id': 'champaign-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from CHAMPAIGN COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'CHAMPAIGN COUNTY HEALTH DEPT',
        'title': 'CHAMPAIGN COUNTY HEALTH DEPT'}
    ,
    {'color': '#971655',
        'description': 'CHAMPAIGN-URBANA PUBLIC HEALTH DIST',
        'id': 'champaign-urbana-public-health-dist',
        'parameters': {'description': 'The following are a subset of parameters that are available from CHAMPAIGN-URBANA PUBLIC HEALTH DIST',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'CHAMPAIGN-URBANA PUBLIC HEALTH DIST',
        'title': 'CHAMPAIGN-URBANA PUBLIC HEALTH DIST'}
    ,
    {'color': '#549412',
        'description': 'KANE COUNTY HEALTH DEPT',
        'id': 'kane-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from KANE COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'KANE COUNTY HEALTH DEPT',
        'title': 'KANE COUNTY HEALTH DEPT'}
    ,
    {'color': '#345542',
        'description': 'CHICAGO HEALTH DEPT',
        'id': 'chicago-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from CHICAGO HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'CHICAGO HEALTH DEPT',
        'title': 'CHICAGO HEALTH DEPT'}
    ,
    {'color': '#688787',
        'description': 'DUPAGE COUNTY HEALTH DEPT',
        'id': 'dupage-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from DUPAGE COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'DUPAGE COUNTY HEALTH DEPT',
        'title': 'DUPAGE COUNTY HEALTH DEPT'}
    ,
    {'color': '#715703',
        'description': 'KENDALL COUNTY HEALTH DEPT',
        'id': 'kendall-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from KENDALL COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'KENDALL COUNTY HEALTH DEPT',
        'title': 'KENDALL COUNTY HEALTH DEPT'}
    ,
    {'color': '#495032',
        'description': 'ADAMS COUNTY HEALTH DEPT',
        'id': 'adams-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from ADAMS COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'ADAMS COUNTY HEALTH DEPT',
        'title': 'ADAMS COUNTY HEALTH DEPT'}
    ,
    {'color': '#395160',
        'description': 'KANKAKEE COUNTY HEALTH DEPT',
        'id': 'kankakee-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from KANKAKEE COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'KANKAKEE COUNTY HEALTH DEPT',
        'title': 'KANKAKEE COUNTY HEALTH DEPT'}
    ,
    {'color': '#504620',
        'description': 'ST CLAIR COUNTY HEALTH DEPT',
        'id': 'st-clair-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from ST CLAIR COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'ST CLAIR COUNTY HEALTH DEPT',
        'title': 'ST CLAIR COUNTY HEALTH DEPT'}
    ,
    {'color': '#829168',
        'description': 'LAKE COUNTY HEALTH DEPT',
        'id': 'lake-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from LAKE COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'LAKE COUNTY HEALTH DEPT',
        'title': 'LAKE COUNTY HEALTH DEPT'}
    ,
    {'color': '#201918',
        'description': 'MCHENRY COUNTY HEALTH DEPT',
        'id': 'mchenry-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from MCHENRY COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'MCHENRY COUNTY HEALTH DEPT',
        'title': 'MCHENRY COUNTY HEALTH DEPT'}
    ,
    {'color': '#478259',
        'description': 'EGYPTIAN HEALTH DEPT',
        'id': 'egyptian-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from EGYPTIAN HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'EGYPTIAN HEALTH DEPT',
        'title': 'EGYPTIAN HEALTH DEPT'}
    ,
    {'color': '#557538',
        'description': 'MASON COUNTY HEALTH DEPT',
        'id': 'mason-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from MASON COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'MASON COUNTY HEALTH DEPT',
        'title': 'MASON COUNTY HEALTH DEPT'}
    ,
    {'color': '#356500',
        'description': 'WASHINGTON COUNTY HEALTH DEPT',
        'id': 'washington-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from WASHINGTON COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'WASHINGTON COUNTY HEALTH DEPT',
        'title': 'WASHINGTON COUNTY HEALTH DEPT'}
    ,
    {'color': '#377902',
        'description': 'JERSEY COUNTY HEALTH DEPT',
        'id': 'jersey-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from JERSEY COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'JERSEY COUNTY HEALTH DEPT',
        'title': 'JERSEY COUNTY HEALTH DEPT'}
    ,
    {'color': '#285401',
        'description': 'JACKSON COUNTY HEALTH DEPT',
        'id': 'jackson-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from JACKSON COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'JACKSON COUNTY HEALTH DEPT',
        'title': 'JACKSON COUNTY HEALTH DEPT'}
    ,
    {'color': '#658574',
        'description': 'STEPHENSON COUNTY HEALTH DEPT',
        'id': 'stephenson-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from STEPHENSON COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'STEPHENSON COUNTY HEALTH DEPT',
        'title': 'STEPHENSON COUNTY HEALTH DEPT'}
    ,
    {'color': '#994861',
        'description': 'LIVINGSTON COUNTY HEALTH DEPT',
        'id': 'livingston-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from LIVINGSTON COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'LIVINGSTON COUNTY HEALTH DEPT',
        'title': 'LIVINGSTON COUNTY HEALTH DEPT'}
    ,
    {'color': '#538035',
        'description': 'PEORIA CITY COUNTY HEALTH DEPT',
        'id': 'peoria-city-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from PEORIA CITY/COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'PEORIA CITY COUNTY HEALTH DEPT',
        'title': 'PEORIA CITY COUNTY HEALTH DEPT'}
    ,
    {'color': '#598215',
        'description': 'WINNEBAGO COUNTY HEALTH DEPT',
        'id': 'winnebago-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from WINNEBAGO COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'WINNEBAGO COUNTY HEALTH DEPT',
        'title': 'WINNEBAGO COUNTY HEALTH DEPT'}
    ,
    {'color': '#955003',
        'description': 'EASTSIDE HEALTH DIST',
        'id': 'eastside-health-dist',
        'parameters': {'description': 'The following are a subset of parameters that are available from EASTSIDE HEALTH DIST',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'EASTSIDE HEALTH DIST',
        'title': 'EASTSIDE HEALTH DIST'}
    ,
    {'color': '#861766',
        'description': 'CLINTON COUNTY HEALTH DEPT',
        'id': 'clinton-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from CLINTON COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'CLINTON COUNTY HEALTH DEPT',
        'title': 'CLINTON COUNTY HEALTH DEPT'}
    ,
    {'color': '#454962',
        'description': 'FULTON COUNTY HEALTH DEPT',
        'id': 'fulton-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from FULTON COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'FULTON COUNTY HEALTH DEPT',
        'title': 'FULTON COUNTY HEALTH DEPT'}
    ,
    {'color': '#376460',
        'description': 'MONROE COUNTY HEALTH DEPT',
        'id': 'monroe-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from MONROE COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'MONROE COUNTY HEALTH DEPT',
        'title': 'MONROE COUNTY HEALTH DEPT'}
    ,
    {'color': '#678731',
        'description': 'LOGAN COUNTY HEALTH DEPT',
        'id': 'logan-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from LOGAN COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'LOGAN COUNTY HEALTH DEPT',
        'title': 'LOGAN COUNTY HEALTH DEPT'}
    ,
    {'color': '#288342',
        'description': 'BOONE COUNTY HEALTH DEPT',
        'id': 'boone-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from BOONE COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'BOONE COUNTY HEALTH DEPT',
        'title': 'BOONE COUNTY HEALTH DEPT'}
    ,
    {'color': '#779654',
        'description': 'BUREAU COUNTY HEALTH DEPT',
        'id': 'bureau-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from BUREAU COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'BUREAU COUNTY HEALTH DEPT',
        'title': 'BUREAU COUNTY HEALTH DEPT'}
    ,
    {'color': '#437699',
        'description': 'STARK COUNTY HEALTH DEPT',
        'id': 'stark-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from STARK COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'STARK COUNTY HEALTH DEPT',
        'title': 'STARK COUNTY HEALTH DEPT'}
    ,
    {'color': '#997490',
        'description': 'KNOX COUNTY HEALTH DEPT',
        'id': 'knox-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from KNOX COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'KNOX COUNTY HEALTH DEPT',
        'title': 'KNOX COUNTY HEALTH DEPT'}
    ,
    {'color': '#733099',
        'description': 'MCDONOUGH COUNTY HEALTH DEPT',
        'id': 'mcdonough-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from MCDONOUGH COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'MCDONOUGH COUNTY HEALTH DEPT',
        'title': 'MCDONOUGH COUNTY HEALTH DEPT'}
    ,
    {'color': '#751553',
        'description': 'CASS COUNTY HEALTH DEPT',
        'id': 'cass-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from CASS COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'CASS COUNTY HEALTH DEPT',
        'title': 'CASS COUNTY HEALTH DEPT'}
    ,
    {'color': '#478013',
        'description': 'SCHUYLER COUNTY HEALTH DEPT',
        'id': 'schuyler-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from SCHUYLER COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'SCHUYLER COUNTY HEALTH DEPT',
        'title': 'SCHUYLER COUNTY HEALTH DEPT'}
    ,
    {'color': '#738368',
        'description': 'WHITESIDE COUNTY HEALTH DEPT',
        'id': 'whiteside-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from WHITESIDE COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'WHITESIDE COUNTY HEALTH DEPT',
        'title': 'WHITESIDE COUNTY HEALTH DEPT'}
    ,
    {'color': '#932889',
        'description': 'MARSHALL COUNTY HEALTH DEPT',
        'id': 'marshall-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from MARSHALL COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'MARSHALL COUNTY HEALTH DEPT',
        'title': 'MARSHALL COUNTY HEALTH DEPT'}
    ,
    {'color': '#728612',
        'description': 'LASALLE COUNTY HEALTH DEPT',
        'id': 'lasalle-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from LASALLE COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'LASALLE COUNTY HEALTH DEPT',
        'title': 'LASALLE COUNTY HEALTH DEPT'}
    ,
    {'color': '#536349',
        'description': 'IROQUOIS COUNTY HEALTH DEPT',
        'id': 'iroquois-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from IROQUOIS COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'IROQUOIS COUNTY HEALTH DEPT',
        'title': 'IROQUOIS COUNTY HEALTH DEPT'}
    ,
    {'color': '#651900',
        'description': 'FAYETTE COUNTY HEALTH DEPT',
        'id': 'fayette-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from FAYETTE COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'FAYETTE COUNTY HEALTH DEPT',
        'title': 'FAYETTE COUNTY HEALTH DEPT'}
    ,
    {'color': '#217165',
        'description': 'MORGAN COUNTY HEALTH DEPT',
        'id': 'morgan-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from MORGAN COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'MORGAN COUNTY HEALTH DEPT',
        'title': 'MORGAN COUNTY HEALTH DEPT'}
    ,
    {'color': '#772521',
        'description': 'ROCK ISLAND COUNTY HEALTH DEPT',
        'id': 'rock-island-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from ROCK ISLAND COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'ROCK ISLAND COUNTY HEALTH DEPT',
        'title': 'ROCK ISLAND COUNTY HEALTH DEPT'}
    ,
    {'color': '#564825',
        'description': 'WARREN COUNTY HEALTH DEPT',
        'id': 'warren-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from WARREN COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'WARREN COUNTY HEALTH DEPT',
        'title': 'WARREN COUNTY HEALTH DEPT'}
    ,
    {'color': '#237180',
        'description': 'CLARK COUNTY HEALTH DEPT',
        'id': 'clark-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from CLARK COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'CLARK COUNTY HEALTH DEPT',
        'title': 'CLARK COUNTY HEALTH DEPT'}
    ,
    {'color': '#390300',
        'description': 'PUTNAM COUNTY HEALTH DEPT',
        'id': 'putnam-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from PUTNAM COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'PUTNAM COUNTY HEALTH DEPT',
        'title': 'PUTNAM COUNTY HEALTH DEPT'}
    ,
    {'color': '#523684',
        'description': 'DEKALB COUNTY HEALTH DEPT',
        'id': 'dekalb-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from DEKALB COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'DEKALB COUNTY HEALTH DEPT',
        'title': 'DEKALB COUNTY HEALTH DEPT'}
    ,
    {'color': '#617446',
        'description': 'CALHOUN COUNTY HEALTH DEPT',
        'id': 'calhoun-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from CALHOUN COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'CALHOUN COUNTY HEALTH DEPT',
        'title': 'CALHOUN COUNTY HEALTH DEPT'}
    ,
    {'color': '#202361',
        'description': 'LEE COUNTY HEALTH DEPT',
        'id': 'lee-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from LEE COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'LEE COUNTY HEALTH DEPT',
        'title': 'LEE COUNTY HEALTH DEPT'}
    ,
    {'color': '#865388',
        'description': 'HENDERSON COUNTY HEALTH DEPT',
        'id': 'henderson-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from HENDERSON COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'HENDERSON COUNTY HEALTH DEPT',
        'title': 'HENDERSON COUNTY HEALTH DEPT'}
    ,
    {'color': '#577760',
        'description': 'GREENE COUNTY HEALTH DEPT',
        'id': 'greene-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from GREENE COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'GREENE COUNTY HEALTH DEPT',
        'title': 'GREENE COUNTY HEALTH DEPT'}
    ,
    {'color': '#277125',
        'description': 'MERCER COUNTY HEALTH DEPT',
        'id': 'mercer-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from MERCER COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'MERCER COUNTY HEALTH DEPT',
        'title': 'MERCER COUNTY HEALTH DEPT'}
    ,
    {'color': '#389285',
        'description': 'JASPER COUNTY HEALTH DEPT',
        'id': 'jasper-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from JASPER COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'JASPER COUNTY HEALTH DEPT',
        'title': 'JASPER COUNTY HEALTH DEPT'}
    ,
    {'color': '#340812',
        'description': 'CARROLL COUNTY HEALTH DEPT',
        'id': 'carroll-county-health-dept',
        'parameters': {'description': 'The following are a subset of parameters that are available from CARROLL COUNTY HEALTH DEPT',
            'ids': ['is-positive',
                'pool-size',
                'week',
                'climate-division']},
        'prettyName': 'CARROLL COUNTY HEALTH DEPT',
        'title': 'CARROLL COUNTY HEALTH DEPT'}


];

app.config.views = {
    welcome: {
        title: "Welcome",
        link: "#welcome",
        "template": "#welcome-template"
    },
    home: {
        title: "Explore",
        link: "#explore",
        attributes: {
            id: 'home-view'
        },
        templateSelector: "#explore-template",
        explore: {
            attributes: {
                class: "accordion"
            },
            map: {
                maxBounds: [
                    [17, -107],
                    [59, -71]
                ],
                minZoom: 5,
                maxZoom: 18,
                scrollWheelZoom: false,
                id: "#explore-map-view",
                mapTileSource: '//{s}.tile.openstreetmap.org/{z}/{x}/{y}.png',
                mapAttribution: '&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a> contributors',
                clusterSize: 45,
                cluster: true
            },
            accordion: {
                containerID: "#explore-accordion-container",
                // set the defaults for an accordion item
                // can be overridden in an item object
                template: '#explore-accordion-item-template',
                class: 'accordion-group',
                hidePills: true,
                maxPills: 20,
                maxPillsCustom: 24,
                items: [
                    {
                        attributes: {
                            id: "layers",
                            class: 'accordion-group'
                        },
                        title: "Explore Layers",
                        defaultOpen: false,
                        showStationLegend: false,
                        contents: {
                            viewType: "LayersCollectionView",
                            containerID: "explore-layers-accordion-contents",
                            viewConfig: {
                                templateID: '#explore-layers-template'
                            }
                        }
                    }, {
                        attributes: {
                            id: "sources"
                        },
                        title: "Explore Data by Source",
                        defaultOpen: true,
                        showStationLegend: true,
                        contents: {
                            viewType: "ExploreSourcesView",
                            containerID: "explore-sources-accordion-contents",
                            viewConfig: {
                                templateID: '#explore-sources-template',
                                map: {
                                    id: "#explore-map-view",
                                    scrollWheelZoom: false
                                },
                                modalsID: "#source-modals-template",
                                pills: {
                                    className: ".explore-pill",
                                    tooltipOptions: {
                                        animation: true,
                                        placement: "right",
                                        container: "body"
                                    }
                                },
                                collapse: {
                                    className: '.collapse',
                                    inputSelector: 'input[name="source"]'
                                }
                            }
                        }
                    }
                    // ,
                    // {
                    //     attributes: {
                    //         id: "explore-accordion-group-climated-division",
                    //         class: 'accordion-group'
                    //     },
                    //     title: "Explore Data by Climate Division",
                    //     defaultOpen: false,
                    //     showStationLegend: true,
                    //     contents: {
                    //         viewType: "ExploreByCustomView",
                    //         containerID: "explore-custom-accordion-contents",
                    //         viewConfig: {
                    //             groupingOrder: ["huc4", "sources", "sensors"],
                    //             primaryCollection: "sensors",
                    //             collectionGroupingFunction: "groupByHUCcodeSourcesSensors",
                    //             collectionGroupingFunctionArguments: {
                    //                 hucCode: 4
                    //             },
                    //             templateID: '#explore-custom-template',
                    //             map: {
                    //                 id: "#explore-map-view",
                    //                 scrollWheelZoom: false
                    //             },
                    //             modalsID: false
                    //         }
                    //     }
                    // }

                ]
            },
            "moreinfo": {
                "text": "More information about EPA/GLMPO",
                "link": "http://www.epa.gov/greatlakes/"
            }
        }
    },
    compare: {
        title: "Compare",
        link: "#compare",
        removeBinDropdown: true,
        miniMap: {
            id: "compare-sidebar-minimap",
            coordinates: [
                [28, -123],
                [48, -68]
            ],
            config: {
                tagName: 'div',
                mapOptions: {
                    zoomControl: false,
                    attributionControl: false,
                    dragging: false,
                    touchZoom: false,
                    scrollWheelZoom: false,
                    doubleClickZoom: false,
                    boxZoom: false,
                    mapTileSource: '//{s}.tile.openstreetmap.org/{z}/{x}/{y}.png',
                    mapAttribution: '&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a> contributors',
                    center: [38, -91],
                    zoom: 2

                },
                geoJsonFeature: []
            }
        },
        subviews: {
            sensors: {
                label: "Stations",
                sidebar: {
                    template: "#compare-sidebar-stations-template",
                    clickableDOMItems: 'button.compare-pill'
                },
                graph: {
                    template: "#compare-graph-stations-template"
                }
            },
            areas: {
                label: "Lakes",
                sidebar: {
                    template: "#compare-sidebar-areas-template"
                },
                graph: {
                    template: "#compare-graph-areas-template"
                }
            }
        }
    },
    detail: {
        attributes: {
            id: "detail-view",
            class: 'row-fluid'
        },
        templateSelector: "#detail-template",
        miniMap: [
            {
                id: "#mini-map",
                config: {
                    tagName: 'div',
                    mapOptions: {
                        zoomControl: false,
                        attributionControl: false,
                        dragging: false,
                        touchZoom: false,
                        scrollWheelZoom: false,
                        doubleClickZoom: false,
                        boxZoom: false,
                        mapTileSource: '//{s}.tile.openstreetmap.org/{z}/{x}/{y}.png',
                        mapAttribution: '&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a> contributors'
                    },
                    geoJsonFeature: []
                }
            }
        ],
        controlsViews: [{
            name: "controlsView",
            config: {
                name: "time",
                el: "#modal-content",
                parametersID: "parameters-time",
                dateRangeID: "date-range-time",
                sliderID: "slider-time",
                attributes: {
                    tagName: 'div',
                    id: 'controls'
                }
            }

        }, {
            name: "controlsDepthView",
            config: {
                name: "depth",
                el: "#modal-content",
                yearFormID: "year-depth",
                yearSelectID: "year-depth-select",
                parametersID: "parameters-depth",
                attributes: {
                    tagName: 'div',
                    id: 'controls'
                }
            }

        }],
        timeSeriesViews: [],
        limnologyViews: []
    },
    search: {
        title: app.config.search_link.title,
        link: app.config.search_link.url,
        attributes: {
            id: "search-body",
            class: 'row-fluid'
        },
        templateSelector: "#search-template",
        map: {
            id: '#search-map',
            maxBounds: [
                [13, -131],
                [58, -55]
            ],
            minZoom: 5,
            maxZoom: 12,
            scrollWheelZoom: false,
            mapTileSource: '//{s}.tile.openstreetmap.org/{z}/{x}/{y}.png',
            mapAttribution: '&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a> contributors',
            markerFillColor: "#C0C0C0",
            markerColor: "#000000",
            radius: 3,
            weight: 1,
            opacity: 1,
            fillOpacity: 1
        },
        shapeOptions: {
            stroke: true,
            color: '#20201F',
            weight: 4,
            opacity: 0.5,
            fill: true,
            fillColor: null, //same as color by default
            fillOpacity: 0.2,
            clickable: true
        },
        drawOptions: {
            position: 'topright',
            draw: {
                polyline: false,
                marker: false
            },
            edit: {
                remove: true
            }
        },
        resetMapButtonOptions: {
            text: 'Reset Search', // string
            iconUrl: '', // string
            glyph: '', // bootstrap glyph icons
            hideText: true, // bool
            maxWidth: 30, // number
            doToggle: false, // bool
            toggleStatus: false // bool
        },
        layers: {
            layerWeight: 1,
            layerOpacity: 1,
            bindPopupClass: "search-popup",
            items: [{
                name: "basins",
                featureProperties: "LAKEBASIN"
            }]
        },
        dateRangeSelector: {
            id: '#searchtime',
            format: 'YYYY-MM-DD h:mm:ss',
            opens: 'right'
        },
        downloadButtons: {
            permalink: {
                id: "#permalink",
                downloadID: "#download-permalink",
                template: "#permalink-template",
                modalID: "#permalink-modal"
            },
            json: {
                id: '#download-json'
            },
            csv: {
                id: "#download-csv"
            },
            visualize: {
                id: "#download-visualize"
            }

        }
    },
    footer: {
        templateID: "#footer-template"
    },
    about: {
        title: "About",
        link: "#about",
        "template": "#about-template",
        "children": [
            {
                "title": "Partners",
                "link": "#partners",
                "template": "#partners-template"
            },
            {
                "title": "Glossary",
                "link": "#glossary",
                "template": "#glossary-template"
            },
            {
                "title": "Help",
                "link": "#help",
                "template": "#help-template"
            },
            {
                "title": "FAQ",
                "link": "#faq",
                "template": "#faq-template"
            }
        ]
    }
};

// your public api url. Prod and Dev use this read-only, so it is staticly set here.
app.config.clowderUrl = window.location.origin + "/clowder";

// loads jQuery and Backbone
(function($, Backbone, window, undefined) {
    "use strict";

app.graphs.boxwhisker = function() {
	var width = 185, height = 500, vMargin = 40, hMargin = 50;

	function boxwhisker(selection) {
		selection.each(function(d) {
			d = d.values[0];
      if (app.config.features.boxWhiskerRaw) {
        d = _.flatten(d.values.map(function(d) { return d.raw; })).sort(d3.ascending);
      } else {
        d = _.flatten(d.values.map(function(d) { return d.y; })).sort(d3.ascending);
      }

			var x = d3.scale.quantize().domain([0, 100]).range([0, hMargin, width / 2, width - hMargin, width]),
				y = d3.scale.linear().domain([Math.min(0, d[0]), d[d.length - 1]]).range([height - vMargin, vMargin]);

			var median = d3.quantile(d, 0.5),
				quartileRange = [d3.quantile(d, 0.25), d3.quantile(d, 0.75)],
				IQR = (quartileRange[1] - quartileRange[0]),
				extremefn = function(d) { return d < quartileRange[0] - 3 * IQR || d > quartileRange[1] + 3 * IQR; },
				outlierfn = function(d) { return !extremefn(d) && (d < quartileRange[0] - 1.5 * IQR || d > quartileRange[1] + 1.5 * IQR); },
				extremes = d.filter(function(d) { return extremefn(d); }),
				outliers = d.filter(function(d) { return outlierfn(d); }),
				mean = d3.mean(d),
				extent = d3.extent(d.filter(function(d) { return !(outlierfn(d) || extremefn(d)); }));

			var svg = d3.select(this).selectAll(".graphs-bw").data([0]);
			svg.enter().append("svg").attr("xmlns", "http://www.w3.org/2000/svg").attr("version", "1.1")
				.attr("preserveAspectRatio", "none").attr("class", "graphs-bw");
			svg.attr("viewBox", "0 0 " + width + " " + height);
			
			// Create lines which represent the upper and lower quartiles.
			var line = svg.selectAll(".graphs-quartile-range").data([x(25), x(75)]);
			line.enter().append("line").attr("class", "graphs-quartile-range");
			line.transition().attr("x1", function(d) { return d; }).attr("x2", function(d) { return d; })
				.attr("y1", y(quartileRange[0])).attr("y2", y(quartileRange[1]));
				
			// Create the circle that represents the mean.	
			var circle = svg.selectAll(".graphs-mean").data([mean]);
			circle.enter().append("circle").attr("class", "graphs-mean");
			circle.transition().attr("cy", function(d) { return y(d); })
				.attr("r", ((x(75) - x(25))/16)).attr("cx", x(50));
			
			
			// Create the lines that connect the quartiles to their extrema	
			var connection = svg.selectAll(".graphs-connection").data(extent);
			connection.enter().append("line").attr("class", "graphs-connection");
			connection.transition().attr("x1", x(50)).attr("y1", function(d) { return y(d); })
				.attr("x2", x(50)).attr("y2", function(d, i) { return y(quartileRange[i]); });
			
			// Create the circles for the outliers	
			var outlier = svg.selectAll(".graphs-outlier").data(outliers);
			outlier.enter().append("circle").attr("class", "graphs-outlier")
				.attr("cy", function(d) { return d < extent[0] ? height + 20 : -10; });
			outlier.exit().transition().style("opactiy", "0")
				.attr("cy", function(d) { return d3.select(this).attr("cy") >= height / 2 ? height + 20 : -10; }).remove();
			outlier.transition().attr("cy", function(d) { return y(d); })
				.attr("r", ((x(75) - x(25))/32)).attr("cx", x(50));

			// create the circles for the extreme outliers
			var extreme = svg.selectAll(".graphs-extreme").data(extremes);
			extreme.enter().append("circle").attr("class", "graphs-extreme")
				.attr("cy", function(d) { return d < extent[0] ? height + 20 : -10; });
			extreme.exit().transition().style("opactiy", "0")
				.attr("cy", function(d) { return d3.select(this).attr("cy") >= height / 2 ? height + 20 : -10; }).remove();
			extreme.transition().attr("cy", function(d) { return y(d); })
				.attr("r", ((x(75) - x(25))/32)).attr("cx", x(50));

			
			// Create the labels for all the interesting features, min, max, quartiles, median
			extent.splice(1, 0, quartileRange[0], median, quartileRange[1]);
			var feature = svg.selectAll(".graphs-feature").data(extent),
				featureEnter = feature.enter().append("g").attr("class", "graphs-feature");

			featureEnter.append("line");
			featureEnter.append("text");

			feature.select("line").transition().attr("x1", x(25)).attr("x2", x(75))
				.attr("y1", function(d) { return y(d); })
				.attr("y2", function(d) { return y(d); });

			feature.select("text").transition().attr("dy", ".32em")
				.attr("x", function(d, i)  { return i % 2 ? x(25) -5 : x(75) + 5; })
				.attr("y", function(d)  { return y(d); }).text(function(d) { return Math.round(d*100)/100; }) // use d3.format
				.style("text-anchor", function(d, i) { return i % 2 ? "end" : "start"; });
		});
	}
	
	boxwhisker.width = function(value) {
		if(!arguments.length) return width;
		width = value;
		return boxwhisker;
	};
	
	boxwhisker.height = function(value) {
		if(!arguments.length) return height;
		height = value;
		return boxwhisker;
	};
	
	boxwhisker.margin = function(vertical, horizontal) {
		if(!arguments.length) return [vMargin, hMargin];
		
		vMargin = vertical;
		
		if(horizontal === undefined) 
			hMargin = vertical;
		else hMargin = horizontal;
		
		return boxwhisker;
	};
	
	return boxwhisker;
};

app.graphs.depth = function() {
    var width = 510, height = 500, margin = 40,
        min = 0, max = 10, interpolate = "linear",
        dispatch = null;
    
    function depth(selection) {
		selection.each(function(d) {
			d = mapper(d);
			
			var ys = yScale(d.values);
			
			var y = d3.scale.linear().range([margin, height]).domain(ys);
            	
            var range = Array.range(+ys[0], +ys[1]);
            
            var graph = d3.select(this).selectAll("svg").data([0]);
            graph.enter()
                .append("svg")
                .attr("class", "graphs-depth-chart");
            graph.attr("width", width).attr("height", height + d.values.length * margin);
            
            // Y-Axis Label
            if(app.config.graphs.depthProfile.showUnits.graphYAxis)
            {
                var yAxisLabel = graph.selectAll(".graphs-yAxisLabel").data([0]);
                
                yAxisLabel.enter()
                    .append("text")
                    .attr("class", "graphs-yAxisLabel");
                
                yAxisLabel.transition()
                    .attr("transform", "rotate(-90)")
                    .style("text-anchor", "middle")
                    .attr("x", -215) // Moving up/down. + (up), - (down)
                    .attr("y", 10) // Moving left/right. + (right), - (left)
                    .text("Meters");
                
                yAxisLabel.exit().remove();
            }
                
            /* Y Axis */
            var yAxis = graph.selectAll(".graphs-y-axis").data([d.values]);
            yAxis.enter().append("g").attr("class", "graphs-y-axis")
                .attr("transform", "translate(" + margin + ", 0)");
            yAxis.exit().remove();
            yAxis.transition().call(d3.svg.axis().scale(y).orient("left"));
            
            if (false) {
              var depthBins = graph.selectAll(".graphs-depth-bin").data(range);
              depthBins.enter().append("rect").attr("class", "graphs-depth-bin").style("color", "white")
                  .style("opacity", "0").style("cursor", "pointer")
                  .on("mouseover.graphs", function(d, i) {
                      d3.select(this).transition().style("color", "grey").style("opacity", "0.6");
                  }).on("mouseout.graphs", function(d, i) {
                      d3.select(this).transition().style("color", "white").style("opacity", "0");
                  }).on("click.graphs", function(d, i) {
                      d3.selectAll(".graphs-selected-bin").classed("graphs-selected-bin", false);
                      d3.select(this).classed("graphs-selected-bin", true);
                      dispatch.changeDepth.call(this, i);
                  });
              depthBins.exit().remove();
              depthBins.transition().attr("x", margin).attr("y", function(d) { return y(d); }).attr("width", width - 2 * margin).attr("height", (height) / range.length);
            }            
            
            var chart = graph.selectAll(".graphs-chart").data(d.values, function(d) { return d.key; });
            chart.enter().append("g").attr("class", function(d) { return "graphs-chart " + d.key; })
                .style("color", function(f) { return f.color; })
                .style("stroke", function(f) { return f.color; })
                .style("fill", function(f) { return f.color; });
            chart.exit().transition().style("opacity", 0).remove();
            
            /* X Axis */
            var xAxis = chart.selectAll(".graphs-x-axis").data(function(d) { return [d]; }, function(d) { return d.key; });
            xAxis.enter().append("g").attr("class", "graphs-x-axis").attr("transform", function(d) { return "translate(0, " + (height + 5) + ")"; });
            xAxis.transition().call(function(selection) { selection.each(function(d) { d3.select(this).call(d3.svg.axis().scale(d.xScale).orient("bottom")); }); })
				.attr("transform", function(d, i, j) { return "translate(0, " + (height + margin * (j)) + ")"; });
            
            // Parameter + Unit
            if(app.config.graphs.depthProfile.showUnits.graphXAxis)
            {
                xAxis.append("text")
                    .attr("x", 40)
                    .attr("y", 27)
                    .text(function(d) {
                        // show the parameter's unit if it exists, otherwise show just the parameter
                        return (d.unit) ? (d.key).toUpperCase() + " ( " + d.unit + " )" : (d.key).toUpperCase()
                    });
            }
            
            var line = chart.selectAll(".graphs-line").data(function(d) { return [d]; }, function(d) { return d.key; });
            line.enter().append("path").attr("class", "graphs-line");
            line.transition().attr("d", function(d) { return d3line(d.xScale, y)(d.values); });
			
			var area = chart.selectAll(".graphs-area").data(function(d) { return [d]; }, function(d) { return d.key; });
			area.enter().append("path").attr("class", "graphs-area");
			area.transition().attr("d", function(d) { return d3area(d.xScale, y)(d.values); });
		});
    }
    
    function d3line(x, y) {
        return d3.svg.line()
			.x(function(d) { return x(d.x); })
			.y(function(d) { return y(d.y); })
			.interpolate(interpolate);
    }

    function d3area(x, y) {
        return d3.svg.area()
            .x0(function(d) { return x(d.x0); })
            .x1(function(d) { return x(d.x1); })
            .y(function(d) { return y(d.y); })
            .interpolate(interpolate);
    }

    function yScale(values) {
    	var yValues = values.reduce(function(a, b) { // Flatten the outer most array
    		return a.concat(b.values.reduce(function(a, b) { // Flatten the value objects
                return a.concat([b.y]); 
    		}, [])); 
    	}, []); // We should now have an array of all the y values in the heirarchy
        
        return d3.extent(yValues);
        // return d3.scale.linear().range([margin, height - values.length * margin])
        //     .domain(d3.extent(yValues));
    }

    function xScale(values) {
        var xValues = values.reduce(function(a, b) { return a.concat([b.x]); }, []);
        return d3.scale.linear().range([margin, width - margin])
            .domain([d3.min(xValues), d3.max(xValues)]);
    }
    
    // Precomputation on data, should happen before (or during) call to mapper
    function depthBin(values) {
        var depthSums = {}, minBoundSum = {}, maxBoundSum = {};
        var depthCounts = {};
        values.forEach(function(d) {
            var val = Math.floor(d.y);
            if(!depthCounts[val]) {
                depthCounts[val] = depthSums[val] = minBoundSum[val] = maxBoundSum[val] = 0;
            }
            
            depthCounts[val]++;
            depthSums[val] += d.x;
            minBoundSum[val] += d.x0;
            maxBoundSum[val] += d.x1;
        });
        
        return Object.keys(depthCounts).map(function(d) {
			return {
				x : depthSums[d] / depthCounts[d],
				y : +d,
				x0 : minBoundSum[d] / depthCounts[d],
				x1 : maxBoundSum[d] / depthCounts[d]
			};
        });
    }
        
    function mapper(data) {
        data.values.map(function(d) {
            d.values = depthBin(d.values);
            d.xScale = xScale(d.values);
            return d;
        });
        
        return data;
    }

    depth.remove = function(selection) {
        selection.each(function(d) {
            d3.select(this).selectAll("svg").transition()
                .attr("height", 0).attr("width", 0).remove();
        });
    };

    depth.width = function(value) {
        if (!arguments.length) return width;
        width = value;
        return depth;
    };

    depth.height = function(value) {
        if (!arguments.length) return height;
        height = value;
        return depth;
    };

    depth.margin = function(value) {
        if (!arguments.length) return margin;
        margin = value;
        return depth;
    };

    depth.min = function(value) {
        if (!arguments.length) return min;
        min = value;
        return depth;
    };

    depth.max = function(value) {
        if (!arguments.length) return max;
        max = value;
        return depth;
    };

    depth.interpolate = function(value) {
        if (!arguments.length) return interpolate;
        interpolate = value;
        return depth;
    };
    
    depth.dispatch = function(value) {
		if(!arguments.length) return dispatch;
		dispatch = value;
		return depth;
    };

    return depth;
};
// this doesn't assume multiple lines in a chart
app.graphs.sparkline = function() {
	var height = 30,
		width = 800,
		max = 100,
		min = 0,
		margin = 2,
		dateFormat = d3.time.format("%x"),
		xScale = null,
		yScale = null,
		interpolate = "linear";

	function sparkline(selection) {
		selection.each(function(d) {
			d = d.values;

			var x = xScale ? xScale : d3.time.scale().domain(d.map(function(d) {
					return d.x;
				})),
				y = yScale ? yScale : d3.scale.linear().domain(d3.extent(d, function(d) {
					return d.y;
				}));

			x.range([margin, width - margin]);
			y.range([height - margin, margin]);

            // only one line per sparkline graph
			var line = d3.svg.line().x(function(d) {
				return x(d.x);
			}).y(function(d) {
				return y(d.y);
			}).interpolate(interpolate);

			var container = d3.select(this);

			var svg = container.selectAll("svg").data([0]);
			svg.enter().append("svg").attr("width", width).attr("height", height);

			var g = svg.selectAll("g").data([0]);
			g.enter().append("g");

			var path = g.selectAll(".graphs-line").data([d]);
			path.enter().append("path").attr("class", "graphs-line").attr("fill", "none").attr("stroke-width", "1").attr("stroke", "#08C");
			path.transition().attr("d", function(d) {
				return line(d);
			});
			
			// nick had wanted to change to add circles at each datapoint
			// he's added to the timeseries to do the reverse lookup in geodashboard
			// in timeseries, ther eis a separate function that could be extended to this if we want it later
			var dataPoints = g.selectAll(".graphs-dataPoint").data(d);
			dataPoints.enter().append("circle").attr("class", "graphs-dataPoint")
				.attr("r", 5).style("opacity", 0);
			dataPoints.attr("cx", function(d) { return x(d.x); }).attr("cy", function(d) { return y(d.y); });
			
			var clearText = g.selectAll(".graphs-clearText").data([0]);
			clearText.enter().append("text").attr("class", "graphs-clearText").attr("x", margin).attr("y", margin + 12);
			
			dataPoints
				.on("mouseover", function(d) {
					d3.select(this).style("opacity", 1);
					g.selectAll(".graphs-clearText").text(dateFormat(d.x) + ", " + d.y);
				})
				.on("mouseout", function(d) {
					d3.select(this).style("opacity", 0);
					g.selectAll(".graphs-clearText").text("");
				});

			// sparkline.exts.forEach(function(d) {
			// 	d.call(sparkline, svg);
			// });
		});
	}

	sparkline.height = function(value) {
		if (!arguments.length) return height;
		height = value;
		return sparkline;
	};

	sparkline.width = function(value) {
		if (!arguments.length) return width;
		width = value;
		return sparkline;
	};

	sparkline.interpolate = function(value) {
		if (!arguments.length) return interpolate;
		interpolate = value;
		return sparkline;
	};

	sparkline.margin = function(value) {
		if (!arguments.length) return margin;
		margin = value;
		return sparkline;
	};

	sparkline.max = function(value) {
		if (!arguments.length) return max;
		max = value;
		return sparkline;
	};

	sparkline.min = function(value) {
		if (!arguments.length) return min;
		min = value;
		return sparkline;
	};

	sparkline.x = function(value) {
		if (!arguments.length) return xScale;
		xScale = value;
		return sparkline;
	};

	sparkline.y = function(value) {
		if (!arguments.length) return yScale;
		yScale = value;
		return sparkline;
	};

	sparkline.ext = function(ext) {
		if (!sparkline.exts) sparkline.exts = [];

		sparkline.exts.push(ext);
	};

	if(sparkline.extensions) {
		sparkline.extensions.forEach(function(d) {
			d.call(sparkline);
		});
	}

	return sparkline;
};

app.graphs.sparkline.extend = function(extension) {
	if (!graphs.sparkline.extensions) graphs.sparkline.extensions = [];

	graphs.sparkline.extensions.push(extension);
};
// similar to the depth graph
// this can do multiple lines on a single graph

// testing  

app.graphs.timeSeries = function() {
	var width = 100, height = 100, // default values overwritten by functions below
		margin = { top: 0, right: 0, bottom: 0, left: 0 }, // default values
		padding = { top: 30, right: 30, bottom: 30, left: 60 }, // default values
		x = null, y = null, interpolate = "linear",
		min = 0, max = 10, xFormat = function(x) { return x; },
		yFormat = function(y) { return y; },
		sharedXAxis = true, sharedYAxis = true;
	
	function timeSeries(selection) {
		selection.each(function(data) {
		    // sanity checks to make sure we are getting real Dates
			data.values = data.values.map(function(e) {
				e.values = e.values.map(function(f) { f.x = new Date(f.x); f.y = +f.y; return f;})
					.sort(function(a, b) { return a.x - b.x; });
				return e;	
			});

			x = d3.time.scale().range([padding.left, width - padding.right]);
			y = d3.scale.linear().range([height - padding.bottom, padding.top]);
			
			var viz = d3.select(this);
			
			var svg = viz.selectAll("svg").data([data], function(d) { return d.key; });
			svg.enter().append("svg")
			  .attr("xmlns", "http://www.w3.org/2000/svg").attr("version", "1.1")
			  .attr("preserveAspectRatio", "none")
			  .attr("class", function(e) { return "graphs-time-series " + e.key; })
			  .attr("viewBox", "0 0 " + width + " " + height);
			  

			/* Plot */
			// creates a different plot for each line you might have in a datapoint
			// allows you to hvae different lines on the same chart
			// different from depth in that it allows point highlighting for each graphed element
			var arr = data.key.split(" ");
			
			var plotG = svg.selectAll(".graphs-plotG").data(function(e) { return e.values; });
			plotG.enter().append("g");
			  
			plotG.transition()
				.attr("class", function(f) { return "graphs-plotG " + f.key; })
                .style("color", function(f) { return f.color; })
                .style("stroke", function(f) { return f.color; })
                .style("fill", function(f) { return f.color; })
				.call(plots, arr[arr.length - 1]);

			plotG.exit().remove();
		});
	}
	
	function plots(selection, units) {
		selection.each(function(data, i) {
			var bisectDate = d3.bisector(function(d) { return d.x; }).left;
			// only show two digits for the point on the graph
			var valueFormat = d3.format(".2f");
			var dateFormat = d3.time.format("%Y-%m-%d");
			
			var plot = d3.select(this);

			// main title 
			var title = plot.selectAll(".graphs-title").data([data]);
			
			title.enter()
				.append("text")
				.attr("class", "graphs-title");

			title.transition()
				.attr("x", 70)
				.attr("y", 15)
				.style("text-anchor", "left")
				.text(function(d) { return _.isUndefined(d.title) ? d.key : d.title; });

			title.exit().remove();
			
			// X-Axis Label
			if(app.config.graphs.timeSeries.showUnits.graphXAxis)
			{
				var xAxisLabel = plot.selectAll(".graphs-xAxisLabel").data([data]);
				
				xAxisLabel.enter()
					.append("text")
					.attr("class", "graphs-xAxisLabel");
				
				xAxisLabel.transition()
					.style("text-anchor", "middle")
					.attr("x", 275)
					.attr("y", 247)
					.text("Date");
				
				xAxisLabel.exit().remove();
			}
			
			// source Label
			if(app.config.graphs.timeSeries.showSource && data.sources && data.sources.length > 0)
			{
				var sourceLabel = plot.selectAll(".graphs-sourceLabel").data([data]);

				sourceLabel.enter()
					.append("text")
					.text("Sources: ")
					.attr("class", "graphs-sourceLabel");
				sourceLabel.transition()
					.style("text-anchor", "end")
					.attr("x", 510)
					.attr("y", 25);
				sourceLabel.exit().remove();

				// TODO make sure with many sources it doesn't fall off the graph. Anchor to right.
				var sources;
				if (data.sources.length < 5) {
					sources = data.sources;
				} else {
					sources = data.sources.splice(0, 5);
					sources.push("...");
				}
				var sourceLabelIndex = sourceLabel.selectAll(".graphs-sourceLabelIndex").data(sources, function(d) { return(d); });
				sourceLabelIndex.enter()
					.append("a")
					.attr("xlink:href", function(d) { return d; })
					.attr("target", "clowder")
					.attr("class", "graphs-sourceLabelIndex")
					.text(function(d, i) { if (d == "...") { return d; } else { return "[" + (i + 1) + "]"; } })
					.append("title")
					.text("Original data source");
				sourceLabelIndex.exit().remove();
			}

			// Y-Axis Label
			if(app.config.graphs.timeSeries.showUnits.graphYAxis)
			{
				var yAxisLabel = plot.selectAll(".graphs-yAxisLabel").data([data]);
				
				yAxisLabel.enter()
					.append("text")
					.attr("class", "graphs-yAxisLabel");
				
				yAxisLabel.transition()
					.attr("transform", "rotate(-90)")
					.style("text-anchor", "middle")
					.attr("x", -110) // Moving up/down. + (up), - (down)
					.attr("y", 25) // Moving left/right. + (right), - (left)
					.text(function(d) { return d.unit; }); // Catch the undefined text
				
				yAxisLabel.exit().remove();
			}
			
			var x = d3.time.scale()
				.domain(data.xextent)
				.range([padding.left, width - padding.right]);
					
			var y = d3.scale.linear()
				.domain(data.yrange)
				.range([height - padding.bottom, padding.top]);
								
		    // background color
		    // TODO make sure to use enter/exit/remove to clean up when redrawing
		    var background = plot.selectAll(".graphs-background-rect").data([data.values]);
			background.enter()
			  .append("g")
			  .attr("class", "graphs-background")
			  .append("rect")
			  .attr("class", "graphs-background-rect")
			  .attr("transform", "translate(" + padding.left + ", " + padding.top + ")")
			  .attr("width", width - padding.left - padding.right)
			  .attr("height", height - padding.top - padding.bottom);

			// y axis before x axis so that y tick lines don't cover x axis
			// TODO there must be a better way
			var yAxisG = plot.selectAll(".graphs-y-axis").data([data.values]);
			
			yAxisG.enter()
				.append("g")
				.attr("class", "graphs-y-axis")
				.attr("transform", "translate(" + padding.left + ", 0)");
				
			yAxisG
				.transition()
				.call(d3.svg.axis()
					.scale(y)
					.orient("left")
					.ticks(5)
                    .tickSize(-width + padding.right + padding.left, 0, 5)
					.tickFormat(valueFormat));

			yAxisG.selectAll("text")
	          .attr("transform", function(d) {
	             return "translate(" + -5 + "," + 0 + ")";
	         });

			var xAxisG = plot.selectAll(".graphs-x-axis").data([data.values]);
			
			xAxisG.enter()
				.append("g")
				.attr("class", "graphs-x-axis");
			
			xAxisG
				.transition()
				.attr("transform", function(d) { return "translate(0, " + (height - padding.bottom ) + ")"; })
				.call(d3.svg.axis()
					.scale(x)
					.orient("bottom")
					.ticks(10)
					);

			// rotate labels at a 45 degree angle so that they don't overlap
			xAxisG.selectAll("text")
	          .attr("transform", function(d) {
	             return "translate(" + (this.getBBox().height*-1.5) + "," + this.getBBox().height + ")rotate(-45)";
	         });
				
			if (_.isUndefined(app.config.graphs.timeSeries['showLine']) || app.config.graphs.timeSeries['showLine'] == true) {
				var linePath = plot.selectAll(".graphs-line").data([data.values]);

				linePath.enter()
					.append("path")
					.attr("class", "graphs-line");

				linePath
					.transition()
					.attr("d",
					function(g) {
						return (d3.svg.line()
							.x(function(d) { return x(d.x); })
							.y(function(d) { return y(d.y); })
							.interpolate(interpolate))(g);
					}
				);

			}

			// Vertical Line on mouseOver
			//if(app.config.graphs.timeSeries.mouseOver.verticalLine)
			var mouseOverVerticalLine = plot.selectAll("graphs-mouseOverVerticalLine").data([data.values]);
			
			mouseOverVerticalLine.enter()
				.append("line")
				.attr("class", "graphs-mouseOverVerticalLine")
				.attr({
					"x1": 0,
					"y1": padding.top,
					"x2": 0,
					"y2": height - padding.bottom
				});
			
			mouseOverVerticalLine.exit().remove();
			
			// div shown with popup when mouse hovers over dot
			var popupDiv = d3.select('.graphs-tooltip').data([0]);
			popupDiv.enter()
				.append("div")
				.attr("class", "graphs-tooltip")
				.style("opacity", "0");
			popupDiv.exit().remove();

			// add little dots to the graph
			var dots = plot.selectAll('.graphs-dots').data(data.values);
			dots.enter()
				.append("path")
				.attr("class", "graphs-dots")
			dots
				.transition()
				.attr("transform", function(d) { return "translate(" + x(d.x) + "," + y(d.y) + ")"; })
				.attr("d", d3.svg.symbol().size(16));
			dots.exit().remove(); 

			var focusDot = plot.selectAll(".graphs-focus").data([0]);
			focusDot.enter()
				.append("circle")
				.attr("class", "graphs-focus");
			focusDot.append("circle");
			focusDot.exit().remove();

			// Mouse hover handling
			var rect = plot.selectAll(".graphs-listener-rect").data([data.values]);
			
			rect.enter()
				.append("rect")
				.attr("class", "graphs-listener-rect")
				.attr("transform", "translate(" + padding.left + ", " + padding.top + ")")
				.attr("width", width - padding.left - padding.right)
				.attr("height", height - padding.top - padding.bottom)
				.style("opacity", 0);
			rect.on("mouseout", function() {
				focusDot.transition().attr("r", "0");
				popupDiv.transition().style("opacity", 0);
				mouseOverVerticalLine.transition().style("opacity", 0);
			});
			rect.on("mouseover", function() {
				focusDot.transition().attr("r", "4.5");
				popupDiv.transition().style("opacity", 0.9);
				mouseOverVerticalLine.transition().style("opacity", 0.9);
			});
			rect.on("mousemove", mousemove);
				
			// handles the hovering over the graph and switching which datapoint is drawn on the map
			// give me the mouse's position, invert it
			// padding.left handles issue where rectangle is offset from the left padding of the svg
			// mouse position + graph padding + adjustments to accommodate
			// bisectDate function defined above: for data values, give me the index of nearest datapoint
			function mousemove() {
				var x0 = x.invert(d3.mouse(this)[0] + padding.left);
                var i = bisectDate(data.values, x0, 1);
                var d;
                if (i >= data.values.length) {
                	d = data.values[i - 1];
                } else {
	                var d0 = data.values[i - 1];
	                var d1 = data.values[i];
	                d = x0 - d0.x > d1.x - x0 ? d1 : d0;
                }

				var label = (d.label === undefined) ? dateFormat(d.x) : d.label;
				var value = valueFormat(d.y);
				
				var unit = "";
				if(app.config.graphs.timeSeries.showUnits.graphTooltip && data.unit)
				{
					unit = " " + data.unit;
				}
        
				mouseOverVerticalLine.attr("transform", function () { return "translate(" + x(d.x) + ",0)"; });

			    popupDiv.html("<b>Date</b>  : " + label + "<br/>" +
												"<b>Value</b> : "  + value + unit + " Avg.<br />")
			        .style("left", (this.getBoundingClientRect().left - padding.left + x(d.x)) + "px")     
			        .style("top", (this.getBoundingClientRect().top - padding.top + y(d.y)) + "px");
			    focusDot.attr("cx", x(d.x)).attr("cy", y(d.y));
			}
		});
	}

	timeSeries.width = function(value) {
		if(!arguments.length) return width;
		width = value;
		return timeSeries;
	};
	
	timeSeries.height = function(value) {
		if(!arguments.length) return height;
		height = value;
		return timeSeries;
	};
	
	timeSeries.margin = function(value) {
		if(!arguments.length) return margin;
		applyPadding(value.split(" "), margin);
		
		return timeSeries;
	};
	
	timeSeries.padding = function(value) {
		if(!arguments.length) return padding;
		applyPadding(value.split(" "), padding);
		
		return timeSeries;
	};
	
	timeSeries.min = function(value) {
		if(!arguments.length) return min;
		min = value;
		return timeSeries;
	};
	
	timeSeries.max = function(value) {
		if(!arguments.length) return max;
		max = value;
		return timeSeries;
	};
	
	timeSeries.x = function(value) {
		if(!arguments.length) return x;
		x = value;
		return timeSeries;
	};
	
	timeSeries.xFormat = function(value) {
		if(!arguments.length) return xFormat;
		xFormat = value;
		return timeSeries;
	};
	
	timeSeries.y = function(value) {
		if(!arguments.length) return y;
		y = value;
		return timeSeries;
	};
	
	timeSeries.yFormat = function(value) {
		if(!arguments.length) return yFormat;
		yFormat = value;
		return timeSeries;
	};
	
	timeSeries.sharedXAxis = function(value) {
		if(!arguments.length) return sharedXAxis;
		sharedXAxis = value;
		return timeSeries;
	};
	
	timeSeries.sharedYAxis = function(value) {
		if(!arguments.length) return sharedYAxis;
		sharedYAxis = value;
		return timeSeries;
	};
	
	timeSeries.interpolate = function(value) {
		if(!arguments.length) return interpolate;
		interpolate = value;
		return timeSeries;
	};
	
	function applyPadding(values, obj) {
		if(values[0]) {
			obj.top = obj.right = obj.bottom = obj.left = +values[0];
		}
		
		if(values[1]) {
			obj.right = obj.left = +values[1];
		}
		
		if(values[2]) {
			obj.bottom = +values[2];
		}
		
		if(values[3]) {
			obj.left = +values[3];
		}
	}

	return timeSeries;
};

// attach the event object to the app to ensure the object exists during the build process
app.event = {};
app.event.EventBus = _({}).extend(Backbone.Events);
app.router = {};
app.router.AppRouter = Backbone.Router.extend({
    
    routes : {
        "" : app.config.landingPage,
        "explore" : "home",
        "search" : "search",
        "compare" : "compare",
        "welcome": "welcome",
        "detail/location/:location(/startTime/:startTime/endTime/:endTime)(/parameters/:parameters)(/bin/:bin)(/depth/:depth)(/depthYear/:depthYear)(/depthBin/:depthBin)(/biologyStartTime/:biologyStartTime)(/biologyEndTime/:biologyEndTime)(/biologyBin/:biologyBin)(/)" : "populateDetailView",
        "about" : "about"
    },

    initialize: function() {
        var self = this;
        // on route changes update google analytics
        this.bind('route', this._pageView);

        // dynamically create a route listener for any "child views" specified in app.config
        _.each(app.config.views, function(view) {
          if (view.children) {
            _.each(view.children, function(childView) {
              if (childView.title && childView.link && childView.template) {
                var routeString = new RegExp('^' + view.link.replace('#', '') + '\/' + childView.link.replace('#', ''));
                self.route(routeString, childView.title.toLowerCase());
              }
            });
          }
        });
    },
    
    // split backbone and send information
    _pageView: function() {
        if (app.config.googleAnalytics != "") {
            var path = Backbone.history.getFragment();
            if (path.match(/^detail/)) {
                path = path.replace(/\/([^/]*)\/([^/]*)/g, '&$1=$2').replace(/&/, "?").replace(/\/$/, "");
            }
            ga('send', 'pageview', {page: "/" + path});
        }
    }
});

// attach the model object to the app to ensure the object exists during the build process
app.model = {};
app.model.Sensor = Backbone.Model.extend({
    keepId: true,
    defaults: {
        selectable: true,
        selected: false,
        checked: false,
        sourceSelected: false,
        sourceChecked: false,
        parameterSelected: false,
        parameterChecked: false,
        areaChecked: false,
        areaSelected: false
    },

    initialize: function() {
        this.on("change:sourceSelected", this.isSelected, this);
        this.on("change:sourceChecked", this.isChecked, this);
        this.on("change:areaChecked", this.isChecked, this);
        this.on("change:areaSelected", this.isSelected, this);
        this.on("change:parameterSelected", this.isSelected, this);
        this.on("change:parameterChecked", this.isChecked, this);
        this.on("change:checked", this.isSelected, this);
        this.on("change:selected", this.isSelected, this);
        this.on("change:parameters[*]", this.isParamSelected, this);
        this.on("change:parameters[*].checked", this.isParamChecked);
    },

    isParamSelected: function() {
        if (this.isParamSelectedProcessing) return;
        this.isParamSelectedProcessing = true;
        var params = this.get("parameters");
        var paramSelected = _.findWhere(params, {selected: true});
        if (paramSelected) {
            this.set("parameterSelected", true);
        }
        this.isParamSelectedProcessing = false;
    },

    isParamChecked: function(changed) {
        if (this.isParamCheckedProcessing) return;
        this.isParamCheckedProcessing = true;
        var params = this.get("parameters");
        var paramChecked = _.findWhere(params, {checked: true});
        if (paramChecked) {
            this.set("parameterChecked", true);
        }
        this.isParamCheckedProcessing = false;
    },

    isSelected: function() {
        if (this.isSelectedProcessing) return;
        this.isSelectedProcessing = true;
        if (this.get("sourceSelected") || this.get("parameterSelected") || this.get("areaSelected") || this.get("checked")) {
            this.set("selected", true);
        } else {
            this.set("selected", false);
        }
        this.isSelectedProcessing = false;
    },

    isChecked: function(changed) {
        if (this.isCheckedProcessing) return;
        this.isCheckedProcessing = true;
        // if a parameter gets checked, and a source is checked, but this sensor's source is not checked, uncheck it
        if ( (this.get("parameterChecked")) && ( (app.collection.sources.getChecked().length == 1) && (!this.get("sourceChecked")) )  ) {
            this.isCheckedProcessing = false;
            return this.set("checked", false);
        }
        if ( (app.collection.sources.getChecked().length == 1) && (this.get("sourceChecked")) ) {
            this.set("checked", true);
        } else if (this.get("sourceChecked") || this.get("parameterChecked") || this.get("areaChecked")) {
            this.set("checked", true);
        } else {
            this.set("checked", false);
        }
        this.isCheckedProcessing = false;
    },

    url: function() {
        if (_.isUndefined(this.id)) {
            return app.config.clowderUrl + '/api/geostreams/sensors';
        } else {
            return app.config.clowderUrl + '/api/geostreams/sensors/' + encodeURIComponent(this.id);
        }
    },

    // set is called after app.collection.sensors calls fetch, then calls parse.
    // set is given JSON objects for each of the sensors, and creates a Backbone model for each sensor.
    // We are checking the JSON object's "type" property (which is the Data Source, like "epa") and
    // ensuring that the Data Source already exists in app.collection.sources.
    set: function ( key, val, options ) {
        var self = this;
        var args, attrs, _attrs, geometry;
        args = arguments;

        // Handle both `"key", value` and `{key: value}` -style arguments.
        if ( typeof key === 'object' ) {
            attrs = key;
            options = val;
        }
        // Handle GeoJSON argument.
        if ( attrs && attrs['type'] && attrs['type'] === 'Feature' ) {
            _attrs = _.clone( attrs['properties'] ) || {};

            if (attrs.created) _attrs['created'] = attrs.created;
            if (attrs.name) _attrs['name'] = attrs.name;
            if (attrs.min_start_time) _attrs['min_start_time'] = attrs.min_start_time;
            if (attrs.max_end_time) _attrs['max_end_time'] = attrs.max_end_time;
            _attrs['selectable'] = true;
            _attrs['selected'] = false;
            _attrs['checked'] = false;
            _attrs['sourceSelected'] = false;
            _attrs['sourceChecked'] = false;
            _attrs['parameterSelected'] = false;
            _attrs['parameterChecked'] = false;
            _attrs['areaChecked'] = false;
            _attrs['areaSelected'] = false;

            if (_attrs['type'] && _attrs['type']['id']) {
                _attrs['type']['id'] = _attrs['type']['id'].toLowerCase().replace(/ /g, '-');
            }

            if (attrs.parameters) {

                // we create a new instance of app.collection.Parameters, inheriting the ability to be custom sorted
                // by defining a comparator in app.config.parameters.comparator in the project's 0config.js file
                _attrs['parameters'] = new app.collection.Parameters();
                _.each(attrs.parameters, function(parameterID) {
                    if (parameterID == null) return;
                    // if this parameterID matches a known parameter, we'll link them, otherwise we'll create a new parameter and link this sensor to it
                    // "alternates" is an array of possible spellings of that parameter

                    // find a parameter model for this parameterID, or see if it is listed as an alternate in any other parameter
                    var parameterModel = app.collection.parameters.find(function(model) {
                        return model.id == parameterID || _.contains(model.get("alternates"), parameterID);
                    });

                    // Only enable the next if/else when set in config
                    if (app.config.useExploreParams == true) {
                        if (parameterModel !== undefined) {
                            // here we're adding this sensor to an existing parameter model
                            // by telling it "merge: true" we'll add this sensor to any other sensors it already has
                            app.collection.parameters.add({id: parameterModel.id, sensors: self}, {merge: true});
                        } else {
                            console.log(_attrs['name'] + " has a new parameter that is not yet listed in config.js : " + parameterID);
                            /*RemoveLogging:skip*/
                            // here we're creating a new parameter model since the parameterID didn't match the ID of an existing parameter model
                            // and wasn't in any other parameters list of "alternates"
                            // we'll sanitize the ID, and if the sanitized version is different, we'll store that as it's alternate value so it can be found
                            parameterModel = app.collection.parameters.add({
                                id: parameterID.replace(/[^a-zA-Z0-9-_]/g, ''),
                                title: parameterID,
                                alternates: (parameterID == parameterID.replace(/[^a-zA-Z0-9-_]/g, '')) ? [] : [parameterID],
                                sensors: self
                            }, {merge: true});
                        }
                    }
                    // by pushing this parameterModel back onto "parameters", our sensor will have a reference to each parameter's model
                    _attrs.parameters.add(parameterModel);

                });
            }
            // Clone the geometry attribute.
            geometry = _.clone( attrs['geometry'] ) || null;
            if ( geometry ) {
                geometry.coordinates = geometry['coordinates'].slice();
            }
            _attrs['geometry'] = geometry;

            if ( attrs[this.idAttribute] ) {
                _attrs[this.idAttribute] = attrs[this.idAttribute];
            }
            args = [_attrs, options];
        }

        // this "finalizes" the Backbone model for this sensor
        var result = Backbone.Model.prototype.set.apply( this, args );

        // This next if statement associates a sensor's "source" (ie. "epa" for Environmental Protection Agency)
        // to a Backbone Model called a Source. We already use Source Models,
        // so we'll add this sensor to the source model to make the connection

        if (_attrs && _attrs.type && _attrs.type.id) {
            // ensure that a "source" model exists
            // since _attrs.type includes id and name, the add method can be used. "add" won't duplicate for the same id
            // 'source' is a single Data Source
            var source = app.collection.sources.add(_attrs.type);

            // assign the source's color to this sensor
            if (source.get('color')) {
                this.set('color', source.get('color'));
            }

            // Get all the sensorIDs for this source
            if (source.get('sensors')) {
                var sensorIDs = source.get('sensors');
                if (source.id == _attrs.type.id) {
                    sensorIDs.push(this.id);
                    source.set({'sensors': sensorIDs});
                }
            }
        }

        // This next if statement associates a sensor's "region" (ie. "Illinois")
        // to a Backbone Model called a Region. We already use Region Models,
        // so we'll add this sensor to the region model to make the connection

        if (_attrs && _attrs.region) {
            // ensure that a "region" model exists
            // add the region to the regions collection (or get the model if it already exists)
            var region = app.collection.regions.add({id: _attrs.region});

            // each region model maintains a Backbone Collection of sources
            if (! region.get('sources')) {
                region.set('sources', new Backbone.Collection);
            }

            region.get("sources").add(this.get('type'));
        }

        return result;

    },

    // The GeoJSON representation of a `Feature`.
    // http://www.geojson.org/geojson-spec.html#feature-objects
    // whenever the collection or model calls the toJSON() function, we manipulate the output
    // to suit our purposes. This allows us to completely alter what is stored in the "model" for a sensor
    // while still ensuring that a true GeoJSON object can be created from the model when needed
    toJSON: function ( options ) {
        var attrs, props, geometry;
        options = options || {};
        attrs = _.clone( this.attributes );
        props = _.omit( attrs, ['geometry', 'created', 'id']);
        // Add model cid to internal use.
        if ( options.cid ) {
            props.cid = this.cid;
        }
        // Clone the geometry attribute.
        geometry = _.clone( attrs['geometry'] ) || null;
        if ( geometry ) {
            geometry.coordinates = geometry['coordinates'].slice();
        }
        var json = {
            type: 'Feature',
            name: attrs.name,
            created: attrs.created,
            geometry: geometry,
            properties: props
        };
        if ( this.keepId ) {
            json[ this.idAttribute ] = this.id;
        }
        return json;
    }
});
// the GeoStreamService model interfaces with '/datapoints' on the API

// if we have already collected the datapoints from the API, the 'geostream' argument will not be empty, and subsequent page loads will not hit the API.
app.model.GeoStreamService = function(geostream, options) {
    this.geostream = geostream ? geostream : {};
    this.options = {};
    // set the API endpoint for this model
    this.options.url = app.config.clowderUrl + "/api/geostreams/datapoints?";
    this.options.urlTrend = app.config.clowderUrl + "/api/geostreams/datapoints/trends?";
    this.options.urlBins = app.config.clowderUrl + "/api/geostreams/datapoints/bin/";

    // lookup a datapoint by location
    this.getByLocation = function(location, callback) {
        // if we have this location in our cached results, return it
        if(this.geostream[location.id]) {
            callback(this.geostream[location.id]);
            return;
        } else {
          // this location is not in our cached results, so fetch from the API using id
          var query = this.options.url + $.param({sensor_id: location.id });
          $.ajax(query, {
              dataType: "jsonp",
              success: (function(geostream) {
                  return function(data) {
                      var cleanedData = cleanupData(data, location.id);

                      // keep a cached copy of the cleaned data
                      geostream[location.id] = cleanedData;
                      callback(cleanedData);
                  };
              })(this.geostream)
          });
        }
    };

    this.getTrend = function(parameter, season, callback){
        //We might need to add cached results here to help site responsiveness

        var binString;
        switch(app.config.binning.time) {
            case "decade":
                binString = "&decade=";
                break;
            case "lustrum":
                binString = "&lustrum=";
                break;
            case "year":
                binString = "&year=";
                break;
            case "semi":
            case "season":
                binString = "&semi=";
                break;
            case "month":
                binString = "&month=";
                break;
            default:
                binString = "";
        }

        season = season || '';

        var query = this.options.urlTrend + parameter  + binString + season;
        console.log(query);
        $.ajax(query, {
            dataType: "jsonp",
            success: function(geostream) {
                // return function(data) {
                var sensorResults = [];
                var parameterTitle = "";
                _.each(geostream, function(trend) {
                    var trendsObject = {};
                    var statsObject = {};
                    _.each(trend.properties, function(value, param) {                      
                      if (param == 'source') { return }
                      if (param.split(/_(.+)?/)[1]) statsObject[param.split(/_(.+)?/)[1]] = value;
                      var parameterModel = app.collection.parameters.find(function(model) {
                        return model.get("id") == param.split('_')[0];
                      });
                      if (parameterModel) {
                        parameterTitle = parameterModel.get('title').replace(/<(.*?)>/g, '');
                        if (parameterTitle) trendsObject[parameterTitle] = {'last_time': trend.last_time};
                      }
                    });
                    var sensor = app.collection.sensors.findWhere({id: +trend.sensor_id});
                    if (!_.isEmpty(statsObject)) {
                        $.extend( trendsObject[parameterTitle], statsObject );
                        var trends = sensor.get('trends');
                        if (trends) {
                            _.extend(trends, trendsObject);
                        } else {
                            sensor.set("trends", trendsObject);
                        }
                    }
                    sensorResults.push(sensor);

                });

                // keep a cached copy of the cleaned data
                //geostream[location.properties.name] = cleanedData;
                //callback(cleanedData);
                // };
                //app.event.eventBus.trigger("change:trends", sensorResults, parameterTitle);
                callback(sensorResults, parameterTitle);

            }

        });


    };
  // retrive binned datapoints
  this.getBinnedData = function(time, depth, sensor_id, cache, callback) {
    var query = this.options.urlBins + time + "/" + depth + "?" + $.param({sensor_id: sensor_id});
    console.log("Query for binned datapoints");
    // Check the cache for results for a sensor / bin
    if(this.geostream[sensor_id + time]) {
      callback(this.geostream[sensor_id + time]);
      return;
    } else {
      $.ajax(query, {
        dataType: "jsonp",
        success: (function(geostream) {
          return function(data) {
            if(cache) {
              geostream[sensor_id + time] = data;
            }
            callback(data);
          };
        })(this.geostream)
      });
    }
  };
};

// Given the data returned by clowder geostreams api this will
// reorganize the data. This will create a single object that
// represents a single reading.
// This can also bin multiple readings time wise, for example for
// SeaGrant this will combine multiple readings per year/season.
// [ {
//      year: 1999,
//      season: 'summer',
//      parameter: 'Chlorophyll a ug/l',
//      values: [ {
//         raw: [ 19.5, 20.1, 18.0, 19.8 ]
//         value: 77.4,
//         count: 4,
//         average: 19.35
//         depth: 0,
//         source: [ 'http://localhost:9001/clowder/XYZ' ]
//      }],
//      raw:
// } ]
//
// value is the sum of data
//
// This function asssumes that start/end date is the same and will
// only use the startTime returned!!!
function cleanupData(data, sensorID) {
    var cleanedData = [];

    // this.binningTime will be something like 'smart', 'semi', 'yearly', etc. It is how the datapoints
    // are averaged before being drawn in the graphs.
    // Projects can setup a filterFunction that accepts the current sensor (the Backbone Sensor Model)
    // as an argument. From there, you can return 'smart', 'semi', or some other binning value
    // based on a condition. For example: return (sensor.get('type')['id'] == 'epa') ? 'semi' : 'smart';
    // would return 'semi' as the binningTime for epa sensors, all others would use 'smart' binning
    var binningTime = "";
    if (app.config.binning.filterFunction) {
      binningTime = app.config.binning.filterFunction(app.collection.sensors.findWhere({name: sensorID}));
    } else if (app.config.binning.time) {
      binningTime = app.config.binning.time;
    } else {
      binningTime = 'smart';
    }

    data.forEach(function(d) {
        // convert returned date to javascript
        var start_time = new Date(d.start_time);

        // check if there is a source in the parameter list
        var source = d.properties.source;

        // check if there is a depth code in parameter list
        var depthcode = d.properties.DEPTH_CODE;
        if (_.isUndefined(depthcode)) depthcode="NA";
        
        // map all these to EP
        if (["SRF", "LEP", "TRM"].indexOf(depthcode) > -1) {
          depthcode = "EP";
        }

        // find the depth binning requirements
        var depth = app.config.binning.depth * Math.ceil(d.geometry.coordinates[2] / app.config.binning.depth);

        // extract the information for each parameter
        for (var k in d.properties) {
            // source is handled differently
            if (k == 'source') continue;

            // depth code is handled differently
            if (k == 'DEPTH_CODE') continue;

            // check the value and make sure it is a number
            var v = parseFloat(d.properties[k]);
            if (_.isNaN(v)) continue;

            // filter to be used to find entry
            var filter = {};

            // find the parameter
            var parr = app.collection.parameters.filter(function(x) {
                if (_.isUndefined(x.get("alternates"))) {
                    
                }
                return (x.id == k) || x.get("alternates").indexOf(k) >= 0;
            });
            if (parr.length == 0) {
                // Format the id of this parameter: "Chlorophyll-a, ug/l" becomes "chlorophyll-a-ug-l"
                var p = k.replace(/[^a-zA-Z0-9-]{1,2}/g, '-').toLowerCase();
                app.collection.parameters.add({
                    id: p,
                    title: k,
                    alternates: [k],
                    detailView: app.config.parameters.defaults.detailView
                });
                filter.parameter = k;
                filter.detailView = app.config.parameters.defaults.detailView;
            } else {
                filter.parameter = parr[0].id;
                filter.detailView = parr[0].get('detailView');
            }

            // find the time binning requirements
            filter.year = start_time.getUTCFullYear();
            filter.label = filter.year.toString();
            var date = new Date(filter.year, 7, 1, 0, 0, 0);
            if (binningTime == 'semi') {
                if (start_time.getUTCMonth() < 6) {
                    filter.bin = "spring";
                    date.setUTCMonth(4);
                } else {
                    filter.bin = "summer";
                    date.setUTCMonth(7);
                }
                filter.label = filter.label + " " + filter.bin;
            } else if (binningTime == 'season') {
                filter.bin = getSeason(start_time);
                filter.label = filter.label + " " + filter.bin;
                if (filter.bin == "winter") {
                    date.setUTCMonth(1);
                } else if (filter.bin == "spring") {
                    date.setUTCMonth(4);
                } else if (filter.bin == "summer") {
                    date.setUTCMonth(7);
                } else if (filter.bin == "fall") {
                    date.setUTCMonth(10);
                }
            } else {
                if (_.contains(['month', 'day', 'hour', 'minute', 'none'], binningTime)) {
                    filter.month = start_time.getUTCMonth();
                    filter.label = filter.label + "-" + (filter.month + 1).toString();
                    date.setUTCMonth(start_time.getUTCMonth());
                }
                // if binningTime is "none" we won't bin beyond the day level
                if (_.contains(['day', 'hour', 'minute', 'none'], binningTime)) {
                    filter.day = start_time.getUTCDate();
                    filter.label = filter.label + "-" + filter.day.toString();
                    date.setUTCDate(filter.day);

                }
                if (_.contains(['hour', 'minute', 'none'], binningTime)) {
                    filter.hour = start_time.getUTCHours();
                    filter.label = filter.label + " " + filter.hour.toString();
                    date.setUTCHours(filter.hour);
                }
                if (_.contains(['minute', 'none'], binningTime)) {
                    filter.minute = start_time.getUTCMinutes();
                    filter.label = filter.label + ":" + filter.minute.toString();
                    date.setUTCMinutes(filter.minute);
                }

            }

            // find the entry in cleanedData, if not found add it.
            var entry;
            if (filter.parameter in cleanedData) {
                entry = _.findWhere(cleanedData[filter.parameter], filter);
                if (_.isUndefined(entry)) {
                    entry = filter;
                    entry.values = [];
                    entry.date = date;
                    cleanedData[filter.parameter].push(entry);
                }
            } else {
                entry = filter;
                entry.values = [];
                entry.date = date;
                cleanedData[filter.parameter] = [entry];
            }

            // find the appropriate depth value, if not found add it.
            var depthval = _.findWhere(entry.values, {depth: depth, depthcode: depthcode});
            if (_.isUndefined(depthval)) {
                depthval = {
                    average: 0,
                    depth: depth,
                    depthcode: depthcode,
                    count: 0,
                    value: 0,
                    raw: [ ],
                    source: [ ]
                };
                entry.values.push(depthval);
            }

            // update the depth value and compute average
            depthval.count++;
            depthval.value += v;
            depthval.raw.push(v);
            depthval.average = depthval.value / depthval.count;

            // add source to depth value if not there already
            if (!_.isUndefined(source) && depthval.source.indexOf(source) == -1) {
                depthval.source.push(source);
            }
        }
    });

    return _.flatten(_.values(cleanedData));
}

// given a date this will return the associated season.
function getSeason(date) {
    if ((date.getUTCMonth() < 2) || (date.getUTCMonth() == 2 && date.getUTCDate() < 21)) {
        return 'winter';
    }
    if ((date.getUTCMonth() < 5) || (date.getUTCMonth() == 5 && date.getUTCDate() < 21)) {
        return 'spring';
    }
    if ((date.getUTCMonth() < 8) || (date.getUTCMonth() == 8 && date.getUTCDate() < 21)) {
        return 'summer';
    }
    if ((date.getUTCMonth() < 11) || (date.getUTCMonth() == 11 && date.getUTCDate() < 21)) {
        return 'fall';
    }
    return 'winter';
}



app.model.Area = Backbone.Model.extend({
    defaults: {
        sensors: new Backbone.Collection,
        markers: {},
        checked: false,
        selected: false
    },

    set: function ( key, val, options ) {
        var args, attrs, _attrs, geometry;
        args = arguments;

        // Handle both `"key", value` and `{key: value}` -style arguments.
        if ( typeof key === 'object' ) {
            attrs = key;
            options = val;
        }
        // Handle GeoJSON argument.
        if ( attrs && attrs['type'] && attrs['type'] === 'Feature' ) {
            _attrs = _.clone( attrs['properties'] ) || {};

            if (attrs.created) _attrs['created'] = attrs.created;
            if (attrs.name) _attrs['name'] = attrs.name;
            if (attrs.checked) _attrs['checked'] = attrs.checked;

            _attrs['selected'] = false;
            _attrs['sensors'] = new Backbone.Collection;

            // Clone the geometry attribute.
            geometry = _.clone( attrs['geometry'] ) || null;
            if ( geometry ) {
                geometry.coordinates = geometry['coordinates'].slice();
            }
            _attrs['geometry'] = geometry;

            if ( attrs[this.idAttribute] ) {
                _attrs[this.idAttribute] = attrs[this.idAttribute];
            }
            args = [_attrs, options];
        }

        return Backbone.Model.prototype.set.apply( this, args );
    },

    // since we are not using the api, we must override any api-type functions
    // or else backbone will try to hit the api and complain because no url exists for this model
    sync : function() { return null; },
    fetch : function() { return null; }

});
app.model.HucItem = Backbone.Model.extend({
    defaults: {
        title: false,
        checked: false,
        selected: false
    },

    initialize: function() {
        this.set('sensors', new Backbone.Collection);

    },

    // since we are not using the api, we must override any api-type functions
    // or else backbone will try to hit the api and complain because no url exists for this model
    sync : function() { return null; },
    fetch : function() { return null; }


});
app.model.Huc = Backbone.Model.extend({
    defaults: {
        title: false, // should be in the format of "huc2", "huc4", etc
        checked: false,
        selected: false
    },

    initialize: function() {
        this.set('items', new app.collection.HucItems);

    },

    // app.collection.hucs.findWhere({id: "huc2"}).groupByHUCSourcesSensors()
    // this creates a response that groups all huc regions in a group, ie, all the HUC2 regions
    // then in each HUC2 region (like Ohio 05), groups by source, then sensors
    groupByHUCSourcesSensors: function() {
        var response = new Backbone.Collection;
        this.get('items').each(function(huc) {
          var responseHucModel = response.add({id: huc.get('id'), title: huc.get('title')});
          responseHucModel.set('sources', new Backbone.Collection);
          huc.get('sensors').each(function(sensor) {
            var responseSource = responseHucModel.get('sources').add(sensor.get('type'));
            if (!responseSource.get('sensors')) {
              responseSource.set('sensors', new Backbone.Collection);
            }
            responseSource.get('sensors').add(sensor);
          });
        });
        return response;
    },

    // since we are not using the api, we must override any api-type functions
    // or else backbone will try to hit the api and complain because no url exists for this model
    sync : function() { return null; },
    fetch : function() { return null; }


});
app.model.Region = Backbone.Model.extend({
  defaults: {
    checked: false,
    selected: false,
    title: null
  },

  // since we are not using the api, we must override any api-type functions
  // or else backbone will try to hit the api and complain because no url exists for this model
  sync : function() { return null; },
  fetch : function() { return null; }


});
app.model.Parameter = Backbone.Model.extend({
    defaults: {
        sensors: [],
        markers: {},
        checked: false,
        selected: false,
        enabled: true,
        sourceChecked: false,
        detailView: app.config.parameters.defaults.detailView,
        searchView: app.config.parameters.defaults.searchView,
        exploreView: app.config.parameters.defaults.exploreView
    },
    // since we are not using the api, we must override any api-type functions
    // or else backbone will try to hit the api and complain because no url exists for this model
    sync : function() { return null; },
    fetch : function() { return null; },

    initialize: function() {
        var self = this;
        if (this.get('categories')) {
            _.each(this.get('categories'), function(cat) {
                var categoryModel = app.collection.parameterCategories.add({id: cat});
                if (!categoryModel.get('parameters')) {
                    categoryModel.set('parameters', new Backbone.Collection);
                }
                categoryModel.get('parameters').add(self);
            });
        }

        this.on("change:sensors[*].selected", this.isSelected, this);
        this.on("change:sensors[*].sourceChecked", this.isSourceChecked, this);
    },

    isSelected: function() {
        var sensors = this.get("sensors");

        var isSensorSelected = _.any(sensors.models, function(sensor) {
            return sensor.get("selected");
        });
        this.set("selected", isSensorSelected);

    },

    isSourceChecked: function() {
        // The scenario: on the search page, click an area, then click a source
        // The problem this fixes: the parameters that show up in the ResultsView should update to only show the parameters for the checked source
        // How we solve this:
        // 1. get all the sensors for this parameter
        // 2. ask the sensor if it's source is checked - because we set this value on the model
        // 3. Using underscore's "some" function, we will return true if any of this parameter's sensors have a checked source
        // 4. If true, we will set "sourceChecked" true on this parameter. The ResultsView will then update the list of parameters
        var sensors = this.get('sensors');
        var sensorsSourceChecked = _.some(sensors.models, function(sensor) {
            return sensor.get("sourceChecked");
        });

        if (sensorsSourceChecked) {
            this.set("sourceChecked", true);
        } else {
            this.set("sourceChecked", false);
        }
    },

    getSelectedSensors: function() {
        var that = this;
        var theSelectedSensors = app.collection.sensors.filter(function(e){
            if (e.attributes.type.id == that.id && e.attributes.selected == true) {
                return e;
            }
        });
        return theSelectedSensors;
    },

    getSelectableSensors: function() {
        var that = this;
        var theSelectableSensors = app.collection.sensors.filter(function(e){
            if ( e.attributes.selectable == true) {
                return e;
            }
        });
        return theSelectableSensors;
    },

    getCheckedSensors: function() {
        var that = this;
        var theCheckedSensors = app.collection.sensors.filter(function(e){
            if (e.attributes.type.id == that.id && e.attributes.checked == true) {
                return e;
            }
        });
        return theCheckedSensors;
    }

});
app.model.Source = Backbone.Model.extend({
    defaults: {
        sensors: [],
        regions: new Backbone.Collection,
        areas: [],
        markers: {},
        checked: false,
        selected: false
    },

    initialize: function(options) {
        if (this.id) {
            this.set('id', this.id.toLowerCase().replace(' ', '-'));
        }

        // this is defined in app.config.sources.parameters.description
        // and is used in source_modals.scala.html (called by ExploreSourcesView)
        if (options.parameters && options.parameters.description) {
            this.set('aboutParametersDescription', options.parameters.description);
        }

        // this is defined in app.config.sources.parameters.ids, and is used in ResultsView
        if (options.parameters && options.parameters.ids) {
            this.set('ParametersIDs', options.parameters.ids);
        }

        this.on("change:sensors[*].selected", this.isSelected, this);

        // if prettyName isn't defined, this is a new Data Source and it isn't listed in sources.json
        // convert the source's title to Proper Case, and set it as the prettyName.
        if (this.get('prettyName') == undefined) {
            var prettyName = this.get('title');
            prettyName = prettyName.replace(/\w\S*/g, function(txt){return txt.charAt(0).toUpperCase() + txt.substr(1).toLowerCase();});
            this.set("prettyName", prettyName);
        }
    },

    isSelected: function() {
        var sensors = this.get("sensors");

        var isSensorSelected = _.any(sensors.models, function(sensor) {
            return sensor.get("selected");
        });
        this.set("selected", isSensorSelected);

    },

    // since we are not using the api, we must override any api-type functions
    // or else backbone will try to hit the api and complain because no url exists for this model
    sync : function() { return null; },
    fetch : function() { return null; },

    // returns "selected" sensors for this source
    getSelectedSensors: function() {
        var that = this;
        var theSelectedSensors = app.collection.sensors.filter(function(e){
            if (e.attributes.type.id == that.id && e.attributes.selected == true) {
                return e;
            }
        });
        return theSelectedSensors;
    },

    // returns "selectable" sensors for this source
    getSelectableSensors: function() {
        var that = this;
        var theSelectableSensors = app.collection.sensors.filter(function(e){
            if (e.attributes.type.id == that.id && e.attributes.selectable == true) {
                return e;
            }
        });
        return theSelectableSensors;
    },

    getCheckedSensors: function() {
        var that = this;
        var theCheckedSensors = app.collection.sensors.filter(function(e){
            if (e.attributes.type.id == that.id && e.attributes.checked == true) {
                return e;
            }
        });
        return theCheckedSensors;
    },

    getColor: function() {
        if (!this.get('color')) {
            return "black";
        } else {
            return this.get('color');
        }
    }
});
app.model.Layer = Backbone.Model.extend({
    defaults: {
        markers: {},
        checked: false,
        initialized: false
    },

    initialize: function() {
      var self = this;
      _.each(this.get('properties'), function(value, key) {
          self.set(key, value);
      });
      this.set("layer", new L.TileLayer.WMS(this.get("wms"), {
          layers: this.get("id"),
          format: 'image/png',
          transparent: true,
          opacity: this.get("opacity")
      }));
      if (this.get("default") == "true") {
          this.set("checked", true);
      }
    }

});

app.collection.Sensors = Backbone.Collection.extend({
	url: app.config.clowderUrl + "/api/geostreams/sensors",
    model: app.model.Sensor,
    
    visible: function() {
        return this.where({ visible: true });
    },
    
    selected: function() {
        return this.where({ selected: true });
    },
    
    getSelectableSensors: function() {
        return this.where({ selectable: true });
    },

    getChecked: function() {
        return this.where({ checked: true });
    },

    getOrFetchStations: function(callback) {
        if (!this.models.length > 0) {
            this.fetch({
                success: function(collection) {
                    callback(collection);
                }
            });
        } else {
            // return "this" which refers to app.collection.sensors
            callback(this);
        }
    },
    
    getStationByName: function(name, callback) {
        this.getOrFetchStations((function(self) {
            return function(sensorsCollection) {
                // we could also use the following command, because we know that app.collection.sensors is populated now:
                // var station = app.collection.sensors.findWhere({name: name})

                var station = sensorsCollection.findWhere({name: name});
                if (station) {
                    callback(station.toJSON());
                } else {
                    callback(undefined);
                }
            }
        })(this));
    },

    uncheckAll: function() {
        _.each(this.models, function(sensor) {
            sensor.set({
                "sourceSelected" : false,
                "sourceChecked" : false,
                "areaChecked" : false,
                "areaSelected" : false,
                "parameterSelected" : false,
                "parameterChecked" : false,
                "checked" : false,
                "selected" : false,
                "selectable" : true
            });
        });
    },

    // parse isn't necessary here at all
    // parse happens after a collection fetch, and before saving each JSON object as a sensor model
    // but I left it in as a reminder in case we would ever want to "filter" our sensors
    // before they become sensor "models". ie: manipulate their structure, etc.
    parse: function(response) {
        return response;
    },
    
    // "select" is used by the draw tools to select sensors on the map.
    // if we use "fetch", all the sensors in the collection get reset, so "select" uses ajax 
    // and doesn't alter the collection
    select: function(params, callback) {
        $.ajax({
            url: this.url,
            dataType: "jsonp",
            data: $.param(params),
            success: function (sensors) {
                
                // anytime someone selects something on the map, we want to designate the sensors as "selectable" and all others as "unselectable"
                // here we are simply getting all known id's...
                var all = _.pluck(app.collection.sensors.toJSON(), 'id');
                // here we get the id's for the sensors selected on the map...
                var found = _.pluck(sensors, 'id');
                // and here we indicate which sensors were NOT selected on the map
                var disabledSensors = _.difference(all, found);
                
                // set "selectable" to false for all the sensors we didn't just select (since they are true by default)
                _.each(disabledSensors, function(disabledSensor) {
                    app.collection.sensors.findWhere({id: disabledSensor}).set({selectable: false, selected: false, areaChecked: false, sourceChecked: false, parameterChecked: false });
                });

                // at this point, the variable 'sensors' is the raw JSON of all our sensors returned from the API
                // however, when fetching this selection from the API, we only specified the coordinates.
                // If the user has already checked a Data Source or a Parameter, we should filter those out of what was returned from the API

                // let's check to see if a Data Source checkbox was already selected.
                // If so, we'll only include those and filter out the rest

                // this next function should return an array of Source models
                var selectedSources = app.collection.sources.getSourcesWithSensors().where({checked: true});
                // if the array contains more than one checked item, we'll proceed...
                if ( (selectedSources instanceof Array) && (selectedSources.length > 0) ) {
                    // we'll use the 'map' function to create an array of just the source ID's
                    selectedSources = _.map(selectedSources, function(source) {
                        return source.get('id');
                    });
                    // now we will update the sensors variable (remember that sensors was the raw data from the API)
                    // we'll use filter to only include the sensors that have one of the checked Data Sources in properties.type.id
                    sensors = _.filter(sensors, function(sensor) {
                        return (selectedSources.indexOf(sensor.properties.type.id) > -1);
                    });
                    // at this point, the sensors variable has been updated, removing any sensors where the Data Source was unchecked
                }

                // let's check to see if a parameter checkbox was already selected.
                // If so, we'll update our sensors variable that was returned from the API to only include those and filter out the rest

                // this next function should return an array of Parameter models
                var selectedParameters = app.collection.parameters.where({checked: true});
                // if the array contains more than one checked item, we'll proceed...
                if ( (selectedParameters instanceof Array) && (selectedParameters.length > 0) ) {
                    // we'll use 'map' to essentially reduce the parameter models to just the list of alternates
                    // and we wrap the map function in the 'flatten' function. This will give us one big array of all possible alternates
                    selectedParameters = _.flatten(_.map(selectedParameters, function(parameter) {
                        return parameter.get('alternates');
                    }));
                    // now we will update the sensors variable (remember that sensors was the raw data from the API)
                    // we'll use filter to only include the sensors that have one of the checked Parameters
                    sensors = _.filter(sensors, function(sensor) {
                        // since sensor.parameters is an array, and selectedParameters is an array, we'll use the "intersection" function.
                        // This will check if this sensor.parameters contains any of the parameters in selectedParameters,
                        // and if true, that sensor will remain in the "sensors" variable. All others will be removed.
                        return _.intersection(sensor.parameters, selectedParameters).length > 0;
                    });
                }

                // any sensor still in the sensors variable is going to be a "checked sensor"
                // we'll grab the sensor model for each, then assign the proper attributes
                // make sure that each sensor is both selectable and areaSelected
                _.each(sensors, function(sensor) {
                    var sensorModel = app.collection.sensors.findWhere({id: sensor.id});
                    sensorModel.set({
                        areaSelected: true,
                        selectable: true,
                        areaChecked: true
                    });
                });
                
                // we check if a callback function was passed so that we can perform some action after this complete
                // see SearchView.js
                if (typeof(callback) == 'function') {
                    callback(sensors);
                } else {
                    return sensors;
                }
                
            }
        });
        
    },

    groupByHUCcodeSourcesSensors: function(options) {
      var hucKey;
      var results = new Backbone.Collection;
      results.comparator = 'code';

      if (options.hucCode && ($.inArray(options.hucCode, [2,4,6,8]) > -1)) {
        hucKey = "huc" + options.hucCode;
      } else {
        console.warn("app.collection.sensors.groupByHUCcodeSourcesSensors(hucCode): hucCode argument is required.");
        return;
      }

      if (hucKey) {
        results['title'] = hucKey;
        // this.each refers to the collection. this.each will iterate all sensors
        this.each(function(sensor) {
          var huc = sensor.get('huc');
          if (huc[hucKey]) {
              var hucModel = results.add({id: huc[hucKey]['code'], code: huc[hucKey]['code'], title: huc[hucKey]['name']});
              hucModel.set('checked', true);
              if (! hucModel.get('sources')) {
                hucModel.set('sources', new Backbone.Collection);
              }
              var source = hucModel.get('sources').add(sensor.get('type'));
              if (! source.get('sensors')) {
                source.set('sensors', new Backbone.Collection);
              }
              source.get('sensors').add(sensor);
          }
        });
      }

      if (options.includedCodes) {
          return results.filter(function(sensor) {
              return _.contains(options.includedCodes, sensor.get('code'));
          });
      } else {
          return results;
      }

    }
});
// currently using this in the SearchView.js, but may further explore collections with other models
var Datapoints = Backbone.Collection.extend({
	url: app.config.clowderUrl + "/api/geostreams/datapoints"
});

app.datapoints = new Datapoints();
app.collection.Parameters = Backbone.Collection.extend({
    model: app.model.Parameter,

    // the comparator function is used to sort the collection
    // if you define a comparator function in app.config.parameters.comparator,
    // we will use that, otherwise it will sort by title
    comparator: function(model) {
        if (app.config.parameters && app.config.parameters.comparator &&
            _.isFunction(app.config.parameters.comparator)) {
            return app.config.parameters.comparator(model);
        } else {
            return model.get('title');
        }
    },

    // a url function is not defined since we are not using the api
    // url: app.config.clowderUrl + "/api/geostream/parameters"

    // convenience method to get only the visible parameters (for exploreView, searchView, etc)
    getVisible: function(view) {
        var options = {};
        view = view || 'exploreView';
        options[view] = 'visible';
        return this.where(options);
    },

    getChecked: function() {
        return this.where({checked: true});
    },

    uncheckAll: function() {
        this.each(function(model) {
            model.set("checked", false);
        });
    },
    groupByParametersSourcesSensors: function(collection) {
        // clone the entire parameters collection (or a passed collection)
        // into a new Backbone Collection called "response"
        // filter the collection only for visible parameters
        // we'll make modifications and return them, but won't alter the original collection
        collection = collection || this;
        var response = new Backbone.Collection(collection.clone().where({exploreView: 'visible'}));

        // for each parameter in the collection
        response.each(function(parameter) {
            // each parameter will look through it's sensors and keep a list of their sources
            // the "HucItems" collection uses a Collection -> Item -> Sensors structure that is
            // reusable here
            var sources = new app.collection.HucItems;

            // loop through each sensor for this parameter
            var theParameterSensors = [];
            if (parameter.get('sensors')) {

                var theSensors = app.collection.sensors;
                theSensors.filter(function(x){
                    x.attributes.parameters.forEach(function(y) {
                        if (parameter.id == y.id) {
                            theParameterSensors.push(x);
                        }
                    });
                    parameter.set({'sensors': theParameterSensors});
                });

            }
            if (parameter.get('sensors').length) {
                parameter.get('sensors').forEach(function (sensor) {

                    // if we call "add", it won't create a duplicate model for the source
                    var source = sources.add(sensor.get('type'));

                    // add this sensor to the source collection
                    source.get('sensors').add(sensor);

                });
            }
            // after looping through each parameter, add the sources collection as a property
            parameter.set('sources', sources);

        });

        return response;
    }
});
app.collection.Areas = Backbone.Collection.extend({
    model: app.model.Area,
    // a url function is not defined since we are not using the api
    // url: app.config.clowderUrl + "/api/geostream/areas"

    clearSelection: function() {
        _.each(this.models, function(area) {
            if (area.get('items')) {
                area.get('items').each(function(areaInGroup) {
                    areaInGroup.set({
                        selected: false,
                        checked: false
                    });
                });
            } else {
                area.set({
                    selected: false,
                    checked: false
                });
            }
        });
    },

    getChecked: function() {
        return this.where({checked: true});
    }

});


app.collection.HucItems = Backbone.Collection.extend({
    model: app.model.HucItem,
    // a url function is not defined since we are not using the api
    // url: app.config.clowderUrl + "/api/geostream/hucs"

    getChecked: function() {
        return this.where({checked: true});
    }

});


app.collection.Hucs = Backbone.Collection.extend({
    model: app.model.Huc,
    // a url function is not defined since we are not using the api
    // url: app.config.clowderUrl + "/api/geostream/hucs"

    getChecked: function() {
        return this.where({checked: true});
    }

});


app.collection.Regions = Backbone.Collection.extend({
  model: app.model.Region,
  // a url function is not defined since we are not using the api
  // url: app.config.clowderUrl + "/api/geostream/regions"

  getChecked: function() {
    return this.where({checked: true});
  },

  groupByRegionsParametersSensors: function() {
    var results = new Backbone.Collection;

    this.each(function(region) {
      var newRegion = results.add(region);
      var regionSensors = app.collection.sensors.where({region: region.id});
      _.each(regionSensors, function(sensor) {

        if (! newRegion.get('parameters')) {
          newRegion.set('parameters', new Backbone.Collection);
        }

        sensor.get('parameters').each(function(parameter){
          var newParameter = parameter.clone();
          newParameter.unset('sensors');

          var parameterSensors = parameter.get('sensors');
          parameterSensors = parameterSensors.where({region: region.id});

          newParameter.set('sensors', parameterSensors);
          newRegion.get('parameters').add(newParameter);
        });

      });
    });
    return results;
  },

  groupByRegionsSourcesSensors: function() {
    var results = new Backbone.Collection;

    this.each(function(region) {
      var newRegion = region.clone();
      var newRegionModel = results.add(newRegion);
      newRegionModel.get('sources').each(function(source) {
        source.set('sensors', new Backbone.Collection);
        var sourceSensors = app.collection.sensors.filter(function(sensor) {
          return sensor.get('type').id == source.id && sensor.get('region') == region.id;
        });
        source.get('sensors').add(sourceSensors);
      });
    });
    return results;
  }

});


app.collection.Sources = Backbone.Collection.extend({
    model: app.model.Source,
    comparator: 'id',
    // a url function is not defined since we are not using the api
    // url: app.config.clowderUrl + "/api/geostream/sources"

    getChecked: function() {
        return this.where({ checked: true });
    },

    // calling 'app.collection.sources.getColor(id)' will return a consistent color for each source
    getColor : function(source) {
        return source == "epa" ? "#0D71BA" :
            source == "usgs" ? "#39B54A" :
            source == "lec" ? "#4D6363" :
            source == "gsfmp" ? "#CC2128" :
            source == "iadn" ? "#F7941E" :
            "white";
    },

    // used by the Explore page. This goes through each source and returns the following:
    // Sources grouped by Areas, then Sensors. ie: [ epa: [ lake-superior: [ sensors: [ sensor1, sensor2...]]
    groupBySourcesAreasSensors: function(callback) {

        // we'll return an array of objects, one for each source
        var response = [];

        // "this" refers to the collection. this.each iterates over each source in app.collection.sources.
        this.each(function(source) {
            // build this source's object
            var sourceResponse = {};
            sourceResponse.id = source.get('id');
            sourceResponse.title = source.get('title');
            sourceResponse.prettyName = source.get('prettyName');
            sourceResponse.acronym = source.get('acronym');
            sourceResponse.description = source.get('description');
            sourceResponse.color = source.get('color');
            sourceResponse.areas = new Array(app.collection.sources.getSourcesWithSensors().length);

            // Filter the Sensors by Source
            var theSensors = app.collection.sensors.filter(function(x){return x.attributes.type.id == sourceResponse.id});
            theSensors.forEach(function(sensor) {
                var sensorRegion = sensor.get("region");
                if (sensorRegion) {
                    sensorRegion = sensorRegion.toLowerCase();
                    // get the Backbone model for this area
                    var areaModel = app.collection.areas.findWhere({ id: sensorRegion });
                    // if no Backbone model exists for this area (aka: the sensor's "region" property), create it
                    if (!areaModel) areaModel = app.collection.areas.add({id: sensorRegion, region: sensorRegion.toUpperCase(), title: sensorRegion.toUpperCase() });
                    var areaTitle = areaModel.get("title");
                    // foundArea must check to see if this area has already been found
                    // otherwise you'd get a huge array where each sensor recreated the area it was in
                    var foundArea = _.findWhere(sourceResponse.areas, { id: sensorRegion });

                    if (!foundArea) {
                        foundArea = { id: sensorRegion, title: areaTitle, sensors: [sensor.toJSON()]};
                        sourceResponse.areas.splice(areaModel.get('sortOrder'), 0, foundArea);
                    } else {
                        foundArea.sensors.push(sensor.toJSON());
                    }

                }

            });

            response.push(sourceResponse);
        });
        if (typeof callback == 'function') {
            callback(response);
        } else {
            return response;
        }
    },

    uncheckAll: function() {
        this.each(function(model) {
            model.set("checked", false);
        });
    },

    // get a unique list of all (non-ignored) parameters for the passed in source
    getParameters: function(source) {
        var parameters = [];
        if (source.get('sensors')) {
            source.get('sensors').each(function(sensor) {
                _.each(sensor.get('parameters'), function(parameter) {
                    if (parameter.get('id') != 'ignored') {
                        parameters.push(parameter);
                    }
                });
            });
        }
        return _.unique(parameters);
    },

    // maintain backwards compatibility of the original getAreas function
    getAreas: function(options) {
        return this.groupBySourcesAreasSensors(options);
    },

    getSourcesWithSensors: function(options) {
        var response = this.filter(function(source){
            return source.get('sensors') && source.get('sensors').length;
        });
        return new Backbone.Collection(response);
    }

});
app.collection.ParameterCategories = Backbone.Collection.extend({
    comparator: 'title',

    // a url function is not defined since we are not using the api
    // url: app.config.clowderUrl + "/api/geostream/parameterCategories"

    getChecked: function() {
        return this.where({checked: true});
    },

    uncheckAll: function() {
        this.each(function(model) {
            model.set("checked", false);
        });
    },

  groupByParameterCategoriesSourcesSensors: function() {
    // clone the entire parameters collection into a new Backbone Collection called "response"
    // filter the collection only for visible parameters
    // we'll make modifications and return them, but won't alter the original collection
    var response = this.clone();

    response.each(function(parameterCategory) {
      if (parameterCategory.get('parameters')) {
        parameterCategory.set('checked', true);
        var catResponse = app.collection.parameters.groupByParametersSourcesSensors(parameterCategory.get('parameters'));
        if (catResponse.get('sources') && catResponse.get('sources').length) {
          parameterCategory.set('parameters', catResponse);
        }

      }
    });

    response = response.filter(function(category) {
      return category.get('parameters') && category.get('parameters').find(function(param) {
          return param.get('sources') && param.get('sources').length && param.get('sources').find(function(source) {
              return source.get('sensors') && source.get('sensors').length;
            });
        });
    });

    return response;
  }
});
app.collection.Layers = Backbone.Collection.extend({
    model: app.model.Layer,
    // a url function is not defined since we are not using the api
    // url: app.clowderUrl + "/api/geostream/areas"


    clearSelection: function() {
        _.each(this.models, function(layer) {
            layer.set("checked", false);
        });
    }


});
app.view = app.view || {};

Backbone.View.prototype.close = function(){
  this.remove();
  this.unbind();
  if (this.onClose){
    this.onClose();
  }
}

function getBinningDesignators(value) {
    switch(value) {
        case "season":
            return {
                title: "Season",
                items: [
                    { id: 'spring', name: 'Spring' },
                    { id: 'summer', name: 'Summer' },
                    { id: 'fall', name: 'Fall' },
                    { id: 'winter', name: 'Winter' }
                 ]
            };
            break;
        case "semi":
        case "semi-year":
        case "semi-annually":
            return {
                title: "Season",
                items: [
                    { id: 'spring', name: 'Spring' },
                    { id: 'summer', name: 'Summer' }
                ]
            };
            break;
        case "monthly":
            return {
                title: "Month",
                items: [
                    {id: 'jan', name: 'January'},
                    {id: 'feb', name: 'February'},
                    {id: 'mar', name: 'March'},
                    {id: 'apr', name: 'April'},
                    {id: 'may', name: 'May'},
                    {id: 'jun', name: 'June'},
                    {id: 'jul', name: 'July'},
                    {id: 'aug', name: 'August'},
                    {id: 'sep', name: 'September'},
                    {id: 'oct', name: 'October'},
                    {id: 'nov', name: 'November'},
                    {id: 'dec', name: 'December'}
                ]
            };
            break;
        default:
            return {title: "Bin", items: []};
            break;
    }
}
app.view.AppView = Backbone.View.extend({
    el : "#appContainer",

    events : {
        "click #header-go-home" : "goHome"
    },

    initialize : function() {

        this.genericSpinner = {
            // spinner specific settings //
            lines: 12, // The number of lines to draw
            length: 60, // The length of each line
            width: 20, // The line thickness
            radius: 40, // The radius of the inner circle
            corners: 1, // Corner roundness (0..1)
            rotate: 0, // The rotation offset
            direction: 1, // 1: clockwise, -1: counterclockwise
            color: '#000000', // #rgb or #rrggbb or array of colors
            speed: 1.2, // Rounds per second
            trail: 80, // Afterglow percentage
            shadow: true, // Whether to render a shadow
            // spinner page settings //
            className: 'generic_spinner', // The CSS class to assign to the spinner
            zIndex: 2e9, // The z-index (defaults to 2000000000)
            top: '50%', // Top position relative to parent
            left: '50%', // Left position relative to parent
            position: 'fixed' // Element positioning
        };

        var self = this;
        this.router = app.router.router = new app.router.AppRouter();

        this.eventBus = app.event.eventBus = _({}).extend(Backbone.Events);

        // compile the map pin, used in HomeView and DetailView
        this.mapPin = _.template($('#map-pin-template').html())();

        this.geoStreamService = app.model.geoStreamService = new app.model.GeoStreamService();

        this.currentView = null;

        $('meta[name="keywords"]').attr('content', app.config.metadata.keywords);
        $('meta[name="description"]').attr('content', app.config.metadata.description);
        $('meta[property="og:title"]').attr('content', app.config.metadata.title);
        $('meta[property="og:description"]').attr('content', app.config.metadata.description);
        $('meta[property="og:url"]').attr('content', app.config.metadata.url);
        $('meta[name="twitter:title"]').attr('content', app.config.metadata.title);
        $('meta[name="twitter:description"]').attr('content', app.config.metadata.description);
        $('meta[name="twitter:url"]').attr('content', app.config.metadata.url);

        app.collection.areas = new app.collection.Areas();
        app.collection.regions = new app.collection.Regions();
        app.collection.hucs = new app.collection.Hucs();
        app.collection.sources = new app.collection.Sources();
        app.collection.parameterCategories = new app.collection.ParameterCategories();
        app.collection.parameters = new app.collection.Parameters();
        app.collection.sensors = new app.collection.Sensors();
        app.collection.layers = new app.collection.Layers();
        app.collection.glossary = new Backbone.Collection();

        if (app.config.areas) {
            if (app.config.areas.groups) {
                app.collection.areas = new app.collection.Areas();
                _.each(app.config.areas.groups, function(areaGroup) {
                    app.collection.areas.add(
                        {
                            id: areaGroup.title.toLowerCase().replace(/ /g, '-'),
                            title: areaGroup.title,
                            items: new app.collection.Areas(areaGroup.items)
                        }
                    );
                });
            } else if (app.config.areas.items) {
                _.each(app.config.areas.items, function(area) {
                    app.collection.areas.add(area);
                });
            }

        }

        if (app.config.parameters && app.config.parameters.items) {
            _.each(app.config.parameters.items, function(parameter) {
                app.collection.parameters.add(parameter, {merge: true});
            });
        }

        if (app.config.parameters.categories) {
            _.each(app.config.parameters.categories, function(category) {
                app.collection.parameterCategories.add(category);
            });
        }

        if (app.config.sources && app.config.sources.items) {
            _.each(app.config.sources.items, function(source) {
                app.collection.sources.add(source);
            });
        }

        if (app.config.sensors && app.config.sensors.items) {
            _.each(app.config.sensors.items, function(sensor) {
                app.collection.sensors.add(sensor);
            });
        }

        if (app.config.layers && app.config.layers.items) {
            _.each(app.config.layers.items, function(layer) {
                app.collection.layers.add(layer);
            });
        }

        if (app.config.glossary && app.config.glossary.items) {
            _.each(app.config.glossary.items, function(item){
                app.collection.glossary.add(item);
            });
        }

        // update all views when new data gets in
        app.collection.sensors.fetch({
            dataType: "jsonp",
            success: function(data) {
                app.event.eventBus.trigger("sensors:refresh");
                return data;
            }
        });

        // if a view in app.config contains an array of "children" pages, setup route listeners
        _.each(app.config.views, function(view) {
            if (view.children) {
                _.each(view.children, function(childView) {
                    if (childView.title && childView.link && childView.template) {
                        if (!childView.view) childView.view = 'PageView';
                        self.router.on("route:" + childView.title.toLowerCase(), (function(self) {
                            return function() {
                                document.title = app.config.title + " - " + childView.title;
                                $("ul.navbar > li").removeClass("active");
                                $("a[href='" + view.link + "']").parent().addClass("active");
                                if(!app.view[childView.title.toLowerCase() + "View"]) {
                                    app.view[childView.title.toLowerCase() + "View"] = new app.view[childView.view](childView);
                                }

                                self.setView(app.view[childView.title.toLowerCase() + "View"]);
                                self.render();
                            }
                        })(self));
                    }
                });
            }
        });

        if (app.config.views.about && app.config.views.about.title && app.config.views.about.link) {
            this.router.on("route:about", (function (self) {
                return function () {
                    document.title = app.config.title + " - " + app.config.views.about.title;
                    $("ul.navbar > li").removeClass("active");
                    $("a[href='" + app.config.views.about.link + "']").parent().addClass("active");
                    self.initializeAboutView();
                    self.render();
                };
            })(this));
        }

        if (app.config.views.welcome && app.config.views.welcome.title && app.config.views.welcome.link) {
            this.router.on("route:welcome", (function (self) {
                return function () {
                    document.title = app.config.title + " - " + app.config.views.welcome.title;
                    $("ul.navbar > li").removeClass("active");
                    $("a[href='" + app.config.views.welcome.link + "']").parent().addClass("active");
                    self.initializeWelcomeView();
                    self.render();
                };
            })(this));
        }

        if (app.config.views.compare && app.config.views.compare.title && app.config.views.compare.link) {
            this.router.on("route:compare", (function(self) {
                return function() {
                    document.title = app.config.title + " - " + app.config.views.compare.title;
                    $("ul.navbar > li").removeClass("active");
                    $("a[href='" + app.config.views.compare.link + "']").parent().addClass("active");
                    self.initializeCompareView();
                    self.render();
                };
            })(this));

            app.collection.parameterBins = new Backbone.Collection();

            // always sort parameter alphabetically in the dropdowns
            app.collection.compareSelectedParameters = new Backbone.Collection();
            app.collection.compareSelectedParameters.comparator = 'title';

            // sort dates by id so they are in order by time
            app.collection.compareSelectedDates = new Backbone.Collection();
            app.collection.compareSelectedDates.comparator = 'id';
        }


        // on route:home, set currentView to the HomeView
        this.router.on("route:home", (function(self) {
            return function() {
                document.title = app.config.title;
                $("ul.navbar > li").removeClass("active");
                $("a[href='" + (app.config.views.home.link || "#explore") + "']").parent().addClass("active");
                self.initializeHomeView();
                self.render();
            };
        })(this));

        this.router.on("route:populateDetailView", (function(self) {
            return function(location, startTime, endTime, parameters, season, depth, depthYear, depthSeason, biologyStartTime, biologyEndTime, biologyBin) {
                document.title = app.config.title + " - Details";
                self.initializeDetailView(location, startTime, endTime, parameters, season, depth, depthYear, depthSeason, biologyStartTime, biologyEndTime, biologyBin);
            };
        })(this));

        this.router.on("route:search", (function(self) {
            return function() {
                document.title = app.config.title + " - " + (app.config.views.search.title || "Search");
                $("ul.navbar > li").removeClass("active");
                $("a[href='" + (app.config.views.search.link || "#search") + "']").parent().addClass("active");
                self.initializeSearchView();
                self.render();
            };
        })(this));

        // catch event fired by explore-pill or map-pin clicks
        // use this to fire the detail page route.
        this.eventBus.bind("change:location", (function(self) {
            return function(location) {
                var loc = "location/" + location + "/";
                self.router.navigate("detail/" + loc, {trigger : true, replace : false});
            };
        })(this));

        this.footerView = new app.view.FooterView({config: app.config.views.footer});
        this.navBarView = new app.view.NavBarView().render();

        // get the config
        $.get(app.config.clowderUrl + "/api/geostreams/config", function(data) {
            _.extend(app.config, data);
        });

        Backbone.history.start();
    },

    render : function() {
        if(this.currentView) this.currentView.render();
    },


    goHome : function() {
        this.router.navigate("", {trigger : true, replace : true});
    },

    // handles changing the current view.
    setView : function(view) {
        // if the new view is not the current view.
        if(this.currentView !== view) {
            // detach (preserves event listeners) the current view from the DOM
            if(this.currentView) this.currentView.$el.detach();
            this.currentView = view;
            this.$("#content-container")
                .append(this.currentView.el); // append the new view.
        }
//      this.render();
    },

    initializeHomeView : function() {
        if(!app.view.homeView) {
            app.view.homeView = new app.view.HomeView({
                config: app.config.views.home
            });
        }

        this.setView(app.view.homeView);

        // Add spinner immediately
        this.$el.spinner = new Spinner(this.genericSpinner).spin(this.el);

        // Need a local copy of this to work properly
        var that = this;

        // Check the page readyState value every second until the if clause is true
        var checkPageState;
        checkPageState= setInterval(function() {
            if (document.readyState == 'complete') {

                // Remove the Spinner only when the page is finished rendering
                that.$el.spinner.stop();

                // Stop checking every second
                clearInterval(checkPageState);

            }
        }, 1000);
    },

    initializeDetailView : function() {
        // create the DetailView if is doesn't exist,
        // or if the existing detailView doesn't match the ID of the location we want
        if(!this.detailView || this.detailView.locationID != arguments[0]) {
            this.detailView = new app.view.DetailView({
                parentView : this,
                eventBus : this.eventBus,
                mapPin : this.mapPin,
                router : this.router,
                stationService : this.stationService,
                geostreamService : this.geoStreamService,
                arguments: arguments,
                attributes: app.config.views.detail.attributes,
                config: app.config.views.detail
            });
        }

        // call the function to set up the view.
        this.setView(this.detailView);
        this.detailView.initiate.apply(this.detailView, arguments);
    },

    initializeSearchView : function() {
        if (!app.view.searchView) {
            app.view.searchView = new app.view.SearchView({
                parentView : this,
                eventBus : this.eventBus,
                router : this.router,
                stationService : this.stationService,
                geostreamService : this.geoStreamService,
                attributes: app.config.views.search.attributes,
                config: app.config.views.search
            });
        }

        this.setView(app.view.searchView);
    },

    initializeAboutView : function() {
        if(!app.view.aboutView) {
            app.view.aboutView = new app.view.AboutView(app.config.views.about);
        }

        this.setView(app.view.aboutView);
    },

    initializeWelcomeView : function() {
        if(!app.view.welcomeView) {
            app.view.welcomeView = new app.view.WelcomeView(app.config.views.welcomeView);
        }

        this.setView(app.view.welcomeView);

        // Add spinner immediately
        this.$el.spinner = new Spinner(this.genericSpinner).spin(this.el);

        // Need a local copy of this to work properly
        var that = this;

        // Check the page readyState value every second until the if clause is true
        var checkPageState;
        checkPageState= setInterval(function() {
            if (document.readyState == 'complete') {

                // Remove the Spinner only when the page is finished rendering
                that.$el.spinner.stop();

                // Stop checking every second
                clearInterval(checkPageState);

            }
        }, 1000);
    },

    initializeCompareView : function() {
        if(!app.view.compareView) {
            app.view.compareView = new app.view.CompareView({
            });
        }

        this.setView(app.view.compareView);
    }
});
/* 
 * Handles the controls on the detail page.
 * Specifically covers the parameters checkboxes and the date slider.
 * Does not properly map to a single div within the DetailView because
 * of the way the tabs are setup in the page.
 */
app.view.ControlsView = Backbone.View.extend({
    attributes: function() {
        return {
            tagName: this.options.attributes.tagName,
            id: this.options.attributes.id
        }
    },

	events : {
		'change #times' : 'changeTime'
	},
	
	initialize : function(options) {
        this.config = options;
        _.bindAll(this, "renderSeasonSelect");
	    this.eventBus = options.eventBus || app.event.eventBus;
        this.eventBus.on("locationUpdated", this.location(arguments));
        this.eventBus.on("renderSeasonSelect", this.renderSeasonSelect);
	  
        this.parametersID = options.parametersID || null;
        this.binDropdown = options.binDropdown || null;
        this.sliderID = options.sliderID || null;
        this.dateRangeID = options.dateRangeID || null;
        this.yearFormID = options.yearFormID || null;
        this.yearSelectID = options.yearSelectID || null;
        this.name = options.name || null;

        this.render = _.bind(this.render, this);
	},
	
	/*
	 * This blog: http://ianstormtaylor.com/break-apart-your-backbonejs-render-methods/
	 * recommended making the render functions return 'this' to make them chainable.
	 * I only got around to applying it here.
	 */
	render : function() {
		this.renderParameters(this.parameters)
			.renderSlider(this.times)
			.renderSeasonSelect();
	},

	// uses a d3 paradigm to avoid reconstructing the slider every time a
	// dimension changes. Allows the same function to handle a change to the
	// dimensions and also create the slider from scratch if it hasn't been
	// initialized yet.
	renderSlider : function(times, location, updateUrl) {
        if (!this.sliderID) return;
		var $slider = d3.select("#" + this.sliderID);

		var data = { items: times, location: location, updateUrl: updateUrl};

        var instance = $slider.selectAll(".instance").data([data], function(d) { return d.location; });
        instance.enter().append("div").attr("class", "instance")
        .call((function (self) {
            return function(selection) {
                selection.each(function(d) {
                    $(this).slider({
                        range : true,
                        step : 1,
                        values : [0, d.items.length - 1],
                        min : 0,
                        max : d.items.length - 1,
                        change : function(event, ui) {
                            var updateUrl = false;
                            if(event.originalEvent){
                                updateUrl = true;
                            }
                            var values = ui.values;
                            self.changeTimes(values[0], values[1], updateUrl);
                        },
                        create : function(event, ui) {
                            self.changeTimes(0, d.items.length - 1, d.updateUrl);
                        },
                        slide: function(event, ui) {
                            var values = ui.values;
                            self.sliderTimes(self.times[values[0]], self.times[values[1]]);
                        }
                    });
                });
            };
        })(this));

        instance.exit().remove();
		
		return this;
	},
	
	// uses a d3 paradigm to avoid reconstructing the parameter checkboxes every
  // time a dimension changes. Allows the same function to handle a change to
  // the dimensions and also create the checkboxes from scratch if they
  // haven't been initialized yet.
	renderParameters : function(parameters, selected, location, colors) {
        if (!this.parametersID) return;
        var parametersID = this.parametersID;
        var $parameters = d3.selectAll("#" + parametersID);

        var data = parameters.map(function(d) {
            var parameterModel = app.collection.parameters.findWhere({id: d});
            if (parameterModel) {
                return { parameter: parameterModel, location: location, color: colors(d) };
            }
        });
        
        var controlGroup = $parameters.selectAll(".control-group").data(data, function(d) { return d.location + "." + d.parameter.id; });
        controlGroup.enter().append("div").attr("class", "control-group");
        controlGroup.exit().remove();

        var controls = controlGroup.selectAll(".controls").data(function(d) { return [d]; });
        controls.enter().append("div").attr("class", "controls");

        var input = controls.selectAll("input").data(function(d) { return [d]; });

        var controlLabel = controlGroup.selectAll(".control-label-parameters").data(function(d) { return [d]; });
        controlLabel.enter().append("label");
        controlLabel.attr("class", function(d) { return "control-label-parameters " + d.parameter.id; })
            .style("color", function(d) { return d.color; })
            .attr("for", function(d) { return d.parameter.id; }).html(function(d) {
              var parameterWithUnit = d.parameter.get('title');
              if (d.parameter.get('unit') && d.parameter.get('unit').length) {
                  parameterWithUnit += " <small>(";
                  parameterWithUnit += d.parameter.get('unit');
                  parameterWithUnit += ")</small>";
              }
              return parameterWithUnit;
          }); //TODO: hack to display Chl a with an italic a. fix this with parameter name mapping
            
        input.enter().append("input").attr("type", "checkbox").attr("name", "parameter")
            .property("checked", function(d, i) { if(selected) return selected.filter(function(e) { return e === d.parameter.id; } ).length === 0 ? null : true; })
            .attr("id", function(d) { return d.parameter.id; }).attr("value", function(d) { return d.parameter.get('title'); })
            .on("click", (function(self) {
                return function() {
                    self.changeParameters();
                }
            })(this));
		return this;
	},

    renderSeasonSelect : function() {
    if (!this.binDropdown) return;
    if (this.binDropdown && this.binDropdown.filterFunction && this.binDropdown.sensor) {
      if (!this.binDropdown.filterFunction(this.binDropdown.sensor)) {
        return;
      }
    }
    var data = getBinningDesignators(app.config.binning.time) || { title: "Season", items: [{ id: "spring", name: "Spring"}, { id: "summer", name: "Summer" }]};

      var seasonForm = d3.select("#" + this.binDropdown.seasonFormID);

	  var controlGroup = seasonForm.selectAll(".control-group").data([data.items]);
	  controlGroup.enter().append("div").attr("class", "control-group");
	  controlGroup.exit().remove();
	  
	  var label = controlGroup.selectAll(".control-label-season").data(function(d) { return [d]; });
	  label.enter().append("label").attr("class", "control-label-season").attr("for", this.binDropdown.seasonSelectID).html(data.title);
	  label.exit().remove();
	  
	  var controls = controlGroup.selectAll(".controls").data(function(d) { return [d]; });
	  controls.enter().append("div").attr("class", "controls");
	  controls.exit().remove();

	  var select = controls.selectAll("#" + this.binDropdown.seasonSelectID).data(function(d) { return [d]; });
	  select.enter().append("select").attr("id", this.binDropdown.seasonSelectID).attr("class", "input-season-select")
	    .on("change", (function(self) {
	      return function() {
	        self.changeSeason();
	      }
	    })(this));
	  select.exit().remove();
	  
	  var options = select.selectAll("option").data(function(d) { return d; });
	  options.enter().append("option").attr("value", function(d) { return d.id; }).html(function(d) { return d.name; })
	  options.exit().remove();
	  
	  return this;
	},

    renderYearSelect : function(times, that) {
        if (!that.yearFormID) return;
        // get the unique years. It gives us a list like: 1998, 1999, 2000...
        var data = _.uniq(_.map(times, function(time) {
                var year = new Date(time);
                return year.getUTCFullYear();
        }));
        var yearForm = d3.select("#" + this.yearFormID);

        var controlGroup = yearForm.selectAll(".control-group").data([data]);
        controlGroup.enter().append("div").attr("class", "control-group");
        controlGroup.exit().remove();

        var label = controlGroup.selectAll(".control-label-year").data(function(d) { return [d]; });
        label.enter().append("label").attr("class", "control-label-year").attr("for", this.yearSelectID).html("Year");
        label.exit().remove();

        var controls = controlGroup.selectAll(".controls").data(function(d) { return [d]; });
        controls.enter().append("div").attr("class", "controls");
        controls.exit().remove();

        var select = controls.selectAll("#" + this.yearSelectID).data(function(d) { return [d]; });
        select.enter().append("select").attr("id", this.yearSelectID).attr("class", "input-year-select")
            .on("change", (function(self) {
                return function() {
                    self.changeYear();
                }
            })(this));
        select.exit().remove();

        var options = select.selectAll("option").data(function(d) { return d; }, function(d) { return d; });
        options.enter().append("option").attr("value", function(d) { return d; }).html(function(d) { return d; });
        options.exit().remove();
        options.order();

        this.year = $("#" + this.yearSelectID).val();

        return this;
    },

    setParameters : function(parameters, selected, colors) {
        this.parameters = parameters;
        var selectedFound = selected || this.getSelectedParameters();
        this.renderParameters(parameters, selectedFound, this.location(), colors);
    },

    setTimes : function(times, updateUrl) {
        this.startTime = times[0];
        this.endTime = times[times.length - 1];
        this.times = times;
        this.renderSlider(times, this.location(), updateUrl) ;
        this.renderSeasonSelect();
    },

    updateTimes: function(start, end){
	    this.startTime = start.toUTCString();
	    this.endTime = end.toUTCString();
	    var $slider = $("#" + this.sliderID + " .instance");
        $slider.slider( "option", 'values', [this.times.indexOf(this.startTime), this.times.indexOf(this.endTime)]);
    },

    setYears: function(years) {
        this.renderYearSelect(years, this);
    },

    // the location is used by the d3 selections to determine if the controls
    // need to be repopulated.
    location : function(location, season) {
        if(!location) return this.loc;

        this.loc = location + (season || "");
    },


    // sets the time range next to the slider.
    sliderTimes : function(start, end) {
      var prettyStart = new Date(start);
      prettyStart = (prettyStart.getUTCMonth() + 1) + "/" + prettyStart.getUTCDate() + "/" + prettyStart.getUTCFullYear();

      var prettyEnd = new Date(end);
      prettyEnd = (prettyEnd.getUTCMonth() + 1) + "/" + prettyEnd.getUTCDate() + "/" + prettyEnd.getUTCFullYear();

      $('#' + this.dateRangeID).html(prettyStart + ' - ' + prettyEnd);
    },

    // catches changes to the date slider and fires an event to change the
    // route.
    changeTimes : function(start, end, updateUrl) {
      this.startTime = this.times[start];
      this.endTime = this.times[end];

      this.sliderTimes(this.startTime, this.endTime);

      if(updateUrl) {
          if(this.name == 'biology') {
              app.event.eventBus.trigger("change:biologyDates", this.startTime, this.endTime);
          } else {
              app.event.eventBus.trigger("change:times", this.startTime, this.endTime);
          }
      }

    },

	getTimes: function() {
		return [new Date(this.startTime), new Date(this.endTime)];
	},

  // catches changes to the parameters and fires an event to change the route.
	changeParameters: function() {
		app.event.eventBus.trigger("change:parameters", this.getSelectedParameters());
	},

	changeSeason: function() {
	    if(this.name == 'biology') {
            app.event.eventBus.trigger("change:biologyBin", $("#" + this.binDropdown.seasonSelectID).val(), this.name);
        } else {
            app.event.eventBus.trigger("change:bin", $("#" + this.binDropdown.seasonSelectID).val(), this.name);
        }

	},

    changeYear: function() {
        this.year = $("#" + this.yearSelectID).val();
        app.event.eventBus.trigger("change:year", this.year);
    },

	  // used by the DetailView to determine which parameters are already selected.
	  // mostly useful when going back and forth between the same DetailView,
	  // so that the selected parameters aren't reset.
    getSelectedParameters : function() {
        var ret = [];
        
        $('.parameters input[type="checkbox"]:checked').each(function() {
            ret.push(encodeURIComponent($(this).attr('id')));
        });
        
        return ret;
    }
});
app.view.DetailView = Backbone.View.extend({

    events : {
        "click #detail-go-back" : "goBack",
        "click #showDistribution" : "showDistribution",
        "click .download:not(.disabled)": app.utils.interceptDownload
    },

    initialize: function(options) {
        var that = this;
        if(app.collection.sensors.length > 0) {
            that.initializeAfterFetch(options);
        } else {
            app.collection.sensors.fetch({
                success: function(collection) {
                    that.initializeAfterFetch(options);
                }
            });

        }

    },

    getInfoIconSettings: function() {
        return (
            '<svg xmlns="http://www.w3.org/2000/svg" version="1.1" height="18" width="18">' +
                '<circle cx="9" cy="9" r="8" fill="url(#g1)" stroke="#939598" stroke-width="2px" />' +
                '<text x="7" y="14" fill="darkblue" style="font : bold 14px Arial sans-serif;">i</text>' +
                '<defs>' +
                    '<linearGradient id="g1" gradientUnits="userSpaceOnUse" ' +
                                    'x1="-3%" y1="3.41%" x2="103%" y2="96.59%">' +
                        '<stop offset=".15" stop-color="#fff" />' +
                        '<stop offset=".39" stop-color="#fafafa" />' +
                        '<stop offset=".67" stop-color="#ececed" />' +
                        '<stop offset=".97" stop-color="#d4d6d6" />' +
                        '<stop offset="1" stop-color="#d1d3d4" />' +
                    '</linearGradient>' +
                '</defs>' +
            '</svg>'
        );
    },

    initializeAfterFetch : function(options) {
        var self = this;
        this.config = options.config;
        _.bindAll(this, 'render', 'setTabTitles', 'updateDownloadLink');
        this.timeSeriesModal = _.template($("#time-series-modal-template").html())();
        this.boxWhiskerModal = _.template($("#box-whisker-modal-template").html())();
        this.dataAggregateModal = _.template($("#data-aggregate-modal-template").html())();
        this.sourceModals = _.template($("#source-modals-template").html())();
        this.stationService = options.stationService;
        this.geostreamService = options.geostreamService;
        this.router = options.router;
        this.eventBus = options.eventBus;
        this.mapPin = options.mapPin;
        // locationID is used in AppView when rendering the DetailView.
        // if the locationID doesn't match the DetailView we are rendering,
        // we'll initialize a new DetailView. Resolves GEOD-309
        this.locationID = options.arguments[0] || null;

        // this.binningTime will be something like 'smart', 'semi', 'yearly', etc. It is how the datapoints
        // are averaged before being drawn in the graphs.
        // Projects can setup a filterFunction that accepts the current sensor (the Backbone Sensor Model)
        // as an argument. From there, you can return 'smart', 'semi', or some other binning value
        // based on a condition. For example: return (sensor.get('type')['id'] == 'epa') ? 'semi' : 'smart';
        // would return 'semi' as the binningTime for epa sensors, all others would use 'smart' binning
        this.binningTime = "";

        this.sensor = app.collection.sensors.findWhere({name: this.locationID});
        if (app.config.binning.filterFunction) {

            this.binningTime = app.config.binning.filterFunction(this.sensor);
        } else if (app.config.binning.time) {
            this.binningTime = app.config.binning.time;
        } else {
            this.binningTime = 'smart';
        }

        this.startTime = null;
        this.endTime = null;
        this.parameters = null;

        this.$el.append(_.template($(this.config.templateSelector).html())());
        var that = this;
        this.miniMap = []
        this.config.miniMap.forEach(function(map) {
            map.config["parentView"] = that;
            map.config["mapPin"] = that;
            that.miniMap.push(new app.view.MiniMapView(map.config));
            that.$(map.id).append(that.miniMap[that.miniMap.length-1].el);
        });

        if (this.config.controlsViews && this.config.controlsViews.length) {
            _.each(this.config.controlsViews, function(controlView) {
                controlView['parentView'] = self;
                controlView['eventBus'] = self.eventBus;
                if (controlView.config.binDropdown && controlView.config.binDropdown.filterFunction) {
                    controlView.config.binDropdown.sensor = app.collection.sensors.findWhere({name: self.locationID});
                }
                self[controlView.name] = new app.view.ControlsView(controlView.config);
            })
        }

//        if (this.config.timeSeriesViews && this.config.timeSeriesViews.length) {
//            _.each(this.config.timeSeriesViews, function(timeSeriesView) {
//                timeSeriesView['parentView'] = self;
//                timeSeriesView['eventBus'] = self.eventBus;
//                self[timeSeriesView.name] = new app.view.TimeSeriesView(timeSeriesView.config);
//            });
//        }

        this.aggregateTimeSeriesView = new app.view.TimeSeriesView({
            parentView : this,
        });

        this.$("#aggregate-timeseries").append(this.aggregateTimeSeriesView.el);

        this.limnologyView = new app.view.LimnologyView({
            parentView : this,
        });

        this.$("#limnology-chart").append(this.limnologyView.el);

        this.limnologyView.changeDepth((function(self) {
            return function(i) {
                self.eventBus.trigger("change:depth", i);
            };
        })(this));

        this.timeSeriesView = new app.view.TimeSeriesView({
            parentView : this,
        });
        this.stackedBarViews  = [];

        this.stackedLineViews = [];

        //this.$("#timeseries-at-depth").append(this.timeSeriesView.el);

        this.$('a[data-toggle="tab"]').on("shown", function(self) {
            return function(event) {
                self.render();
            };
        }(this));

        this.$el.append(this.timeSeriesModal);
        this.$el.append(this.boxWhiskerModal);
        this.$el.append(this.dataAggregateModal);

        // setup a loading spinner we can turn on and off
        var spinner = app.config.views.detail.spinnerOptions || {
                lines: 13 // The number of lines to draw
                , length: 28 // The length of each line
                , width: 14 // The line thickness
                , radius: 42 // The radius of the inner circle
                , scale: 1 // Scales overall size of the spinner
                , corners: 1 // Corner roundness (0..1)
                , color: '#000' // #rgb or #rrggbb or array of colors
                , opacity: 0.25 // Opacity of the lines
                , rotate: 0 // The rotation offset
                , direction: 1 // 1: clockwise, -1: counterclockwise
                , speed: 1 // Rounds per second
                , trail: 60 // Afterglow percentage
                , fps: 20 // Frames per second when using setTimeout() as a fallback for CSS
                , zIndex: 2e9 // The z-index (defaults to 2000000000)
                , className: 'spinner' // The CSS class to assign to the spinner
                , top: '50%' // Top position relative to parent
                , left: '50%' // Left position relative to parent
                , shadow: false // Whether to render a shadow
                , hwaccel: false // Whether to use hardware acceleration
                , position: 'absolute'
            };
        this.spinner = new Spinner(spinner);

        // the spinner isn't appended to the DOM until the first time it gets called.
        app.event.eventBus.on("detail:spinner:start", function() {
            self.$("#detail-panel").append(self.spinner.spin().el);
        });
        // use the eventBus to stop the spinner from anywhere
        app.event.eventBus.on("detail:spinner:stop", function() {
            self.spinner.stop();
        });



        // This function will return a url string in the order required by the view.
        // ie: location/time/parameters/depth/bin
        // Each individual change event listener in this view only needs to check to see if
        // its attribute (like parameter, bin, depth or time) is already set -
        // if so, it will replace it with the new values.
        // Otherwise it will append the attributes to the end of the url
        // The urlReOrder function does the job of making sure the order
        // matches what is required by this view.
        this.urlReOrder = function(newUrl) {
            // find "detail/location/ID/
            var locationRegex = /detail\/location\/.+?\//g;
            var locationFragment = locationRegex.exec(newUrl) || "";

            // find "startTime/DATE/endTime/DATE/
            var timeRegex = /startTime\/.*\/endTime\/.*?\//g;
            var timeFragment = timeRegex.exec(newUrl) || "";

            // find "parameters/PARAMETERS
            var parametersRegex = /parameters\/.*?\//g;
            var parametersFragment = parametersRegex.exec(newUrl) || "";

            // find "bin/SEASON"
            var binIDs = _.map(getBinningDesignators(self.binningTime).items, function(bin) { return bin.id} );
            var binRegexString = binIDs.join("|");
            var binRegex = new RegExp("bin\/(" + binRegexString + ")\/");
            var binFragment = binRegex.exec(newUrl);
            // since we are using parenthesis to match spring or summer, regex returns
            // an array of matches. We only need the first one, which is the entire url, so we use [0] below.
            binFragment = (binFragment ? binFragment[0] : "");

            // find "depth/NUMBER"
            var depthRegex = /depth\/\d+\//g;
            var depthFragment = depthRegex.exec(newUrl) || "";

            // find "depthYear/YEAR"
            var depthYearRegex = /depthYear\/.*?\//g;
            var depthYearFragment = depthYearRegex.exec(newUrl) || "";
            depthYearFragment = (depthYearFragment ? depthYearFragment[0] : "");

            // find "depthBin/SEASON"
            var depthBinRegex = new RegExp("depthBin\/(" + binRegexString + ")\/");
            var depthBinFragment = depthBinRegex.exec(newUrl);
            // since we are using parenthesis to match spring or summer, regex returns
            // an array of matches. We only need the first one, which is the entire url, so we use [0] below.
            depthBinFragment = (depthBinFragment ? depthBinFragment[0] : "");

            // find "biologyStartTime/DATE/biologyEndTime/DATE/
            var biologyDateRegex = /biologyStartTime\/.*\/biologyEndTime\/.*?\//g;
            var biologyFragment = biologyDateRegex.exec(newUrl) || "";


            // find "biologyBin/SEASON"
            var biologyBinRegex = /biologyBin\/.*?\//g;
            var biologyBinFragment = biologyBinRegex.exec(newUrl) || "";
            biologyBinFragment = (biologyBinFragment ? biologyBinFragment[0] : "");

            return locationFragment + timeFragment + parametersFragment + binFragment + depthFragment + depthYearFragment + depthBinFragment + biologyFragment + biologyBinFragment;

        };

        // fire the route for a change to the selected time range in the detail view - times tab
        this.eventBus.bind("change:times", (function(self) {
            return function(start, end) {
                var timeFragment = "startTime/" + encodeURIComponent(start) + "/endTime/" + encodeURIComponent(end) + "/";
                var newUrl = Backbone.history.fragment;

                if(Backbone.history.fragment.indexOf("startTime") >= 0) {
                    newUrl = newUrl.replace(/startTime\/[^\/]*\/endTime\/[^\/]*\//, timeFragment);
                } else {
                    newUrl = newUrl + timeFragment;
                }
                self.router.navigate(self.urlReOrder(newUrl), {trigger : true, replace : true});
            };
        })(this));

        // fire the route for a change to the selected time range in the detail view - biology tab
        this.eventBus.bind("change:biologyDates", (function(self) {
            return function(start, end) {
                var timeFragment = "biologyStartTime/" + encodeURIComponent(start) + "/biologyEndTime/" + encodeURIComponent(end) + "/";
                var newUrl = Backbone.history.fragment;

                if(Backbone.history.fragment.indexOf("biologyStartTime") >= 0) {
                    newUrl = newUrl.replace(/biologyStartTime\/[^\/]*\/biologyEndTime\/[^\/]*\//, timeFragment);
                } else {
                    newUrl = newUrl + timeFragment;
                }
                self.router.navigate(self.urlReOrder(newUrl), {trigger : true, replace : true});
            };
        })(this));

        // fire the route for a change to the selected parameters in the detail view
        this.eventBus.bind("change:parameters", (function(self) {
            return function(parameters) {
                self.parameters = parameters;
                var parametersFragment =  parameters.length === 0 ? "" : "parameters/" + parameters.join() + "/";
                var newUrl = Backbone.history.fragment;

                if(Backbone.history.fragment.indexOf("parameters") >= 0) {
                    newUrl = newUrl.replace(/parameters\/.*?\//g, parametersFragment);
                } else {
                    newUrl = Backbone.history.fragment + parametersFragment;
                }
                self.router.navigate(self.urlReOrder(newUrl), {trigger : true, replace : true});
            };
        })(this));

        // fires the route for a change to the bin value
        this.eventBus.bind("change:bin", (function(self) {
            return function(bin, view) {
                if (view == "depth") {
                    self.eventBus.trigger("change:depthBin", bin, view);
                    return;
                } else if (view == "biology") {
                    self.eventBus.trigger("change:biologyBin", bin, view);
                    return;
                }
                var binFragment = "";
                var newUrl = Backbone.history.fragment;
                var binIDs = _.map(getBinningDesignators(self.binningTime).items, function(bin) { return bin.id} );
                var binRegex = binIDs.join("|");
                var binRegexObject = new RegExp("bin\/("+ binRegex +")?\/");

                if (bin != "") {
                    binFragment = "bin/" + bin + "/";
                }

                if (Backbone.history.fragment.indexOf("bin") >= 0) {
                    newUrl = newUrl.replace(binRegexObject, binFragment);
                } else {
                    newUrl = newUrl + binFragment;
                }

                self.router.navigate(self.urlReOrder(newUrl), { trigger : true, replace : true });

            };
        })(this));

        // fires the route for a change to the depth value in the limnology chart.
        this.eventBus.bind("change:depth", (function(self) {
            return function(depth) {
                var depthFragment = "depth/" + depth + "/";
                var newUrl = Backbone.history.fragment;

                if(Backbone.history.fragment.indexOf("depth") >= 0) {
                    newUrl = newUrl.replace(/depth\/[^\/]*\/?/, depthFragment);
                } else {
                    newUrl = newUrl + depthFragment;
                }
                self.router.navigate(self.urlReOrder(newUrl), {trigger : true, replace : true});
            };
        })(this));

        // fires the route for a change to the depth value in the limnology chart.
        this.eventBus.bind("change:year", (function(self) {
            return function(depthYear) {
                var depthYearFragment = "depthYear/" + depthYear + "/";
                var newUrl = Backbone.history.fragment;

                if(Backbone.history.fragment.indexOf("depthYear") >= 0) {
                    newUrl = newUrl.replace(/depthYear\/[^\/]*\/?/, depthYearFragment);
                } else {
                    newUrl = newUrl + depthYearFragment;
                }
                self.router.navigate(self.urlReOrder(newUrl), {trigger : true, replace : true});
            };
        })(this));

        // fires the route for a change to the bin value
        this.eventBus.bind("change:depthBin", (function(self) {
            return function(depthBin) {
                var depthBinFragment = "";
                var newUrl = Backbone.history.fragment;
                var binIDs = _.map(getBinningDesignators(self.binningTime).items, function(bin) { return bin.id} );
                var binRegex = binIDs.join("|");

                if (depthBin != "") {
                    depthBinFragment = "depthBin/" + depthBin + "/";
                }

                if (Backbone.history.fragment.indexOf("depthBin") >= 0) {
                    newUrl = newUrl.replace(new RegExp("depthBin\\/("+ binRegex +")?\\/"), depthBinFragment);
                } else {
                    newUrl = newUrl + depthBinFragment;
                }

                self.router.navigate(self.urlReOrder(newUrl), { trigger : true, replace : true });

            };
        })(this));

        // fires the route for a change to the bin value
        this.eventBus.bind("change:biologyBin", (function(self) {
            return function(biologyBin) {
                var biologyBinFragment = "";
                var newUrl = Backbone.history.fragment;
                var binIDs = _.map(getBinningDesignators(self.binningTime).items, function(bin) { return bin.id} );
                var binRegex = binIDs.join("|");

                if (biologyBin != "") {
                    biologyBinFragment = "biologyBin/" + biologyBin + "/";
                }

                if (Backbone.history.fragment.indexOf("biologyBin") >= 0) {
                    newUrl = newUrl.replace(new RegExp("biologyBin\\/("+ binRegex +")?\\/"), biologyBinFragment);
                } else {
                    newUrl = newUrl + biologyBinFragment;
                }

                self.router.navigate(self.urlReOrder(newUrl), { trigger : true, replace : true });

            };
        })(this));



    },

    initiate : function(location, startTime, endTime, parameters, bin, depth, depthYear, depthBin,  biologyStartTime, biologyEndTime, biologyBin) {
        this.locationID = location;
        this.sensor = app.collection.sensors.findWhere({name: this.locationID});

        app.collection.sensors.getStationByName(location, (function(self) {
            return function(station) {
                self.eventBus.trigger("locationUpdated", location, bin);
                self.miniMap.forEach(function(map) {
                    map.setGeoJsonFeature([ station ]);
                    map.render();
                });

                self.go(station, startTime, endTime, parameters, bin, depth, depthYear, depthBin, biologyStartTime, biologyEndTime, biologyBin);
            };
        })(this));
    },

    go : function(station, startTime, endTime, parameters, bin, depth, depthYear, depthBin,  biologyStartTime, biologyEndTime, biologyBin) {
        var self = this;
        self.sensorID = station.id;
        // If start / end time are null, we need to initialize the range slider with time data
        if(startTime == null && endTime == null || !sessionStorage.getItem(station.id)) {

            // Generate the dates for the sensor min / max
            var sensor = app.collection.sensors.findWhere({id: station.id});
            var dates = getDates(new Date(sensor.get('min_start_time')), new Date(sensor.get('max_end_time')));

            // save dates in session so we don't regenerate for the same sensor
            sessionStorage.setItem(station.id, JSON.stringify(dates));

            // here is how I understand the following:
            // the setTimes function sets the times for the controlView, which calls renderSlider,
            // which calls changeTimes, which triggers a "change:times" event which re-renders this view
            // Update 03/2017: If it is the first time you call this when coming from the explore page you want to update
            // the url so the points are filtered by the dates. Otherwise, if there are dates specified, you don't want to
            // update the already set start and end date in the url.
            var updateTimesInUrl = true;
            if(startTime != null && endTime != null) {
                updateTimesInUrl = false;
            }
            self.controlsView.setTimes(dates, updateTimesInUrl);


            // the return in the following case is heavily dependent on the setTimes function called above.
            // The first time running the DetailView go function, you won't have a startTime or endTime
            // so this returns and waits for setTimes to finish. See notes just above...
            if(updateTimesInUrl) {
                return;
            }

        }

        if(biologyStartTime == null && biologyEndTime == null && self.controlsBiologyView != null) {
            biologyStartTime = startTime;
            biologyEndTime = endTime;

        }

        var time = self.binningTime;
        if (_.isUndefined(self.binningTime)) {
            time = 'none';
        }

        var info_icon_appearance = self.getInfoIconSettings();

        // If self.binningTime is 'smart', then determine aggregation by temporal range
        if (self.binningTime == 'smart') {
            time = getAggregationBin(new Date(startTime), new Date(endTime));
            $("#bin-duration").text("Averaged by " + time).append('' +
                ' <a href="#data-aggregate-modal" role="button" ' +
                'data-toggle="modal" class="info-icon-spacing">' +
                info_icon_appearance  +
                '</a>');
        }

        // Use default depth if no depth value provided
        var sensorDepth = depth;
        if(sensorDepth === undefined || sensorDepth === null) {
            sensorDepth = app.config.binning.depth;
        }

        // Fetch and Display sensor data for a particular time bin
        this.geostreamService.getBinnedData(time, sensorDepth, station.id, true, function(data) {

            self.startTime = startTime = new Date(startTime);
            self.endTime = endTime = new Date(endTime);
            biologyStartTime = new Date(biologyStartTime);
            biologyEndTime = new Date(biologyEndTime);

            // If a list of selected parameters are provided, then only display selected
            parameters = parameters == null ? [] : parameters.split(",");

            // Retrieve generated dates for this station
            var dates = JSON.parse(sessionStorage.getItem(station.id));
            self.controlsView.setTimes(dates, false);
            if(startTime != null && endTime != null) {
                self.controlsView.updateTimes(startTime, endTime);
            }

            // Used to filter data outside of the range of start / end time
            var filterDatesByRange = function(x, startTime, endTime) {
                var date = new Date(x.date);
                var datapoint = {year: date.getUTCFullYear(), month: date.getUTCMonth(), day: date.getUTCDate(), hour: date.getUTCHours(), minute: date.getUTCMinutes() };

                if (startTime.getUTCFullYear() > datapoint.year) {
                    return false;
                }
                if (startTime.getUTCFullYear() == datapoint.year) {
                    if (!_.isUndefined(datapoint.month)) {
                        if (startTime.getUTCMonth() > datapoint.month) {
                            return false;
                        }
                        if (startTime.getUTCMonth() == datapoint.month) {
                            if (!_.isUndefined(datapoint.day)) {
                                if (startTime.getUTCDate() > datapoint.day) {
                                    return false
                                }
                                // I'm leaving this here in case we decide to support filter down to hour/minutes
                                // Since the slider does not filter to a smaller unit than days, I'm removing this unnecessary check
                                // The slider would need be smarter to change it's increment when the date range is small enough
                                // in order to support showing hourly / minute data
                                // if (startTime.getUTCDate() == datapoint.day) {
                                //   if (!_.isUndefined(datapoint.hour)) {
                                //     if (startTime.getUTCHours() > datapoint.hour) {
                                //       return false;
                                //     }
                                //     if (startTime.getUTCHours() == datapoint.hour) {
                                //       if (!_.isUndefined(datapoint.minute) && startTime.getUTCMinutes() > datapoint.minute) {
                                //         return false;
                                //       }
                                //     }
                                //   }
                                // }
                            }
                        }
                    }
                }
                if (endTime.getUTCFullYear() < datapoint.year) {
                    return false;
                }
                if (endTime.getUTCFullYear() == datapoint.year) {
                    if (!_.isUndefined(datapoint.month)) {
                        if (endTime.getUTCMonth() < datapoint.month) {
                            return false;
                        }
                        if (endTime.getUTCMonth() == datapoint.month) {
                            if (!_.isUndefined(datapoint.day)) {
                                if (endTime.getUTCDate() < datapoint.day) {
                                    return false
                                }
                                // I'm leaving this here in case we decide to support filter down to hour/minutes
                                // Since the slider does not filter to a smaller unit than days, I'm removing this unnecessary check
                                // The slider would need be smarter to change it's increment when the date range is small enough
                                // in order to support showing hourly / minute data
                                // if (endTime.getUTCDate() == datapoint.day) {
                                //   if (!_.isUndefined(datapoint.hour)) {
                                //     if (endTime.getUTCHours() < datapoint.hour) {
                                //       return false;
                                //     }
                                //     if (endTime.getUTCHours() == datapoint.hour) {
                                //       if (!_.isUndefined(datapoint.minute) && endTime.getUTCMinutes() < datapoint.minute) {
                                //         return false;
                                //       }
                                //     }
                                //   }
                                // }
                            }
                        }
                    }
                }
                return true;
            };

            // time series parameters found in binned data
            var time_series_params = [];

            // depth parameters found in binned data
            var depth_profile_params = [];

            // biology parameters found in binned data
            var biology_params = [];

            // Dissolved oxygen parameters found in binned data
            var stacked_line_params = [];

            // We need both keys and ids to support parameters that were not found, but added at runtime
            // The returned data from the API matches the key, but the app.collection.parameters are stored by id and needed later
            var timeSeriesMap = {};
            var depthKeyMap = {};
            var biologyMap = {};
            var stackedLineMap = {};

            // properties in the binned data
            var properties = data[0].properties;

            // Break out depth and time data and store display name for graphs
            for(var key in properties) {
                var parr = app.collection.parameters.filter(function(x) {
                    return (x.id == key) || x.get("alternates").indexOf(key) >= 0;
                });

                if (parr[0] && parr[0]['id'] ) {
                    if(parr[0].id.indexOf('ignored') == -1 && parr[0].get('detailView') === 'time') {
                        timeSeriesMap[parr[0].id] = key;
                        time_series_params.push(parr[0].id);
                    } else if (parr[0].id.indexOf('ignored') == -1 && parr[0].get('detailView') === 'depth') {
                        depthKeyMap[parr[0].id] = key;
                        depth_profile_params.push(parr[0].id);
                    } else if (parr[0].id.indexOf('ignored') == -1 && parr[0].get('detailView') === 'biology') {
                        biologyMap[parr[0].id] = key;
                        biology_params.push(parr[0].id);
                    }  else if (parr[0].id.indexOf('ignored') == -1 && parr[0].get('detailView') === 'stacked_line') {
                        stackedLineMap[parr[0].id] = key;
	                    stacked_line_params.push(parr[0].id);
                    }

                }
            }

            if (time_series_params.length > 0) {
                $("#time-tab").toggle(true);

                time_series_params.sort();

                // For time series data, if applicable, use bin selected in UI or default value if none specified
                // This is used when selecting a subset of the semi bin (e.g spring or summer data)
                bin = bin || $('#bin-select-time').val();
                if (bin === undefined) {
                    if ( self.binningTime && !(self.binningTime == 'none' || self.binningTime == 'smart')) {
                        if(!_.isEmpty(getBinningDesignators(self.binningTime).items)) {
                            bin = getBinningDesignators(self.binningTime).items[0]['id'];
                        }
                    }
                }

                // Use a unique color for each parameter
                var time_series_params_colors = Object.keys(properties).length > 10 ? d3.scale.category20().domain(time_series_params) : d3.scale.category10().domain(time_series_params);

                // keep a list of data sources, pointing back to clowder dataset
                var sources = [];

                var alldata = [], summerEPdata = [];
                var foundEP = false;
                // iterate over each of the unique parameters
                for (var i = 0; i < time_series_params.length; i++) {
                    // 'parameters' is what gets passed in via the URL (ie: the Backbone router gives us these)
                    // if there are parameters in the URL, but the param we are on isn't one of them, skip it
                    if (!_.isEmpty(parameters) && (_.indexOf(parameters, time_series_params[i]) < 0)) {
                        continue;
                    }

                    var propKey = timeSeriesMap[time_series_params[i]];

                    var valuesAll = [], valuesEPsummer = [];

                    // Gather date ranges to set time series X range
                    var dateRange = [];

                    // Since server side binning separates by depth code, we use this to see if a bin has been processed
                    var currentBin = null;
                    _.each(properties[propKey], function(entry) {

                        // Skip entry if we have already processed it
                        if(currentBin != entry.label) {
                            currentBin = entry.label;

                            // Check if data is in date range and matches the selected bin (e.g. summer/spring), if applicable
                            if((_.isUndefined(bin) || (entry.label.indexOf(bin) != -1)) && filterDatesByRange(entry, startTime, endTime)) {
                                // Server side binning separates by depth code so we must locate all values for a bin
                                var obj = _.select(properties[propKey], function(item) {
                                    return item.label === entry.label;
                                });

                                var countAll = 0, countEPdata = 0;
                                var sumAll = 0, sumEPdata = 0;
                                var rawAll = [], rawEP = [];
                                var entryDate;

                                _.each(obj, function(x) {
                                    var depthCode = x.depth_code;

                                    // Added this because client side filtering mapped these depth codes to EP
                                    if(["SRF", "LEP", "TRM"].indexOf(depthCode) > -1) {
                                        depthCode = "EP";
                                    }

                                    if(x.label.indexOf("summer") != -1 && !_.isUndefined(depthCode) && (depthCode == "EP")) {
                                        foundEP = true;
                                    }

                                    if(x.label.indexOf("summer") == -1 || _.isUndefined(depthCode) || (depthCode == "EP") || (depthCode == "NA")) {
                                        countEPdata += x.count;
                                        sumEPdata += x.average * x.count;
                                        rawEP.push(x.average * x.count);
                                    }

                                    countAll += x.count;
                                    sumAll += x.average * x.count;
                                    rawAll.push(x.average);
                                    entryDate = x.date;
                                    _.each(x.sources, function(source) {
                                        sources.push(source);
                                    });
                                });

                                valuesAll.push({ x: entryDate, y: sumAll / countAll, label: currentBin, raw: _.flatten(rawAll) });
                                dateRange.push(entryDate);

                                if(countEPdata != 0) {
                                    valuesEPsummer.push({ x: entryDate, y: sumEPdata / countEPdata, label: currentBin, raw: _.flatten(rawEP) })
                                }
                            }
                        }
                    });

                    var yrange = d3.extent(valuesAll.concat(valuesEPsummer), function(d) { return d.y; });
                    if (app.config.graphs.timeSeries.showUnits.showZero != false && yrange[0] > 0) {
                        yrange[0] = 0;
                    }

                    var xrange = [new Date(dateRange[0]), new Date(dateRange[dateRange.length-1])];
                    var xExtent = app.config.views.detail.timeSeriesFullExtent ? self.controlsView.getTimes() : xrange;

                    if(valuesAll.length > 0) {
                        alldata.push({
                            key: i.toString(),
                            values: [ {
                                color: time_series_params_colors(time_series_params[i]),
                                key: time_series_params[i],
                                xextent: xExtent,
                                xrange: xrange,
                                yrange: yrange,
                                values: valuesAll,
                                sources: _.uniq(_.flatten(sources)),
                                unit: (app.collection.parameters.findWhere({id: time_series_params[i]})).get("unit")
                            }]
                        });
                    }

                    if(!_.isEmpty(valuesEPsummer)) {
                        summerEPdata.push({
                            key: i.toString(),
                            values: [ {
                                color: time_series_params_colors(time_series_params[i]),
                                key: time_series_params[i],
	                            xextent: xExtent,
                                xrange: xrange,
                                yrange: yrange,
                                values: valuesEPsummer,
                                unit: (app.collection.parameters.findWhere({id: time_series_params[i]})).get("unit")
                            }]
                        })
                    }
                }
                if((bin == "spring") || !foundEP) {
                    self.aggregateTimeSeriesView.setData(alldata, undefined);
                } else {
                    self.aggregateTimeSeriesView.setData(alldata, summerEPdata);
                }
                self.controlsView.setParameters(time_series_params, _.isEmpty(parameters) ? time_series_params : parameters, time_series_params_colors);
            } else {
                $("#time-tab").toggle(false);
            }

            // Setup depth profile tab
            var dates = JSON.parse(sessionStorage.getItem(station.id));
            self.controlsDepthView.setTimes(dates, false);

            if (depth_profile_params.length > 0) {
                $("#depth-tab").toggle(true);

                // If depth year is set in the UI, use that as the depth year filter
                var depthDateFilter = null;
                if(depthYear) {
                    depthDateFilter = new Date(depthYear, 0, 1);
                }

                depth_profile_params.sort();

                // Used to filter depth data outside of the selected year
                var filterByYear = function(x, depthDateYear) {
                    var date = new Date(x.date);
                    var datapoint = {year: date.getUTCFullYear() };

                    if(depthDateYear.getUTCFullYear() == datapoint.year) {
                        return true;
                    } else {
                        return false;
                    }
                };

                // For depth data, if applicable, use bin selected in UI or default value if none specified
                // This is used when selecting a subset of the semi bin (e.g spring or summer data)
                depthBin = depthBin || $('#bin-select-depth').val();
                if (depthBin === undefined) {
                    if (self.binningTime && !(self.binningTime == 'none' || self.binningTime == 'smart')) {
                        if(!_.isEmpty(getBinningDesignators(self.binningTime).items)) {
                            depthBin = getBinningDesignators(self.binningTime).items[0]['id'];
                        }
                    }
                }

                // Use d3 to create colors for each of the unique parameters
                var depth_profile_params_colors = depth_profile_params.length > 10 ? d3.scale.category20().domain(depth_profile_params) : d3.scale.category10().domain(depth_profile_params);

                // List of available years for depth data
                var depthDates = [];

                // We're creating a display_data object for this date
                var display_data = [{
                    key: new Date(startTime),
                    values: []
                }];

                for(var i = 0; i < depth_profile_params.length; i++) {
                    // 'parameters' is what gets passed in via the URL (ie: the Backbone router gives us these)
                    // if there are parameters in the URL, but the param we are on isn't one of them, skip it
                    if (!_.isEmpty(parameters) && (_.indexOf(parameters, depth_profile_params[i]) < 0)) {
                        continue;
                    }

                    // keep a list of data sources, pointing back to clowder dataset
                    var sources = [];

                    var property = depth_profile_params[i];
                    var propKey = depthKeyMap[property];

                    var valuesAll = [];
                    _.each(properties[propKey], function(x) {
                        // Check if data matches the selected bin (e.g. summer/spring), if applicable
                        if(_.isUndefined(depthBin) || x.label.indexOf(depthBin) > -1) {

                            // If no depth year is set in the UI, then use the first date as the filter
                            if(depthDateFilter == null) {
                                depthDateFilter = new Date(x.date);
                            }

                            // Create a list of unique dates to build the depth date year selection widget
                            if(_.isEmpty(_.where(depthDates, x.date))) {
                                depthDates.push(x.date);
                            }

                            // Only add values for the selected depth year
                            if(filterByYear(x, depthDateFilter)) {
                                for(var j = 0; j < x.sources.length; j++) {
                                    if(_.isEmpty(_.where(sources, x.sources[j]))) {
                                        sources.push(x.sources[j]);
                                    }
                                }
                                valuesAll.push({
                                    x: x.average,
                                    x0: 0,
                                    x1: 0,
                                    y: x.depth
                                });
                            }
                        }
                    });

                    // Only add parameter if it has values for the depth year
                    if(valuesAll.length > 0) {
                        display_data[0].values.push({
                            color: depth_profile_params_colors(property),
                            key: property,
                            sources: sources,
                            values: valuesAll,
                            unit: (app.collection.parameters.findWhere({id: property})).get("unit")
                        });
                    }
                }

                depthDates.sort();

                self.controlsDepthView.setYears(depthDates);
                self.limnologyView.setData(display_data);
                self.controlsDepthView.setParameters(depth_profile_params, _.isEmpty(parameters) ? depth_profile_params : parameters, depth_profile_params_colors);
            } else {
                $("#depth-tab").toggle(false);
            }

            if (biology_params.length > 0) {
                $("#biology-tab").toggle(true);
                $('#biology-graphs').html("");
                var biology_params_colors = [];

                biologyBin = biologyBin || $('#bin-select-biology').val();

                if(biologyBin === undefined) {
                    if( self.binningTime && !(self.binningTime == 'none' || self.binningTime == 'smart')) {
                        if(!_.isEmpty(getBinningDesignators(self.binningTime).items)) {
                            biologyBin = getBinningDesignators(self.binningTime).items[0]['id'];
                        }
                    }
                }
                self.stackedBarViews = [];
                // Iterate over all of the unique parameters
                for(var i =0; i < biology_params.length; i++) {
                    if (!_.isEmpty(parameters) && _.indexOf(parameters, biology_params[i]) < 0) {
                        continue;
                    }
                    var stackedGraphData = [];
                    var propKey = biologyMap[biology_params[i]];
                    var biologyDates = [];

                    _.each(properties[propKey], function (entry) {
                        biologyDates.push(new Date(entry.date));
                        //Check if data is in date range and is part of the season selected on the bin
                        if((_.isUndefined(biologyBin) || (entry.label.indexOf(biologyBin) != -1)) && filterDatesByRange(entry, biologyStartTime, biologyEndTime)) {
                            for (var k = 0; k < entry.array.length; k++) {
                                var biology_row = JSON.parse(entry.array[k]);
                                biology_row["date"] = entry.date;
                                stackedGraphData.push(biology_row);
                            }
                        }

                    });

                    //If the start and end date are the ones in the 'times' we want to update them to be a 'smaller' range
                    // of dates just to cover the range of the biology dates.
                    var biologyMinDate = new Date(Math.min.apply(null, biologyDates));
                    var biologyMaxDate =  new Date(Math.max.apply(null, biologyDates));

                    //This should only be called the first time. That is why the comparison between the biology and the biology start times.
                    if(biologyStartTime.getTime() == startTime.getTime() && biologyMinDate.getTime() > biologyStartTime.getTime()) {
                        biologyStartTime = biologyMinDate;
                        if(biologyEndTime.getTime() == endTime.getTime() && biologyMaxDate.getTime() < biologyEndTime.getTime()) {
                            biologyEndTime = biologyMaxDate;
                        }
                        var dates = getDates(biologyStartTime, biologyEndTime);
                        self.controlsBiologyView.setTimes(dates, false);
                    } else if (biologyStartTime.getTime() >= biologyMinDate.getTime() || biologyEndTime.getTime() <= biologyMaxDate.getTime()) {
                        //This should be called when you refresh the details page.
                        var dates = getDates(biologyMinDate, biologyMaxDate);
                        self.controlsBiologyView.setTimes(dates, false);
                        self.controlsBiologyView.updateTimes(biologyStartTime, biologyEndTime);
                    }

                    var parameterProps = app.collection.parameters.findWhere({id: propKey});
                    var newGraphId = "stacked-biology-graph" + propKey;
                    $("#"+newGraphId).remove();
                    $('#biology-graphs').append('<svg id="' + newGraphId + '" width="960" height="500"></svg>');
                    var biologyZ = d3.scale.category10();
                    var scaleNames = [];

                    if(parameterProps.get("scaleColors") != undefined && parameterProps.get("scaleNames") != undefined) {
                        scaleNames = parameterProps.get("scaleNames");
                        biologyZ = d3.scale.ordinal().domain(scaleNames).range(parameterProps.get("scaleColors"));

                    }
                    var areaView = new app.view.StackedBarView({
                        id: newGraphId,
                        data: stackedGraphData,
                        scale: d3.time.years,
                        title: parameterProps.get("title") + " (" + parameterProps.get("unit") + ")",
                        scaleNames: scaleNames,
                        unit: parameterProps.get("unit"),
                        z: biologyZ
                    });
                    self.stackedBarViews.push(areaView);

                    biology_params_colors.push("#000000");
                }
                var biology_colors = d3.scale.ordinal().range(biology_params_colors);
                self.controlsBiologyView.setParameters(biology_params, _.isEmpty(parameters) ? biology_params : parameters, biology_colors);
            } else {
                $("#biology-tab").toggle(false);
            }

            if (stacked_line_params.length > 0) {
                $("#stacked-line-tab").toggle(true);
                $("#stacked-line-graphs").html("");
                self.stackedLineViews = [];

                for(var k =0; k < stacked_line_params.length; k++) {
	                if (!_.isEmpty(parameters) && _.indexOf(parameters, stacked_line_params[k]) < 0) {
		                continue;
	                }
	                var propKey = stacked_line_params[k];
	                var stackedLineGraphData = []; // properties[propKey];

	                var parameterProps  = app.collection.parameters.findWhere({id: propKey});
	                var newGraphId = "stacked-line-graph-"+ propKey;
                    $("#"+newGraphId).remove();
	                $("#stacked-line-graphs").append('<svg id="' + newGraphId + '" width="960" height="500"></svg>');

	                _.each(properties[propKey], function(entry) {
                        var stackedLineRow = {};
                        stackedLineRow["date"] = entry.date.substring(0,10);
                        stackedLineRow["values"] = JSON.parse(entry.array);
                        stackedLineGraphData.push(stackedLineRow);

                    });
                    var stackedLineView = new app.view.StackedLineView({
                        id: newGraphId,
                        data: stackedLineGraphData,
                        scale: d3.time.years,
                        title: parameterProps.get("title") + " (" + parameterProps.get("unit") + ")",
                        unit: parameterProps.get("unit"),
                        color: d3.scale.category10()
                    });
                    self.stackedLineViews.push(stackedLineView);
                }

	            stacked_line_params.sort();
            } else {
                $("#stacked-line-tab").toggle(false);
            }

            // render everything
            if (self.sensor) self.updateDownloadLink();
            self.render();

        });
    },

    render : function() {
        var sourceColor;
        app.event.eventBus.trigger("detail:spinner:start");
        if (!this.sensor) {
            this.sensor = app.collection.sensors.findWhere({name: this.locationID});
        }
        this.sourceColor = app.collection.sensors.findWhere({name: this.locationID}).attributes.color;
        this.source = app.collection.sources.findWhere({id: this.sensor.get('type').id});

        $("#detail-view-pin").html(this.mapPin);
        $("#detail-view-pin > svg > g > ellipse").attr("style", "fill: " + this.sourceColor);
        $("#detail-view-source").html(this.source.attributes.prettyName);
        $("#detail-view-source").attr("title", this.source.attributes.prettyName);

        var header_text = (this.sensor && this.sensor.get('popupContent')) || this.locationID;
        if (this.sensor) {
            if (this.sensor.get('online_status') && this.sensor.get('online_status')=="online"){
                header_text +=  " [" + this.sensor.get('online_status').charAt(0).toUpperCase() + this.sensor.get('online_status').slice(1) +  "]";
                $("#detail-view-pin > svg > g > path").attr("style", "stroke: green; stroke-width: 2");
            }
            $("#detail-view-header").html(header_text);
            $("#detail-view-header").attr("title", header_text);
        }

        $("#time-series.tab-pane").each((function(self) {
            return function() {
                self.aggregateTimeSeriesView.render();
            };
        })(this));
        $("#depth-profile.tab-pane").each((function(self) {
            return function() {
                self.limnologyView.render();
                self.timeSeriesView.render();

                self.stackedBarViews.forEach(function(view) {
                    view.render();
                });
            };
        })(this));
        $('#stacked-line-profile.tab-pane').each((function(self){
            return function() {
	            self.stackedLineViews.forEach(function(view) {
	                view.render();
                });
            };
        })(this));
        // using true here makes the map pan into position each time. With false, it stays in place
        this.miniMap.forEach(function(mapElement){
            mapElement.map.invalidateSize(false);
        });
        this.eventBus.trigger("renderBinSelect");
        this.setTabTitles();
        this.$el.append(this.sourceModals);

        var info_icon_appearance = this.getInfoIconSettings();

        if (this.source) {
            if (this.source.get('calculation') && this.source.get('calculation')['time-series']) {
                var timeTitle = $("#time-series-title");
                timeTitle.find('a').remove();
                timeTitle.find('i').remove();

                timeTitle.append('' +
                    '<a href="#' + this.source.id + '-time-series-modal" role="button" ' +
                    'data-toggle="modal" class="info-icon-spacing">' +
                    info_icon_appearance +
                    '</a>');
            }
            if (this.source.get('calculation') && this.source.get('calculation')['depth-profile']) {
                var depthTitle = $("#depth-profile-title");
                depthTitle.find('a').remove();
                depthTitle.find('i').remove();
                depthTitle.append('<a href="#' + this.source.id + '-depth-profile-modal" role="button" ' +
                    'data-toggle="modal"><i class="icon-info-sign bw-info"></i></a>');
            }

            $("#detail-source-icon").html(
                '<a href="#about-' + this.source.id + '-modal" role="button" data-toggle="modal">' +
                    info_icon_appearance  +
                '</a>'
            );
	        $("#detail-biology-source-icon").html(
		        '<a href="#about-' + this.source.id + '-modal" role="button" data-toggle="modal">' +
		        info_icon_appearance  +
		        '</a>'
	        );
        }
        app.event.eventBus.trigger("detail:spinner:stop");

    },

    showDistribution : function() {
        this.$("#showDistribution").button("toggle");
        this.aggregateTimeSeriesView.render();
        this.timeSeriesView.render();
    },

    goBack : function(event) {
        if (this.sensor && this.sensor.id) {
            this.sensorID = this.sensor.id;
        }
        sessionStorage.removeItem(this.sensorID);
        this.router.navigate("#explore", {
            trigger : true,
            replace : false
        });
    },

    setTabTitles: function() {
        var source = app.collection.sources.findWhere({id: this.sensor.attributes.type.id});
        if (source && source.get('tabs')) {
            if (source.get('tabs').timeseries) {
                $('#times-tab').find('a').text(source.get('tabs').timeseries);
            }
            if (source.get('tabs').depthprofile) {
                $('#depth-tab').find('a').text(source.get('tabs').depthprofile);
            }
            if (source.get('tabs').biology) {
                $('#biology-tab').find('a').text(source.get('tabs').biology);
            }
            if (source.get('tabs').stackedLine) {
                $('#staccke-line-tab').find('a').text(source.get('tabs').stackedLine);
            }
        }
    },

    updateDownloadLink : function() {
        var format = "YYYY-MM-DD HH:mm:ss";
        var params = {};

        params['sensor_id'] = [
            this.sensor.get('id')
        ].toString();

        if (this.startTime) params["since"] = moment(this.startTime).format(format);
        if (this.endTime) params["until"] = moment(this.endTime).format(format);

        if (this.parameters) params["attributes"] = this.parameters;

        // create the url
        var url = app.datapoints.url + '?' + $.param(params, true);

        // update the DOM
        var downloadAsJsonButton = $("#detail-download-json");
        downloadAsJsonButton.attr('href', url + "&format=json");

        var downloadAsCsvButton = $("#detail-download-csv");
        downloadAsCsvButton.attr('href', url + "&format=csv");

    }
});

// Determine the bin based on the temporal range of the start / end date
function getAggregationBin(startTime, endTime) {
    var time = endTime.getUTCFullYear() - startTime.getUTCFullYear();
    var timeBin = 'day';

    // This should probably be configurable by project to select the binning
    // that makes the most sense for the expected temporal range of the data
    if(time > 100) {
        timeBin = 'decade';
    } else if(time > 50) {
        timeBin = 'lustrum';
    } else if(time > 25) {
        timeBin = 'year';
    } else if(time > 10) {
        timeBin = 'season';
    } else if(time > 1) {
        timeBin = 'month';
    } else {
        // Convert to days
        time = (endTime - startTime) / 86400000;
        if(time > 14) {
            timeBin = 'day';
        } else if(time > 3) {
            timeBin = 'hour';
        } else {
            timeBin = 'minute';
        }
    }
    return timeBin;
}

// Generate dates between start/end times with 1 day time steps
function getDates(startTime, endTime) {
    var dates = [];
    var currentDate = startTime;
    while(currentDate <= endTime) {
        dates.push(new Date(currentDate).toUTCString());
        currentDate = new Date(currentDate);
        currentDate.setDate(currentDate.getDate() + 1);
    }
    dates.push(new Date(endTime).toUTCString());

    return dates;
}

app.view.SelectItemView = Backbone.View.extend({
    tagName: "option",
    attributes: function() {
        return {
            value: this.model.id || ''
        }
    },

    initialize : function(options) {
        this.model = options.model;
        this.selected = options.selected;
        var content = this.model.get('name') || this.model.get('title') || '';
        this.template = _.template(content.replace(/<(?:.|\n)*?>/gm, ''));
        this.render();
    },

    render : function() {
        this.$el.empty();
        this.$el.append(this.template());
        if (this.selected) this.$el.attr('selected', 'selected');
        return this;
    }
});

app.view.SelectCollectionView = Backbone.View.extend({
    tagName : "select",
    className : "dropdown",

    events: {
        'change': 'changeSelect'
    },

    initialize: function(options) {
        this.trigger = options.trigger;
        if (options.placeholder) this.placeholder = new Backbone.Model({name: options.placeholder});

        _.bindAll(this, "render", "changeSelect", "append", "setSelected");
        this.collection.on('all', this.render);

        this.render();
    },

    render : function() {
        var self = this;
        this.$el.empty();

        // if there are models in this collection, we will populate them as select options
        if (this.collection.length) {
            // self.placeholder allows you to insert a default field like "None" or "Select a Value"
            if (self.placeholder) {
              self.$el.append(new app.view.SelectItemView({ model: self.placeholder, selected: true }).render().el);
            }

            // add each of the options to the select element and mark the selected item
            this.collection.each(function(item) {
                var selected = false;
                if (self.selectedItem && (item.id == self.selectedItem)) {
                  selected = true;
                }
                self.$el.append(new app.view.SelectItemView({ model: item, selected: selected }).render().el);
            });
        }
        return this;
    },

    append: function(item) {
        this.$el.append(new app.view.SelectItemView({model: item}).render().el);
    },

    changeSelect: function(event) {
        var self = this;
        self.setSelected(event.target.value);
        event.cancleBubble = true;
        if (this.trigger) {
            var parameterElement = $('.parameter-trend-active');
            if (parameterElement) {
              var parameterID = parameterElement.data('id');
              if (parameterID) {
                app.event.eventBus.trigger(this.trigger + ":" + parameterID, event.target.value);
              }
            }

        }
    },

    setSelected: function(value) {
        this.selectedItem = value;
    }


});

app.view.ExploreSourcesView = Backbone.View.extend({

    initialize : function(options) {

        var self = this;
        this.config = options.config;
        _.bindAll(this, "render");

        this.template = _.template($(this.config.templateID).html());

        this.modals = _.template($(this.config.modalsID).html())();

        this.sources = app.collection.sources.getSourcesWithSensors().toJSON();

        this.listenTo(app.collection.sources, 'change', this.render);

        // This event is fired when someone opens/closes an accordion
        // in the ExploreView.
        app.event.eventBus.on("change:sources", function(sources, updateGeoJsonFeature) {
            if ($('#sources').find('.data-nav-header-active').length) {
                if (!sources) {
                    sources = [];
                    $('input[name="source"]:checked').each(function() {
                        sources.push($(this).attr("value"));
                    });
                }

                var sensorModels = app.collection.sensors.filter(function(sensor) {
                    return _.contains(sources, sensor.get('type').id);
                });
                var sensors = _.map(sensorModels, function(sensor) {
                    return sensor.toJSON();
                });

                if(updateGeoJsonFeature) {
                    app.view.exploreMapView.setGeoJsonFeature(sensors, self.config.map);
                    app.view.exploreMapView.render(self.config);
                }

            }
        });

    },

    render : function() {

        var self = this;

        if (self.sources.length > 0) {
            var checkedSources = [];

            if ($('input[name="source"]').length == 0) {
                checkedSources = app.collection.sources.getSourcesWithSensors().map(
                    function(source) { return source.get('id'); }
                );
            } else {
                $('input[name="source"]:checked').each(function() {
                    checkedSources.push($(this).attr("value"));
                });
            }

            this.$el.empty();

            app.collection.sources.getAreas().forEach(function(source) {
                // if sources.json hasn't been filled out, the default will be an
                // empty template that we should not render
                if (source.id) {
                    if (_.contains(checkedSources, source.id)) source.checked = "checked";
                    self.$el.append(self.template({ model: source }));
                }
            });

        } else {
            // display placeholder text if no sources are found
            this.$el.html(app.config.sources.noneFound);
        }

        this.$el.append(this.modals);

        var $explorePills = this.$(this.config.pills.className);
        // enable bootstrap tooltips
        // $explorePills.tooltip(this.config.pills.tooltipOptions);

        // fires events to highlight or unhighlight map pins
        $explorePills.hover(function(self) {
            return function(event) {
                app.event.eventBus.trigger("marker:mouseover",
                    event.currentTarget.value.replace(/\W/g, "-"));
            };
        }(this), function(self) {
            return function(event) {
                app.event.eventBus.trigger("marker:mouseout",
                    event.currentTarget.value.replace(/\W/g, "-"));
            };
        }(this));

        $explorePills.on("click", (function(self) {
            return function(event) {
                app.event.eventBus.trigger("marker:click",
                    event.currentTarget.value.replace(/\W/g, "-"));
            };
        })(this));

        var $collapse = this.$(this.config.collapse.className);

        $collapse.on("hide", (function(self) {
            return function(event) {
                if(event.target !== this) return;
                $(this).parent().find(self.config.collapse.inputSelector).prop("checked", false);

                var sources = [];
                $(self.config.collapse.inputSelector + ':checked').each(function() {
                    sources.push($(this).attr("value"));
                });
                app.event.eventBus.trigger("change:sources", sources, true);
            };
        })(this));

        $collapse.on("show", (function(self) {
            return function(event) {
                if(event.target !== this) return;
                $(this).parent().find(self.config.collapse.inputSelector).prop("checked", true);

                var sources = [];
                $(self.config.collapse.inputSelector + ':checked').each(function() {
                    sources.push($(this).attr("value"));
                });
                app.event.eventBus.trigger("change:sources", sources, true);
            };
        })(this));

        self.$('.showHideExplore').on('click', this.toggleButton);

        return this;

    },

    toggleButton: function() {

        if(this.innerHTML.indexOf("more") >=0) {
            this.innerHTML = "Show less";
        } else {
            this.innerHTML = "Show more (" + this.dataset.sensors + " more sensors)";
        }

   }

});
app.view.ExploreByCustomView = Backbone.View.extend({
    initialize: function (options) {
        var self = this;
        this.config = options.config;
        this.elementID = options.elementID;
        _.bindAll(this, "render");

        this.template = _.template($(this.config.templateID).html());

        if (_.isArray(this.config.modalsID)) {
            this.modals = _.map(this.config.modalsID, function (template) {
                return _.template($(template).html())();
            });
        } else if (this.config.modalsID) {
            // setting showModal to true will enable the info icon in the explore_custom template
            this.showModal = true;
            this.modals = _.template($(this.config.modalsID).html())();
        }


        this.firstGroup = this.config.groupingOrder[0];
        this.lastGroup = this.config.groupingOrder[this.config.groupingOrder.length - 1];
        this.primaryCollection = this.config.primaryCollection || this.firstGroup;
        this.config.collectionGroupingFunctionArguments = this.config.collectionGroupingFunctionArguments || '';

        app.event.eventBus.on("change:" + self.elementID, function (models) {
            if (models && models.length) {
                if ($('#' + self.elementID).find('.data-nav-header-active').length) {
                    var filteredModels = app.collection[self.lastGroup].filter(function (model) {
                        var huc;
                        switch (self.firstGroup) {
                            case "categories":
                                var cats = new Backbone.Collection;
                                model.get('parameters').each(function (p) {
                                    _.each(p.get('categories'), function (cat) {
                                        cats.add(cat)
                                    })
                                });
                                return _.intersection(cats.pluck('id'), models).length;
                                break;
                            case "parameterCategories":
                                return _.intersection(model.get('parameters').pluck('id'), models).length;
                                break;
                            case "parameters":
                                return _.intersection(model.get(self.firstGroup).pluck('id'), models).length;
                                break;
                            case "sources":
                                return _.contains(models, model.get('type')['id']);
                                break;
                            case "regions":
                            case "areas":
                                return _.contains(models, model.get('region'));
                                break;
                            case "river-reaches":
                                return _.contains(models, model.get('river-reaches'));
                                break;
                            case "huc2":
                                huc = model.get('huc');
                                if (huc && huc['huc2'] && _.contains(models, huc['huc2']['code'])) {
                                    return model;
                                } else {
                                    return false;
                                }
                            case "huc4":
                                huc = model.get('huc');
                                if (huc && huc['huc4'] && _.contains(models, huc['huc4']['code'])) {
                                    return model;
                                } else {
                                    return false;
                                }
                            case "huc6":
                                huc = model.get('huc');
                                if (huc && huc['huc6'] && _.contains(models, huc['huc6']['code'])) {
                                    return model;
                                } else {
                                    return false;
                                }
                            case "huc8":
                                huc = model.get('huc');
                                if (huc && huc['huc8'] && _.contains(models, huc['huc8']['code'])) {
                                    return model;
                                } else {
                                    return false;
                                }
                            default:
                                return false;
                        }

                    });
                    if (filteredModels && filteredModels.length) {
                        var filteredModelsToJSON = _.map(filteredModels, function (model) {
                            return model.toJSON();
                        });
                        app.view.exploreMapView.setGeoJsonFeature(filteredModelsToJSON, self.config.map);
                        app.view.exploreMapView.render(self.config);
                    }

                }
            }
        });

    },

    render: function () {
        var self = this;

        if (app.collection[self.primaryCollection] && app.collection[self.primaryCollection].length > 0) {
            var checkedCollectionItems = new Backbone.Collection;

            if ($('input[name="collection"]').length == 0) {
                app.collection[self.primaryCollection].each(function (model) {
                    checkedCollectionItems.add({id: model.get('id')});
                });
            } else {
                $('input[name="collection"]:checked').each(function () {
                    checkedCollectionItems.add({id: $(this).attr("value")});
                });
            }

            this.$el.empty();

            app.collection[self.primaryCollection][self.config.collectionGroupingFunction](self.config.collectionGroupingFunctionArguments).forEach(function (model) {
                // if models.json hasn't been filled out, the default will be an empty template that we shouldn't render
                if (model.id) {
                    if (checkedCollectionItems.contains(model.id)) model.set('checked', "checked");
                    self.$el.append(self.template({
                        model: model.toJSON(),
                        grouping: self.config.groupingOrder,
                        showModal: (self.showModal ? self.showModal : false)
                    }));
                }
            });
            app.event.eventBus.trigger("change:" + self.elementID, checkedCollectionItems.pluck('id'));

        } else {
            // display placeholder text if no sources are found
            if (app.config[self.primaryCollection]) {
                this.$el.html(app.config[self.primaryCollection].noneFound);
            } else {
                this.$el.html("No models found.");
            }

        }

        if (this.modals) {
            this.$el.append(this.modals);
        }


        var $explorePills = this.$(".explore-pill");
//       $explorePills.tooltip(this.config.pills.tooltipOptions); // enable bootstrap tooltips

        // fires events to highlight or unhighlight map pins
        $explorePills.hover(function (self) {
            return function (event) {
                app.event.eventBus.trigger("marker:mouseover", event.currentTarget.value.replace(/\W/g, "-"));
            };
        }(this), function (self) {
            return function (event) {
                app.event.eventBus.trigger("marker:mouseout", event.currentTarget.value.replace(/\W/g, "-"));
            };
        }(this));

        $explorePills.on("click", (function (self) {
            return function (event) {
                app.event.eventBus.trigger("marker:click", event.currentTarget.value.replace(/\W/g, "-"));
            };
        })(this));

        /* Keep the checkboxes in sync with the collapsed accordion
         * checked - accordion open
         * unchecked - accordion closed
         * not happy with this solution.
         * In the future the EPA wants the checkboxes to be displayed,
         * the checkboxes should determine which pins are on the map.
         * TODO : see GEO-258
         */
        var $collapse = this.$('.collapse');

        $collapse.on("hide", (function (self) {
            return function (event) {
                if (event.target !== this) return;
                $(this).parent().find('input[name="collection"]').prop("checked", false);

                var collectionItems = new Backbone.Collection;
                self.$('input[name="collection"]:checked').each(function () {
                    collectionItems.add({id: $(this).attr("value")});
                });
                app.event.eventBus.trigger("change:" + self.elementID, collectionItems.pluck('id'));
            };
        })(this));

        $collapse.on("show", (function (self) {
            return function (event) {
                if (event.target !== this) return;
                $(this).parent().find('input[name="collection"]').prop("checked", true);

                var collectionItems = new Backbone.Collection;
                self.$('input[name="collection"]:checked').each(function () {
                    collectionItems.add({id: $(this).attr("value")});
                });
                app.event.eventBus.trigger("change:" + self.elementID, collectionItems.pluck('id'));
            };
        })(this));

        self.$('.showHideExplore').on('click', this.toggleButton);
        return this;
    },

    toggleButton: function () {
        if (this.innerHTML.indexOf("more") >= 0) {
            this.innerHTML = "Show less";
        } else {
            this.innerHTML = "Show more (" + this.dataset.sensors + " more sensors)";
        }

    }
});
app.view.ExploreAccordionItemView = Backbone.View.extend({
    className: 'accordion-group',

    initialize: function (options) {
        var self = this;
        _.bindAll(this, "render", "renderAccordionContents");
        // these items are used to construct the template
        this.template = _.template($(options.template).html());

        // these items are passed into the template
        this.options = options;
        this.id = options.attributes.id;
        this.title = options.title;
        this.defaultOpen = options.defaultOpen;
        this.showStationLegend = options.showStationLegend;
        this.showHeader = (_.isBoolean(options.showHeader)) ? options.showHeader : true;
        this.subviewID = (options.contents && options.contents.containerID) ? options.contents.containerID : "";

        this.render();
        if (this.showHeader) {
            this.$el.on('show', function (event) {
                if (event.target.id === 'accordion-nav-collapse-' + self.id) {
                    $(this).find('.accordion-heading.data-nav-header').addClass('data-nav-header-active');
                }
            });
            this.$el.on('hide', function (event) {
                if (event.target.id === 'accordion-nav-collapse-' + self.id) {
                    $(this).find('.accordion-heading.data-nav-header').removeClass('data-nav-header-active');
                }
            });
        }
    },

    render: function () {
        var self = this;
        // all model properties are directly available to this.template (defined above)
        this.$el.empty();
        this.$el.html(this.template({
            id: this.id,
            title: this.title,
            defaultOpen: this.defaultOpen,
            showStationLegend: this.showStationLegend,
            subviewID: this.subviewID,
            showHeader: this.showHeader
        }));

        this.renderAccordionContents();
        this.$('#accordion-nav-collapse-' + this.id).on('shown', function () {
            if (self.id === "sources") {
                app.event.eventBus.trigger("change:" + self.id, false, true);
            } else {
                app.event.eventBus.trigger("change:" + self.id);
            }
        });

        if (this.defaultOpen) {
            app.event.eventBus.trigger('change:' + this.id);
        }

        return this;
    },

    renderAccordionContents: function () {
        var config = this.options.contents;
        var elementID = this.options.attributes.id;

        if (config && config.viewType && config.viewConfig && app.view[config.viewType]) {
            var view = new app.view[config.viewType]({config: config.viewConfig, elementID: elementID});
            this.$("#" + config.containerID).append(view.render().el);
        }

        return this;
    }
});
app.view.ExploreTrendsCollectionView = Backbone.View.extend({
//    tagName : "div",
//    className : "accordian",

    initialize: function(options) {
        this.config = options.config;
        this.selected = this.config.selected;
        this.collection = [];
        this.render();
    },

    render : function() {
        var self = this;

        if (app.collection.parameters.length > 0) {

            this.$el.empty();
            this.collection.forEach(function(subView) {
              subView.remove();
              subView.unbind();
              if (subView.close) subView.close();
            });

            //Removed the depth parameters until Medici can handle depth parameter calculations
            app.collection.parameters.where({exploreView: "visible", detailView: "time"}).forEach(function(parameter) {
              if (self.config.filterFunction && typeof self.config.filterFunction == 'function') {
                if (!self.config.filterFunction(parameter)) {
                  return;
                }
              }
              // don't show parameters in the list if they don't have any sensors
                if (parameter.id && parameter.get('sensors') && parameter.get('sensors').length) {
                    var selected = false;
                    if (self.selected && (parameter.get('title') == self.selected)) {
                      selected = true;
                    }
                    var itemView = new app.view.ExploreTrendsItemView({ model: parameter, selected: selected });
                    self.collection.push(itemView);
                    self.$el.append(itemView.render().el);
                }
            });
        } else {
            // display placeholder text if no sources are found
            this.$el.html(app.config.parameters.noneFound);
        }
        return this;
    }


});

app.view.ExploreTrendsItemView = Backbone.View.extend({

    attributes: function() {
        return {
          class: 'btn parameter-trend',
          'data-id': this.model.id,
          'data-title': this.model.get('title').replace(/<(.*?)>/g, '')
        }
    },
    events: {
        'click': 'clickItem'
    },

    initialize : function(options) {
        var self = this;
        _.bindAll(this, "redrawMapArrows");
        this.model = options.model;
        this.selected = options.selected;
        this.geostreamService = app.model.geoStreamService;
        this.template = _.template(this.model.get('title').replace(/<(.*?)>/g, ''));

        app.event.eventBus.on("trends:redrawMapArrows:" + self.model.get('id'), function(season) {
            var activeParameterModel = self.getActiveParameterModel();
            if (activeParameterModel.get('id') == self.model.get('id')) {
              self.redrawMapArrows(null, season);
            }

        });

        app.event.eventBus.on('trends:changeLegendTitle', function(parameter) {
            if (parameter) {
              self.getActiveParameterModel(parameter, function(parameterModel) {
                  self.changeLegendTitle(parameterModel.get('title'));
              });
            }
        });

        this.render();
    },

    close: function() {
        app.event.eventBus.off('trends:redrawMapArrows');
    },

    render : function() {
        var sensors = this.model.get('sensors');
        if (sensors.length > 0) {
            this.$el.empty();
            this.$el.html(this.template);
        }
//        if (this.selected) {
//            this.$el.trigger('click');
//        }
        return this;
    },

    clickItem: function(event) {
        event.cancelBubble = true;
        var self = this;
        if (event) {
          $('.parameter-trend').removeClass("parameter-trend-active");
          $(event.target).addClass('parameter-trend-active');
          var parameterID = $(event.target).data('id');
          if (self.model.get('id') != parameterID) return;

          var parameterModel = app.collection.parameters.findWhere({id: parameterID});

          self.redrawMapArrows(parameterID);

          app.event.eventBus.trigger("change:trends", self.model.get('sensors'), parameterModel.get('title'));
        }
    },

    redrawMapArrows : function(parameter, season) {
        app.event.eventBus.trigger("explore:map:spinner:start");

        var self = this;

        parameter = self.getActiveParameterModel(parameter);

        if (self.model.get('id') != parameter.get('id')) {
            return;
        }

        self.changeLegendTitle(parameter.get('title'));

        season = self.getActiveSeason(season);

        var attr_str = $.param({attributes: this.model.get('id') }, true);
        this.geostreamService.getTrend(attr_str, season, function(sensors, parameterTitle){
            app.event.eventBus.trigger("change:trends", sensors, parameterTitle);
            app.event.eventBus.trigger("explore:map:spinner:stop");
        });



    },

    getActiveParameterModel: function(parameterID, callback) {
      var parameterElement = $('.parameter-trend-active');
      if (parameterElement) {
        parameterID = parameterID || ((parameterElement.data('id')) ? parameterElement.data('id') : null);
        if (parameterID) {
          var parameter = app.collection.parameters.findWhere({id: parameterID});
        }
      }
      if (typeof callback == 'function') {
          callback(parameter);
      } else {
          return parameter;
      }

    },

    getActiveSeason: function(season) {
        // TODO this should not be using app.config.binning.time since the dropdown isn't being used to 'bin'
        // like the TODO in the ExploreMapView, this should probably be moved to app.config.views.trendMap or similar
        season = season || $('#trends-map-season-control-div').find('select').val() ||
            ((getBinningDesignators(app.config.binning.time).items && getBinningDesignators(app.config.binning.time).items[0]) ? getBinningDesignators(app.config.binning.time).items[0].id : 'spring');
        return season;
    },

    changeLegendTitle: function(title) {
      if (title) {
        $("#trends-map-legend-title-info").html(title);
      }
    }


});

app.view.LayerItemView = Backbone.View.extend({
    tagName: 'div',
    className: "toggleLayerView",
    attributes: function() {
        return {
            id : "layer-" + this.model.get("id")
        }
    },

    events: {
        //"click input": 'check',
        "click .layer-radio": 'check',
        "change .layer-opacity" : "updateOpacity"
    },


    initialize: function(options) {
        // the whole model gets passed to this template as "model", so we can directly use any values we need like "model.id"
        this.template = _.template($('#explore-layers-template').html());

        this.layers = options.layers;
//    	layers: 'sf:USRB_30m_DEM',
//        format: 'image/png',
//        transparent: true,
//        opacity: 0.75
//
        this.shapeOptions = {
            stroke: true,
            color: '#f06eaa',
            weight: 4,
            opacity: 0.5,
            fill: true,
            fillColor: null, //same as color by default
            fillOpacity: 0.2,
            clickable: true
        };

        var self = this;
        return this;
    },

    render: function() {
        // all model properties are directly available to this.template (defined above)
        var self = this;
        this.$el.empty();

        this.$el.html(
            this.template({
                checked: (this.model.get('properties').checked) ? "checked" : '',
                group: this.model.get('group') || '',
                showLayerLegend: this.model.get('properties').showLayerLegend,
                layerLegendStartOpen: this.model.get('properties'). layerLegendStartOpen,
                layerLegendTitle: this.model.get('properties').layerLegendTitle,
                layerLegendContents: this.model.get('properties').layerLegendContents,
                id: this.model.get('properties').id,
                title: this.model.get('properties').title,
                opacity: this.model.get('properties').opacity || 0.5,
                legend: this.model.get('properties').legend
            })
        );
        return this;
    },

    // this function handles the action of actually clicking the div for this Area - like "checking" an input box
    check: function(event) {
        var self = this;

        var checkedState = this.model.get("checked");
        this.model.set("checked", !(checkedState));
        app.event.eventBus.trigger("change:layer", this.model);
    },

    updateOpacity: function(event) {
        this.model.get("properties").opacity = $(event.currentTarget).val();
        app.event.eventBus.trigger("change:layer:opacity", this.model);
    },

    selectLayer : function(event) {
        //var self = this;
        //var geometry = self.model.get("geometry");
        //var points = geometry.coordinates[0].map(function(x) { return L.latLng(x[1], x[0]); });
        //app.event.eventBus.trigger("map:polygon:select", {'points': points});
        //var polygon = L.polygon(points, self.shapeOptions);
        //self.model.set("polygon", polygon);
        //polygon.addTo(app.view.advancedSearchView.drawnItems);
    }
});

app.view.LayersGroupView = Backbone.View.extend({
    initialize: function(options) {
        this.layers = options.layers;
        this.group = options.group;

        this.template = _.template($('#explore-layers-groups-template').html());
        this.$el.empty();
        this.$el.html(
            this.template({
                group: this.group
            })
        );

        return this;
    },

    render: function() {
        var self = this;

        var group_id = this.group.replace(/ /g, '-');

        var templateClass = ("#explore-layers-group-" + group_id);
        _.each(this.layers, function(model) {
            self.append(templateClass, model);
        });

        return this;
    },

    append: function(templateClass, model) {
        this.$(templateClass).append(new app.view.LayerItemView({model: model}).render().el);
    }
});

app.view.LayersCollectionView = Backbone.View.extend({
    initialize: function() {
        this.collection = app.collection.layers;
        this.listenTo(this.collection, 'add', this.append, this);
        this.listenTo(this.collection, 'remove', this.render, this);
    },


    render: function() {
        var self = this;
        this.$el.empty();


        // append each of the areas to the view (like adding "li" elements to a "ul")...
        _.each(this.collection.models, function(model) {
            self.append(model);
        });


        return this;
    },


    append: function(model) {
        this.$el.append(new app.view.LayerItemView({model: model}).render().el);
    }
});
app.view.LayersCollectionGroupView = Backbone.View.extend({

    initialize: function() {
        this.collection = app.collection.layers;
        this.listenTo(this.collection, 'add', this.append, this);
        this.listenTo(this.collection, 'remove', this.render, this);
        this.layerGroupsToCreate = [];
        this.layersWithGroups = [];

        var self = this;

        // Get all Groups for Layers
        _.each(this.collection.models, function(model) {
            if (model.get('group')) {
                var layerIndex =  self.layerGroupsToCreate.indexOf(model.get('group'));
                if (layerIndex === -1) {
                    self.layerGroupsToCreate.push(model.get('group'));
                }
                self.layersWithGroups.push(model);
            }
        });
    },

    render: function() {
        var self = this;
        this.$el.empty();

        // Layers with Groups
        _.each(self.layerGroupsToCreate, function(group) {

            var layers = [];

            _.each(self.layersWithGroups, function(layer) {
                if (layer.get('group') === group) {
                    layers.push(layer);
                }
            });

            self.group(group, layers);

        });

        // Layers without Groups
        _.each(this.collection.models, function(model) {

            if (!model.get('group')) {
                self.append(model);
            }

        });

        return this;
    },

    group: function(group, layers) {
        // Pass the Groups with Layers Only, and only those Layers with Groups
        this.$el.append(new app.view.LayersGroupView({group: group, layers: layers}).render().el);
    },

    append: function(model) {
        // Non-Group Layers
        this.$el.append(new app.view.LayerItemView({model: model}).render().el);
    }

});

// this "view" controls how we list one specific Area on the Search page (like "Lake Michigan")
// each Area is a model, and this view ties that model to the UI
// AreaListView (below) does the job of inserting all of these views
// think of AreaView as an "li" and AreaListView is the "ul"
if (app.config.useV3 == false) {
    app.view.AreaItemView = Backbone.View.extend({
        tagName: 'div',
        className: "areaView",
        attributes: function () {
            return {
                id: "area-" + this.model.get("id")
            }
        },

        events: {
            "click": 'check'
        },

        initialize: function () {

            // the whole model gets passed to this template as "model", so we can directly use any values we need like "model.id"
            this.template = _.template($('#search-areas-template').html());

            this.shapeOptions = app.config.views.search.shapeOptions || {
                    stroke: true,
                    color: (app.config.areas && app.config.areas.shapeOptions && app.config.areas.shapeOptions.color) ? app.config.areas.shapeOptions.color : '#7eb4fc',
                    weight: 4,
                    opacity: 0.5,
                    fill: true,
                    fillColor: null, //same as color by default
                    fillOpacity: 0.2,
                    clickable: true
                };

            this.model.on("change", this.render, this);

            return this;
        },

        render: function () {
            // all model properties are directly available to this.template (defined above)
            var self = this;
            // if the area does not contain a geometry property, it won't be able to draw a region, so don't show it as an option to check
            if (this.model.get('geometry')) {
                this.$el.empty();
                this.$el.html(this.template({area: this.model.toJSON()}));
            }


            return this;
        },

        // this function handles the action of actually clicking the div for this Area - like "checking" an input box
        check: function (event) {

            // since we are using a radio input, "uncheck" all other areas
            app.collection.areas.clearSelection();
            this.model.set({
                checked: true,
                selected: true
            });
            this.selectLake(event);

            // always update the buttons when something gets checked
            app.view.searchView.updateDownloadLink();
        },

        selectLake: function (event) {
            var self = this;
            var geometry = self.model.get("geometry");
            if (!geometry) {
                return;
            }
            var points = geometry.coordinates[0].map(function (x) {
                return L.latLng(x[1], x[0]);
            });
            app.event.eventBus.trigger("map:polygon:select", {'points': points});
            var polygon = L.polygon(points, self.shapeOptions);
            self.model.set("polygon", polygon);
            polygon.addTo(app.view.searchView.drawnItems);

            // zoom into area if zoomInOnClick is set to true
            if (app.config.areas.zoomInOnClick) {
                app.view.searchView.map.fitBounds(points, {padding: [50, 50]});
            }

        }
    });
}

if (app.config.useV3 == false) {
    app.view.AreasCollectionView = Backbone.View.extend({

        initialize: function(options) {
            if (this.collection) {
                this.listenTo(this.collection, 'add', this.append, this);
                this.listenTo(this.collection, 'remove', this.render, this);
            }
            this.collapsibleGroupTemplate = _.template($('#search-area-group-template').html());
        },

        render: function() {
            var self = this;
            // if there are areas, create a list of them.
            // if there is only one area, make sure it isn't an empty one from the default app.config.areas.items
            if (this.collection && this.collection.length > 0) {
                this.$el.empty();

                // append each of the areas to the view (like adding "li" elements to a "ul")...
                this.collection.each(function(model) {

                    // if this view was created from a app.config.areas.groups, it will contain items
                    // and should nest them in a collapsible element
                    if (model.get('items') && model.get('items').length > 0) {
                        self.$el.append('<div class="accordion searchAreaGroup" id="searchAreaGroup-' + model.get('title').replace(/ /g, '-') + '">');

                        // create an array of the item views so that we can attach them to the DOM
                        // if you try to attach them inside of the template function, their events won't fire
                        var itemElements = model.get('items').map(function(item) {
                            return new app.view.AreaItemView({model: item});
                        });

                        self.$('#searchAreaGroup-' + model.get('title').replace(/\W/g, '-')).append(self.collapsibleGroupTemplate({
                            title: model.get('title'),
                            parent: "searchAreaGroup-" + model.get('title').replace(/\W/g, '-')
                        }));

                        // now attach items to the dom, preserving events
                        _.each(itemElements, function(item) {
                            self.$('#accordion-inner-' + model.get('title').toLowerCase().replace(/ /g, '-')).append(item.render().el);
                        });

                        self.$el.append('</div>');
                    } else {
                        self.append(model);
                    }
                });

            } else {
                // if this is seen, you need to define a FeatureCollection in /assets/layers/layers.json
                this.$el.html("<p>" + app.config.areas.noneFound + "</p>");
            }

            return this;
        },

        append: function(model) {
            this.$el.append(new app.view.AreaItemView({model: model}).render().el);
            return this;
        }
    });
}
// this "view" controls how we list one specific Parameter on the Search page (like "Chlorophyl a")
// each Parameter is a model, and this view ties that model to the UI
// ParameterListView (below) does the job of inserting all of these views
if (app.config.useV3 == false) {
    app.view.ParameterItemView = Backbone.View.extend({
        events: {
            "click :checkbox": 'check'
        },

        render: function () {
            // all model properties are directly available to this.template (defined above)
            this.$el.empty();
            this.$el.html(this.template({
                model: this.model.toJSON(),
                view: this.view
            }));

            return this;
        },

        initialize: function (options) {
            // the whole model gets passed to this template, so we can directly use any values we need
            this.template = _.template($('#search-parameters-template').html());

            this.view = options.view;

            _.bindAll(this, "check");
            this.model.on("change", this.render, this);

            return this;
        },

        check: function () {
            app.event.eventBus.trigger("check:parameter", {view: this.view, model: this.model});
        }

    });
}
if (app.config.useV3 == false) {
    app.view.ParametersCollectionView = Backbone.View.extend({

        initialize: function(options) {
            this.config = options;
            this.view = options.view;
            this.listenTo(this.collection, 'add', this.append, this);
            this.listenTo(this.collection, 'remove', this.render, this);

        },

        append: function(model) {
            if (model.id) {
                this.tagName = (this.config.itemOptions && this.config.itemOptions.tagName) ? this.config.itemOptions.tagName : "div";
                this.className = (this.config.itemOptions && this.config.itemOptions.className) ? this.config.itemOptions.className : "parameters";
                this.$el.append(new app.view.ParameterItemView({
                    model: model,
                    view: this.view,
                    tagName: this.tagName,
                    className: this.className
                }).render().el);
            }
        },

        render: function() {
            var self = this;
            // if there are parameters, create a list of them.
            // if there is only one parameter, make sure it isn't an empty one from the default parameters.json
            if (this.collection.length > 1 || (this.collection.length == 1 && this.collection.models[0].id)) {
                this.$el.empty();

                // append each of the parameter Views
                _.each(this.collection.models, function(model) {
                    if (model.get(self.view) != "ignore") {
                        self.append(model);
                    }
                });
            } else {
                // if you are seeing this error, you need to specify the parameters you want to shown in /public/data/parameters.json
                this.$el.html(app.config.parameters.noneFound)
            }
            return this;
        }

    });
}
// this "view" controls how we list one specific Data Source on the Search page (like "WATER QUALITY (epa)")
// each Data Source is a model, and this view ties that model to the UI
// SourcesView (below) does the job of inserting all of these views
// think of SourceView as an "li" and SourcesView is the "ul"
if (app.config.useV3 == false) {
    app.view.SourceItemView = Backbone.View.extend({
        tagName: 'tr',
        className: "sourceView",

        events: {
            // TODO: Need to create a progress bar icon on the map.
            "click [type='checkbox']": 'check'
        },

        initialize: function() {
            var self = this;
            // the whole model gets passed to this template as "model", so we can directly use any values we need like "model.id"
            this.template = _.template($('#search-sources-template').html());
            this.eventBus = app.event.eventBus;

            // TODO: add a loading gif on the map
            this.eventBus.on("map:loading:start", function() {
                $('#loading').removeClass("hidden");
            });

            // TODO: add a loading gif on the map
            this.eventBus.on("map:loading:stop", function() {
                $('#loading').addClass("hidden");
            });

            this.model.on("change", this.render, this);

            return this;
        },

        render: function() {
            // all model properties are directly available to this.template (defined above)
            var self = this;

            this.$el.empty();
            this.$el.html( this.template( { model: this.model.toJSON() } ) );

            return this;
        },

        // updates the colored badge with the number of sensors selected on the map
        renderSelectedCount: function() {
            // in the template above, we're assigning the colored badge an "id": sensors-epa-selected
            var id = "#sensors-" + this.model.get('id') + "-selected";
            // the selected() function returns the number of sensors whose selected attribute is true
            $(id).html(this.model.getSelectedSensors().length);
        },

        // this function handles the action of actually clicking the div for this Data Source - like "checking" an input box
        check: function() {
            var self = this;

            self.eventBus.trigger("map:loading:start");

            // when you "check" the Data Source, it will highlight only the sensors that are "selectable".
            // if the user hasn't drawn a region on the map, everything is selectable. But if the user has drawn a region,
            // only those sensors will be selectable
            var allSelectableSensors = app.collection.sensors.getSelectableSensors();
            var sourceSelectableSensors = self.model.getSelectableSensors();
            var areasChecked = app.collection.areas.getChecked();

            // we have to do this next step because if you look at the sensor.js file, each sensor's isChecked function
            // listens to areaChecked, sourceChecked or parameterChecked to determine if it should show its color marker
            // I'd rather not do this, because after you uncheck a source, the sensor's areaChecked doesn't go back to true
            // and the sensor won't draw its color marker again, even though the area has selected it, but I don't see any other way around this yet.
            if (areasChecked) {
                _.each(allSelectableSensors, function(sensor) {
                    sensor.set("areaChecked", false);
                });
            }

            // the model is currently checked...
            if (this.model.get("checked")) {
                // "uncheck" it...
                this.model.set("checked", false);

                // ...then deselect each of its sensors...
                _.each(sourceSelectableSensors, function(sensor) {
                    sensor.set("sourceChecked", false);
                });

            } else { // this model was not "checked"
                // "check" it...
                this.model.set("checked", true);

                // ...select each of its "selectable" sensors
                _.each(sourceSelectableSensors, function(sensor) {
                    sensor.set("sourceChecked", true);
                });

            }
            // always update the buttons when something gets checked
            app.view.searchView.updateDownloadLink();

            self.eventBus.trigger("map:loading:stop");


        }
    });
}

if (app.config.useV3 == false) {
    app.view.SourcesCollectionView = Backbone.View.extend({
        el: "table#searchSourcesView",
        className: 'lite-1',

        initialize: function() {
            this.listenTo(this.collection, 'add', this.append, this);
            this.listenTo(this.collection, 'remove', this.render, this);
        },

        render: function() {
            var self = this;
            // if there are sources, create a list of them.
            // if there is only one source, make sure it isn't an empty one from the default sources.json
            if (this.collection.length > 1 || (this.collection.length == 1 && this.collection.models[0].id)) {
                this.$el.empty();

                // append each of the sources to the view (like adding "li" elements to a "ul")...
                _.each(this.collection.models, function(model) {
                    self.append(model);
                });
            } else {
                this.$el.html(app.config.sources.noneFound);
            }

            return this;
        },

        append: function(model) {
            if (model.id){
                this.$el.append(new app.view.SourceItemView({model: model}).render().el);
            }

        }
    });
}

// this view is an experiment to see if we can bind a sensor directly to the map 
// so that it shows up when the model property "selected" changes
// UPDATE: this is working - it is being called at the bottom of SearchView
if (app.config.useV3 == false) {
    app.view.SensorItemView = Backbone.View.extend({

        initialize: function() {

            // get the color value from this sensor's Data Source
            // stored in app.config.sources - each source has a color
            var sourceModel = app.collection.sources.findWhere({id: this.model.get('type').id });
            var sourceColor = (sourceModel && sourceModel.get('color')) ? sourceModel.get('color') : 'blue';
            var geojsonMarkerOptions = {
                radius: 2,
                fillColor: sourceColor,
                color: sourceColor,
                weight: 5,
                opacity: 1,
                fillOpacity: 1
            };

            var geoJsonLayer = L.geoJson(this.model.toJSON(), {
                onEachFeature: function (feature, layer) {
                    layer.bindPopup("<div class='search-popup'>"+feature.name+'</div>');
                },
                pointToLayer: function (feature, latlng) {
                    return L.circleMarker(latlng, geojsonMarkerOptions);
                }
            });

            // we set this marker on the model so that we can use Leaflet's "bringToFront" function when switching between Pages
            this.model.set("marker", geoJsonLayer);
            this.listenTo(this.model, "change:selected", this.render, this);
            this.listenTo(this.model, "change:checked", this.render, this);
        },

        render: function() {
            if (this.model.get("checked")) {
                this.model.get("marker").addTo(app.view.searchView.map);
            } else {
                app.view.searchView.map.removeLayer(this.model.get("marker"));
            }

        }
    });
}
// this View gets created by SearchView.renderSensorViews as a "container" for the Sensor views
// it prevents them from getting recreated when switching between Explore and Search
app.view.SensorsCollectionView = Backbone.View.extend({
    render: function() {
        var selected = this.collection.selected();
        _.each(selected, function(sensor) {
            // the marker gets added to the sensor model when the sensor view is created in sensor.js
            // bringToFront() is a Leaflet function
            sensor.get("marker").bringToFront();
        });
    }
});
app.view.HomeView = Backbone.View.extend({
    id: 'home-view',

  initialize: function(options) {
    var self = this;
    this.mapPin = options.mapPin;
    this.router = options.router;
    this.stationService = options.stationService;
    this.config = options.config;
    this.explore = options.config.explore;
    this.accordionItems = [];
    this.mapConfigs = {};
    this.selection = {};

    this.render = _.bind(this.render, this);
    this.$el.append(_.template($("#explore-template").html())());

    if (this.explore.accordion && this.explore.accordion.items && this.explore.accordion.items.length) {
        _.each(this.explore.accordion.items, function(accordionItem) {
            // inherit options from the accordion if not specified
            accordionItem.template = '#explore-accordion-item-template';
            accordionItem.attributes.class = 'accordion-group';

            var accordionItemView = new app.view.ExploreAccordionItemView(accordionItem);

            self.$('#explore-accordion-container').append(accordionItemView.el);
            self.accordionItems.push(accordionItemView);
            if (accordionItem.contents && accordionItem.contents.viewConfig && accordionItem.contents.viewConfig.map) {
                self.mapConfigs[accordionItem.attributes.id] = accordionItem.contents.viewConfig.map;
                self.mapConfigs[accordionItem.attributes.id].title = accordionItem.attributes.id;
                self.selection[accordionItem.attributes.id] = {};
            }
        });
    }

    app.view.exploreMapView = new app.view.ExploreMapView({
      parentView : this,
      geoJsonFeature : [],
      mapOptions: this.explore.map
    });

    this.$("#explore-map-view").append(app.view.exploreMapView.el);

    if(self.mapConfigs['trends'] && self.mapConfigs['trends'].aboutTrendData) {
      this.$el.append(_.template($(self.mapConfigs['trends'].aboutTrendData).html())());
    }

    // catch event fired by explore-pill or map-pin clicks
    // use this to fire the detail page route.
    app.event.eventBus.bind("sensors:refresh", (function(self) {
        return function() {
            _.each(self.accordionItems, function(accordionItem) {
                accordionItem.render();
            });
          self.render();
        };
    })(this));

    app.event.eventBus.on("change:trends", function(sensors, parameterTitle) {
        if ($('#trends').find('.data-nav-header-active').length) {
          if (sensors) {
            sensors = _.isArray(sensors) ? new Backbone.Collection(sensors) : sensors;
            self.selection.trends.sensors = sensors;
          } else  {
            sensors = self.selection.trends.sensors || app.collection.sensors;
          }

          if (parameterTitle) {
            self.selection.trends.parameter = parameterTitle;
          }

          var parameterModel = app.collection.parameters.findWhere({title: self.selection.trends.parameter});
          if (parameterModel) {
            app.event.eventBus.trigger('trends:changeLegendTitle', parameterModel.get('id'));
          }

          app.view.exploreMapView.setGeoJsonFeature(sensors.toJSON(), self.mapConfigs['trends'], self.selection.trends.parameter);
          app.view.exploreMapView.render(self.mapConfigs['trends']);

        }
    });

  },

  render: function(options) {
      var checkedSources = [];
      var sensors, visibleSensors;

      $('input[name="source"]:checked').each(function() {
        checkedSources.push($(this).attr("value"));
      });

      if (checkedSources.length) {
        sensors = app.collection.sensors.filter(function(sensor) {
          return _.contains(checkedSources, sensor.get('type').id);
        });
      } else {
        sensors = app.collection.sensors.models;
      }

      visibleSensors = _.map(sensors, function(sensor) {
        return sensor.toJSON();
      });
      app.view.exploreMapView.setGeoJsonFeature(visibleSensors, options);
      var self = this;
      _.each(app.config.sources.items, function(source) {
          self.$('#about-' + source.id + '-modal').draggable({handle: '.modal-header'});
      });

  }
});

app.view.LimnologyView = Backbone.View
    .extend({
      tagName : 'div',
      id : 'main-graphs',
      className : 'v11n-title',

      initialize : function() {
        this.render = _.bind(this.render, this);

        this.data = [];

        // d3.dispatch handles events passed from d3 charts
        this.dispatch = d3.dispatch("changeDepth");

        // initialize depth app.graphs with height 400, width 300
        this.depthGraph = app.graphs.depth().height(300).width(800)
          .dispatch(this.dispatch);

        // this almost certainly belongs in the detail_view.scala.html
        this.$el.append('<h4 id="depth-profile-title">Depth Profile</h4><div id="timestamp"></div>');
      },

      render : function() {
          var container = d3.select(this.el);
          var graph = container.selectAll(".depth-chart").data(this.data),
          graphEnter = graph.enter().append("div").attr("class", "depth-chart"),
          graphExit = graph.exit().remove();          
          graph.call(this.depthGraph);
      },

      setData : function(data) {
        if (data && data.length > 0) {
          if (data[0].values.length > 0) {
            $("#timestamp").empty();
            this.data = data;
          } else {
            $("#timestamp").text("no data found for " + data[0].key.toUTCString());
            this.data = [];
          }
        } else {
          $("#timestamp").text("no data found");
          this.data = [];
        }
      },

      changeDepth : function(callback) {
        this.dispatch.on("changeDepth", callback);
      }
    });
app.view.MapView = Backbone.View.extend({
      tagName : "div",
      className : "leaflet_map",

      initialize : function(options) {
        this.mapOptions = options.mapOptions;
        this.eventBus = options.eventBus;
        this.mapPin = $('#map-pin-template').html();
        this.mapArrowUp = _.template($('#map-arrow-up-template').html())();
        this.mapArrowDown = _.template($('#map-arrow-down-template').html())();
        this.mapLocation = _.template($('#map-location-template').html())();
        this.mapArrowUpThresh = _.template($('#map-arrow-up-thresh-template').html())();
        this.mapArrowDownThresh = _.template($('#map-arrow-down-thresh-template').html())();


        this.render = _.bind(this.render, this);

        this.map = L.map(this.el, this.mapOptions);

        var mapTileSource = this.mapOptions.mapTileSource || '//{s}.tile.osm.org/{z}/{x}/{y}.png';
        var mapAttribution = this.mapOptions.mapAttribution || '&copy; <a href="http://osm.org/copyright">OpenStreetMap</a> contributors';
        this.tileLayer = L
            .tileLayer(mapTileSource,
                {
                  attribution: mapAttribution,
                  maxZoom: Math.min(16, app.config.views.home.explore.map.maxZoom),
                  maxBounds: app.config.views.home.explore.map.maxBounds,
                  minZoom: app.config.views.home.explore.map.minZoom
                });

        this.tileLayer.addTo(this.map); //check if this is necessary.

        this.setGeoJsonFeature(options.geoJsonFeature);
        return this;
      },

      render : function() {
        this.map.invalidateSize(true);

        if (this.geoJsonLayer) {
            if(app.config.views.home.explore.map.cluster){
                this.markerClusterLayer.clearLayers();
                var markerCluster = L.markerClusterGroup({
                    maxClusterRadius: app.config.views.home.explore.map.clusterSize
                });
                markerCluster.addLayer(this.geoJsonLayer);
                this.map.addLayer(markerCluster);
                this.markerClusterLayer = markerCluster;
            } else {
                this.geoJsonLayer.addTo(this.map);
            }

        }

        return this;
      },

      setGeoJsonFeature : function(geoJsonFeature, parameter) {
        if (this.markerClusterLayer) this.markerClusterLayer.clearLayers();
        if (this.geoJsonLayer) this.map.removeLayer(this.geoJsonLayer);

        if (geoJsonFeature instanceof app.view.SensorsCollectionView) {
            this.geoJsonFeature = geoJsonFeature.toJSON();
        } else {
            this.geoJsonFeature = geoJsonFeature;
        }

        this.markerClusterLayer = L.geoJson(this.geoJsonFeature, this.geoJsonOptions(this, parameter));
        this.geoJsonLayer = L.geoJson(this.geoJsonFeature, this.geoJsonOptions(this, parameter));

      },

      getSourcePin: function(sensor) {
        var source, sourceColor;
        if (sensor && sensor.properties && sensor.properties.type && sensor.properties.type.id) {
          source = app.collection.sources.findWhere({id: sensor.properties.type.id});
          if (source) {
            sourceColor = source.getColor();
            if (sensor.properties.online_status  == "online"){
              return _.template(this.mapPin)({fill: sourceColor, stroke: "green"});
            } else {
              return _.template(this.mapPin)({fill: sourceColor});
            }
          }
        }

        return _.template(this.mapPin)();
      }
});

app.view.ExploreMapView = app.view.MapView.extend({
    tagName : "div",
    className : "leaflet_map",

    markers : {},

    events: {
        'click .btn': 'viewDetails'
    },


    // limits the
    latlngFormat : d3.format(".4f"),

    // this function gets called in MapView.js (we're using MapView.js like a super-class)
    // It is used with: L.geoJson(geoJsonFeature, geoJsonOptions)
    // So this sets the options for the Map, specifically
    geoJsonOptions : function(self, parameter) {
        var pin = {};
        return {
            pointToLayer: function(feature, latlng) {
                pin.template = self.pinTemplate || self.getSourcePin(feature);
                if (self.pinFunction) {
                    pin = self.pinFunction(feature, parameter);
                } else {
                    pin.template = self.getSourcePin(feature);
                }
                var marker = L.marker(latlng, {
                    icon : L.divIcon({
                        html : '<div id="' + ("station-" + feature.properties.name.replace(/\W/g, "-")) + '" class="' + feature.properties.type.id + '">' + pin.template + '</div>'
                    }),
                    title : feature.properties.name,
                    riseOnHover : true
                });

                self.markers["station-" + feature.properties.name.replace(/\W/g, "-")] = marker;
                return marker;
            },
            onEachFeature: function(feature, layer) {

                if (feature.properties && feature.properties.popupContent) {
                    var popupContent = self.populatePopupTemplate(feature, pin.threshold, 'fetching...', ['fetching...']);

                    var sname = "station-" + feature.properties.name.replace(/\W/g, "-")
                    if ((!(sname in self.markers)) && self.map) {
                        var poly = L.polygon(feature.geometry.coordinates, {
                            title : feature.properties.name,
                            riseOnHover : true
                        });
                        self.markers[sname] = poly;
                        poly.addTo(self.map);
                    }

                    layer.bindPopup(popupContent, { autoPanPadding: [30, 30], offset: new L.Point(160, -50)});
                    layer.on("mouseover", function(event) {
                        if(event.originalEvent.target.className.baseVal === "mouseCapture") {
                            self.hoverMarker("station-" + feature.properties.name.replace(/\W/g, "-"));
                        }
                    });
                    layer.on("mouseout", function(event) {
                        if(event.originalEvent.target.className.baseVal === "mouseCapture") {
                            self.unhoverMarker("station-" + feature.properties.name.replace(/\W/g, "-"));
                        }
                    });
                    layer.on("click", function(event) {
                        self.highlightMarker("station-" + feature.properties.name.replace(/\W/g, "-"), self.title);
                    });
                }
            }
        };
    },

    initialize : function(options) {
        var self = this;
        this.options = options;
        this.popupTemplate = _.template($("#map-popup-template").html());

        this.geoStreamService = app.model.geoStreamService = new app.model.GeoStreamService();

        // essesntially super.initialize(options)
        app.view.MapView.prototype.initialize.apply(this, arguments);

        app.event.eventBus.bind("marker:mouseover", (function(self) {
            return function(markerId) {
                markerId = "station-" + markerId;
                self.hoverMarker(markerId);
            };
        })(this));

        app.event.eventBus.bind("marker:mouseout", (function(self) {
            return function(markerId) {
                markerId = "station-" + markerId;
                self.unhoverMarker(markerId);
            };
        })(this));

        app.event.eventBus.bind("marker:click", (function(self) {
            return function(markerId) {
                markerId = "station-" + markerId;

                self.highlightMarker(markerId);
            };
        })(this));

        app.event.eventBus.bind("marker:unclick", (function(self) {
            return function(markerId) {
                markerId = "station-" + markerId;
                self.unhighlightMarker(markerId);
            };
        })(this));


        app.event.eventBus.bind("station:update", (function(self) {
          return function(sensor) {
            var popupContent = self.populatePopupTemplate(sensor);

            self.markers["station-" + sensor.get('name').replace(/\W/g, "-")].setPopupContent(popupContent, { offset: new L.Point(160, -50)});
          };
        })(this));

        $(window).on('scroll', this, function(event) {
            event.data.resizemap(false);
        });

        $(window).on('resize', this, function(event) {
            event.data.resizemap(false);
        });

        app.event.eventBus.bind("change:region", (function(self) {
            return function(regionName) {
                ;
            };
        })(this));

        app.event.eventBus.on("change:layer", (function(self) {
            return function(layerModel) {
                if (layerModel.get("checked")) {
                    layerModel.get("layer").addTo(self.map);
                    if (app.config.layers && app.config.layers.zoomInOnClick) {
                        self.map.panTo(new L.LatLng(layerModel.get("geometry").coordinates[1], layerModel.get("geometry").coordinates[0]));
                    }

                } else {
                    self.map.removeLayer(layerModel.get("layer"));
                }
            }
        })(this));

        app.event.eventBus.on("change:layer:opacity", (function(self) {
            return function(layerModel) {
                var opacity = layerModel.get("properties").opacity;
                layerModel.get("layer").setOpacity(opacity);
            }
        })(this));
    },

    resizemap : function(callrender) {
        // constants, only need to be done once
        var exploreMapViewEl = $("#explore-map-view");
        var header = $("#header");
        if (!this.extra) {
            this.extra = exploreMapViewEl.outerHeight(false) - exploreMapViewEl.height();
            this.padding = 10;
            this.marginheader = parseInt(header.css('margin-bottom'), 10);
        }

        // compute map size and offset
        var windowHeight = $(window).height();
        if (header && header.length) {
            var headerBounds = header[0].getBoundingClientRect();
            var offset = headerBounds.height + this.padding + Math.max(this.marginheader, -headerBounds.height - headerBounds.top);
            var footerTop = $(".footer")[0].getBoundingClientRect().top;
            var height = windowHeight - this.marginheader - 2*this.padding - this.extra - Math.max(0, windowHeight - footerTop) - Math.max(0, headerBounds.bottom);

            // set the map size
            exploreMapViewEl.offset({ top: offset });
            exploreMapViewEl.height(height);

            // render map
            this.map.invalidateSize(true);
            if (callrender) {
                app.view.MapView.prototype.render.apply(this, arguments);
            }
        }

    },

    render : function() {
        if(!this.geoJsonFeature.length) return; //if geoJsonLayer doesn't exist, don't render this view
        // this.geoJsonLayer gets set in MapView.setGeoJsonFeature
        this.map.fitBounds(new L.featureGroup([this.geoJsonLayer]).getBounds().pad(0.05),
            {maxZoom: ((this.options && this.options.map && this.options.map.maxZoom) ? this.options.map.maxZoom : 16)});
        this.resizemap(true);

        if (app.collection.layers && app.collection.layers.length > 0) {
            app.collection.layers.forEach((function(self) {
                return function(layer) {
                    if (!layer.get("initialized")) {
                        layer.set("initialized", true);
                        if (layer.get("checked")) layer.get("layer").addTo(self.map);
                    }
                }
            })(this));
        }
    },
    setGeoJsonFeature : function(geoJsonFeature, options, parameter) {
        if (this.pinFunction) delete this.pinFunction;
        if (options) {
            if (options.popupTemplate) this.popupTemplate = _.template($(options.popupTemplate).html());
            if (options.pinTemplate) this.pinTemplate = _.template($(options.pinTemplate).html())();
            if (options.pinFunction && (typeof this[options.pinFunction] == 'function')) this.pinFunction = this[options.pinFunction];
            if (options.title) this.title = options.title;
            if (options.legend) {
                var legend = _.template($(options.legend).html());
                //Add legend if it doesn't already exist
                if($('#trends-map-legend').length == 0) {
                    $("#explore-map-view").prepend(legend);

                    // TODO this needs to be changed to something more specific
                    // what this is doing is using app.config.binning.time to determine
                    // what to put in the dropdown on the trends map
                    // instead, this should go in something like app.config.views.trendsMap
                    // since it isn't really binning
                    if (app.config.binning.time && app.config.binning.time != 'none') {
                        //Add season drop down
                        if (!app.view.trendsSelectSeason) {
                          app.view.trendsSelectSeason = new app.view.SelectCollectionView({
                            collection: new Backbone.Collection(getBinningDesignators(app.config.binning.time).items),
                            trigger: "trends:redrawMapArrows"
                          });
                        }
                        $("#trends-map-season-control-div").append(app.view.trendsSelectSeason.el);
                        $("select").addClass("trends-map-season-control");
                    }
                    //Add SVG icons.
                    var trendUp = _.template($("#map-arrow-up-template").html());
                    var trendDown = _.template($("#map-arrow-down-template").html());
                    var trendLocation = _.template($("#map-location-template").html());
                    var trendUpThresh = _.template($("#map-arrow-up-thresh-template").html());
                    var trendDownThresh = _.template($("#map-arrow-down-thresh-template").html());

                    $("#trends-map-legend-up-icon").append(trendUp);
                    $("#trends-map-legend-down-icon").append(trendDown);
                    $("#trends-map-legend-no-trend-icon").append(trendLocation);
                    $("#trends-map-legend-threshold-icon-up").append(trendUpThresh);
                    $("#trends-map-legend-threshold-icon-down").append(trendDownThresh);
                }
            } else {
                $('#map-legend').remove();
            }

        }
        if(geoJsonFeature && geoJsonFeature.length) {
            app.view.MapView.prototype.setGeoJsonFeature.call(this, geoJsonFeature, parameter);
        }

        if(this.geoJsonFeature && this.geoJsonFeature.length) {
            this.render();
        }
    },

    hoverMarker: function(markerId) {
        d3.selectAll('#' + markerId + ' svg').attr("class", "map-pin-hover");
    },

    highlightMarker : function(markerId, title) {


        if(app.config.views.home.explore.map.cluster){
            //This addresses when a marker is in a cluster the map zooms so the marker shows up and then opens the popup.
            var m = this.markers[markerId];
            this.markerClusterLayer.zoomToShowLayer(m, function() {
                m.openPopup();
            });
        } else {
            this.markers[markerId].openPopup();
        }


        if (title && (title == 'trends')) {
            this.panToMarker(markerId);
            return;
        }

        if( app.collection.sensors.findWhere({ name: this.markers[markerId].options.title }).get("parameters").length == 0 ) {
            $("#detail-button").text("No Data Available")
                .attr('disabled', true)
                .bind('click', false);
        }
        else {
            // disable button for now
            $("#detail-button").text("Loading Data ...")
                .attr('disabled', true)
                .bind('click', false);

            // this.binningTime will be something like 'smart', 'semi', 'yearly', etc. It is how the datapoints
            // are averaged before being drawn in the graphs.
            // Projects can setup a filterFunction that accepts the current sensor (the Backbone Sensor Model)
            // as an argument. From there, you can return 'smart', 'semi', or some other binning value
            // based on a condition. For example: return (sensor.get('type')['id'] == 'epa') ? 'semi' : 'smart';
            // would return 'semi' as the binningTime for epa sensors, all others would use 'smart' binning
            this.binningTime = "";
            if (app.config.binning.filterFunction) {
              this.binningTime = app.config.binning.filterFunction(app.collection.sensors.findWhere({name: markerId.slice(8).replace(/-/g, " ")}));
            } else if (app.config.binning.time) {
              this.binningTime = app.config.binning.time;
            } else {
              this.binningTime = 'smart';
            }

            // this.binningTime is 'smart', then determine aggregation by temporal range
            if (this.binningTime == 'smart') {
                this.binningTime = getAggregationBin(
                  new Date(this.markers[markerId].feature.properties.min_start_time),
                  new Date(this.markers[markerId].feature.properties.max_end_time)
                );
            }

            // Use default depth if no depth value provided
            var sensorDepth = app.config.binning.depth || 1;

            // fetch data, when fetched enable button
            this.geoStreamService.getBinnedData(this.binningTime, sensorDepth, this.markers[markerId].feature.id, true, function(data) {
                $("#detail-button").text("View Data")
                    .attr('disabled', false)
                    .unbind('click');
            });
        }
    },

    unhoverMarker: function(markerId) {
        d3.selectAll('#' + markerId + ' svg').attr("class", "map-pin");
    },

    unhighlightMarker : function(markerId) {
        this.markers[markerId].closePopup();
    },

    panToMarker : function(markerId) {
        // The 280 size is the size of the popup width.
        var targetPoint = this.map.project(this.markers[markerId].getLatLng(), this.map.getZoom()).add([280 / 2, 0]);
        var targetLatLng = this.map.unproject(targetPoint, this.map.getZoom());
        this.map.panTo(targetLatLng);
    },

    populatePopupTemplate : function(sensor, threshold) {
        if (sensor instanceof app.model.Sensor) {
            sensor = sensor.toJSON();
        }
        return this.popupTemplate({model: sensor, threshold: threshold, sourceColor: sensor.properties.color});
    },

    viewDetails: function(e) {
        e.preventDefault();
        var location = $(e.currentTarget).data('location');
        app.event.eventBus.trigger("change:location", location);
    },

    getTrendsPin: function(sensor, parameter) {
        var areaModel, parameterModel, thresholdParameter;
        _.each(app.config.areas.items, function(area) {
            if (area.properties.id == "er") return;
            if (gju.pointInPolygon(sensor.geometry, area.geometry)) {
              areaModel = app.collection.areas.findWhere({id: area.properties.id});
            }
        });

        if (parameter) {
            parameterModel = app.collection.parameters.findWhere({title: parameter});
            if (parameterModel) {
              thresholdParameter = parameterModel.get('trendThreshold');
            } else {
              thresholdParameter = undefined;
            }
        }

        if (sensor && sensor.properties && sensor.properties.trends && sensor.properties.trends[parameter]
            && sensor.properties.trends[parameter].percentage_change) {
            if (+sensor.properties.trends[parameter].percentage_change > 0 && areaModel) {
                if (+sensor.properties.trends[parameter].last_average > areaModel.get('threshold')[parameter] && thresholdParameter) {
                    return {template: this.mapArrowUpThresh, threshold: areaModel.get('threshold')[parameter]};
                } else {
                    return {template: this.mapArrowUp, threshold: areaModel.get('threshold')[parameter]};
                }
            } else if (+sensor.properties.trends[parameter].percentage_change < 0 && areaModel) {
                if (+sensor.properties.trends[parameter].last_average > areaModel.get('threshold')[parameter] && thresholdParameter) { 
                    return {template: this.mapArrowDownThresh, threshold: areaModel.get('threshold')[parameter]};
                } else {
                    return {template: this.mapArrowDown, threshold: areaModel.get('threshold')[parameter]};
                }
            } else if (+sensor.properties.trends[parameter].percentage_change > 0 && !areaModel) {
                return {template: this.mapArrowUp};
            } else if (+sensor.properties.trends[parameter].percentage_change < 0 && !areaModel) {
                return {template: this.mapArrowDown};
            } else {
                return {template: this.mapLocation};
            }
        } else { 
            return {template: this.mapLocation};
        }
    }

});

app.view.MiniMapView = app.view.MapView.extend({
    geoJsonOptions : function(self) {
        return {
            pointToLayer : function(feature, latlng) {
                var marker = L.marker(latlng, {
                    icon : L.divIcon({
                        html : '<div id="' + feature.properties.name + '" class="' + feature.properties.type.id + '">' + self.getSourcePin(feature) + '</div>'
                    })
                });
                
                return marker;
            },
            onEachFeature : function(feature, layer) {
                
            }
        };
    },
    
    initialize : function(options) {
        app.view.MapView.prototype.initialize.apply(this, arguments);
        return this;
    },
    
    render : function() {
        app.view.MapView.prototype.render.apply(this, arguments);
        return this;
    },
    
    setGeoJsonFeature : function(geoJsonFeature) {
        if(geoJsonFeature.length === 0) return;
      
        app.view.MapView.prototype.setGeoJsonFeature.apply(this, arguments);
        
        var coordinates = geoJsonFeature[0].geometry.coordinates;
        this.map.setView(new L.LatLng(coordinates[1], coordinates[0]), 5);
        this.map.invalidateSize();
    }
});
app.view.TimeSeriesView = Backbone.View.extend({
	tagName : 'div',
	id : 'time',
    
    defaultOptions : {
        height : 250,
        width : 525,
        boxWhiskerMarginH : 60,
        boxWhiskerMarginV : 60
    },
	
	initialize : function(options) {
		this.render = _.bind(this.render, this);
        
        this.data = [];
        this.showEP = true;
        this.haveEP = true;
        
        this.chartOptions = _.extend({}, this.defaultOptions, options.chartOptions);
        
		this.timeSeries = app.graphs.timeSeries().height(this.chartOptions.height).width(this.chartOptions.width).max(15).padding("30 10 50 60");
		this.boxWhisker = app.graphs.boxwhisker().height(this.chartOptions.height).width(175).margin(this.chartOptions.boxWhiskerMarginH, this.chartOptions.boxWhiskerMarginV);
		this.$el.append('<h4 id="time-series-title" class="span9">Time Series</h4>' +
            '<h4 id="box-whisker-title" class="span3">Box and Whisker' +
                '<a href="#bw-modal" role="button" data-toggle="modal" class="info-icon-spacing">' +
                    '<svg xmlns="http://www.w3.org/2000/svg" version="1.1" height="18" width="18">' +
                        '<circle cx="9" cy="9" r="8" fill="url(#g1)" stroke="#939598" stroke-width="2px" />' +
                        '<text x="7" y="14" fill="darkblue" style="font : bold 14px Arial sans-serif;">i</text>' +
                        '<defs>' +
                            '<linearGradient id="g1" gradientUnits="userSpaceOnUse" ' +
                                            'x1="-3%" y1="3.41%" x2="103%" y2="96.59%">' +
                                '<stop offset=".15" stop-color="#fff" />' +
                                '<stop offset=".39" stop-color="#fafafa" />' +
                                '<stop offset=".67" stop-color="#ececed" />' +
                                '<stop offset=".97" stop-color="#d4d6d6" />' +
                                '<stop offset="1" stop-color="#d1d3d4" />' +
                            '</linearGradient>' +
                        '</defs>' +
                    '</svg>' +
                '</a>' +
            '</h4>');
	},
	
	render : function() {
        if(!this.data || !this.data.length) {
            this.$el.html('<div class="no-data">No data for the selected attributes.</div>');
        } else {
            this.$('.no-data').remove();
            this.$('.graphs-mouseOverVerticalLine').remove();
            var that = this;
            var data = that.showEP ? that.summerData : that.data;
            
            var container = d3.select(this.el).selectAll(".time-series-distribution-charts").data(data, function(d) { return d.key; });
            container.enter().append("div").attr("class", "time-series-distribution-charts row-fluid");
            container.exit().remove();
            
            var mytimeseries = container.selectAll(".time-series-chart").data(function(d) { return that.showEP ? [d.ep] : [d.all]; }, function(d) { if(d) {return d.key;} });
            mytimeseries.enter().append("div").attr("class", "time-series-chart span9");
            mytimeseries.exit().remove();
            mytimeseries.call(this.timeSeries);

            // comment this line off to disable switching between all data and filtered data
            mytimeseries.on("click", function(e) { that.showEP = !that.showEP; that.render(); });
            
            var boxWhiskerChart = container.selectAll(".box-whisker-chart").data(function(d) { return that.showEP ? [d.ep] : [d.all]; }, function(d) { return d.key; });
            boxWhiskerChart.enter().append("div").attr("class", "box-whisker-chart span3");
            boxWhiskerChart.exit().remove();
            boxWhiskerChart.call(this.boxWhisker);
        }
        return this;
	},

    setData : function(alldata, summerEPdata) {
        _.each(alldata, function(d) {
            var parameter = app.collection.parameters.findWhere({id: d.values[0].key});
            if (parameter) {
                d.values[0].title = parameter.get("title").replace(/<(.*?)>/g, '');
            } else {
                d.values[0].title = d.values[0].key;
            }

            if(app.config.graphs.timeSeries.showUnits.graphTitle && d.values[0].unit)
                d.values[0].title += " (" + d.values[0].unit + ")";
        });
        if (_.isUndefined(summerEPdata)) {
            summerEPdata = alldata;
            this.haveEP = false;
            this.showEP = false;
        } else {
            if (!this.haveEP) {
                this.showEP = true;
            }
            this.haveEP = true;
            _.each(summerEPdata, function(d) {
                var parameter = app.collection.parameters.findWhere({id: d.values[0].key});
                if (parameter) {
                    d.values[0].title = parameter.get("title").replace(/<(.*?)>/g, '');
                } else {
                    d.values[0].title = d.values[0].key;
                }

                if(app.config.graphs.timeSeries.showUnits.graphTitle && d.values[0].unit)
                    d.values[0].title = d.values[0].title + " (" + d.values[0].unit + ")"

                d.values[0].title += " (summer displays epilimnion data only)";
            });
        }
        this.data = [];
        this.summerData = [];
        for (var i = 0; i < alldata.length; i++) {
            this.data.push({key: i, all: alldata[i]});
            if(summerEPdata[i] !== undefined) {
	            this.summerData.push({key: i, ep: summerEPdata[i]});
            }

        }
        this.render();
    }
});

if (app.config.useV3 == false) {
    app.view.SearchView = Backbone.View.extend({

        attributes: function() {
            return {
                tagName: this.options.attributes.tagName,
                className: this.options.attributes.className,
                id: this.options.attributes.id
            }
        },

        events : {
            "click #download-permalink:not(.disabled)" : "setPermalink",
            "click #download-visualize:not(.disabled)" : "visualizeResults",
            "click .download:not(.disabled)": app.utils.interceptDownload
        },

        initialize : function(options) {
            var self = this;
            this.config = options.config;
            this.resultsVisualized = false;
            _.bindAll(this, "setPermalink", "updateDownloadLink", "updateDatesFromData");
            this.$el.append(_.template($(this.config.templateSelector).html())());

            this.eventBus = app.event.eventBus;
            this.stationService = options.stationService;

            this.dateRangeSelector = this.config.dateRangeSelector;
            this.layers = this.config.layers;
            this.downloadButtons = this.config.downloadButtons;

            this.geojsonMarkerOptions = {
                fillColor: this.config.map.markerFillColor,
                color: this.config.map.markerColor,
                radius: this.config.map.radius,
                weight: this.config.map.weight,
                opacity: this.config.map.opacity,
                fillOpacity: this.config.map.fillOpacity
            };

            // container for currently selected sensors
            this.sensorsfound = L.layerGroup();
            this.sensors = {};
            this.coordinates = {};

            // the format specified in app.config.views.search.dateRangeSelector.format
            // is passed to startDate and endDate, however, if you change the format
            // in `this.startDate = moment('2010....'`  <-- here then this.format can't be changed
            this.format = this.dateRangeSelector.format;
            this.startDate = moment('1970-10-01 1:00:00', this.format);
            this.endDate = moment();
            this.dataStartDate = this.startDate;
            this.dataEndDate = this.endDate;

            // map
            this.map = L.map(this.$(this.config.map.id)[0], {
                maxBounds: this.config.map.maxBounds,
                minZoom: this.config.map.minZoom,
                maxZoom: this.config.map.maxZoom,
                scrollWheelZoom: this.config.map.scrollWheelZoom
            });

            // Initialise the FeatureGroup to store editable layers
            this.drawnItems = new L.FeatureGroup();
            this.map.addLayer(this.drawnItems);

            // tileLayer
            var mapTileSource = this.config.map.mapTileSource || '//{s}.tile.osm.org/{z}/{x}/{y}.png';
            var mapAttribution = this.config.map.mapAttribution || '&copy; <a href="http://osm.org/copyright">OpenStreetMap</a> contributors';
            var tileLayer = L.tileLayer(mapTileSource,
                {
                    attribution: mapAttribution,
                    maxZoom: Math.min(16, this.config.map.maxZoom)
                });
            tileLayer.addTo(this.map);

            // controls
            var baseMaps = {
                "BaseMap": tileLayer
            };

            this.mapControls = L.control.layers(baseMaps);
            this.mapControls.addTo(self.map);

            this.resultsView = new app.view.ResultsView({geostreamService: options.geostreamService});

            app.event.eventBus.bind("sensors:refresh", (function(self) {
                return function() {
                    app.view.sensors = new app.view.SensorsCollectionView({collection: app.collection.sensors});
                    self.render();
                };
            })(this));

            this.eventBus.on("dates:new", this.updateDatesFromData);

            this.eventBus.on("sensors:selected", (function(self) {
                return function(sensors) {
                    self.sensors = sensors;
                };
            })(this));

            this.eventBus.on("map:circle:select", (function(self) {
                return function(coordinates) {
                    self.coordinates = coordinates;
                    self.clearLayers();
                    var params = {geocode: coordinates.latlng.lat + ',' + coordinates.latlng.lng + ',' + (coordinates.radius/1000)};
                    app.collection.sensors.select(params, function() {
                        if (app.config.areas.zoomInOnClick) {
                            app.event.eventBus.trigger("centerMap");
                        }
                        self.updateDownloadLink();
                    });
                };
            })(this));

            this.eventBus.on("map:polygon:select", (function(self) {
                return function(coordinates) {
                    self.coordinates = coordinates;
                    self.clearLayers();
                    var params = {geocode: coordinates.points.map(function(x) { return x.lat + "," + x.lng; }).join()};
                    app.collection.sensors.select(params, function() {
                        if (app.config.areas.zoomInOnClick) {
                            app.event.eventBus.trigger("centerMap");
                        }
                        self.updateDownloadLink();
                    });
                };
            })(this));

            this.eventBus.on("check:parameter", function(options) {
                if (options.view && options.view == "searchView"){
                    self.checkParameter(options);
                }
            });

            this.shapeOptions = this.config.shapeOptions;
            this.drawOptions = {
                position: this.config.drawOptions.position,
                draw: {
                    polyline: this.config.drawOptions.draw.polyline,
                    polygon: {
                        shapeOptions: this.shapeOptions
                    },
                    circle: {
                        shapeOptions: this.shapeOptions
                    },
                    rectangle: {
                        shapeOptions: this.shapeOptions
                    },
                    marker: this.config.drawOptions.draw.marker
                },
                edit: {
                    featureGroup: this.drawnItems, //REQUIRED!!
                    remove: this.config.drawOptions.edit.remove
                }
            };

            // Initialise the draw control and pass it the FeatureGroup of editable layers
            var drawControl = new L.Control.Draw(this.drawOptions);
            this.map.addControl(drawControl);

            this.resetMapButtonOptions = {
                text: this.config.resetMapButtonOptions.text,
                iconUrl: this.config.resetMapButtonOptions.iconUrl,
                glyph: this.config.resetMapButtonOptions.glyph,
                onClick: function() {
                    $('input[name=areaRadios]').prop("checked", false);
                    self.resetSearch();
                    self.resultsView.render();
                },  // callback function
                hideText: this.config.resetMapButtonOptions.hideText,
                maxWidth: this.config.resetMapButtonOptions.maxWidth,
                doToggle: this.config.resetMapButtonOptions.doToggle,
                toggleStatus: this.config.resetMapButtonOptions.toggleStatus
            };

            var resetMapButton = new L.Control.Button(this.resetMapButtonOptions);
            resetMapButton.addTo(this.map);

            var colors = d3.scale.category10();
            // basins
            // originally from http://www.great-lakes.net/gis/data/refdata.html
            // TODO: extract this - check for options.layers && options.layers.items

            if (app.config.basins && app.config.basins.items && app.config.basins.items.length > 0) {
                self.basins = L.geoJson(app.config.basins.items,{
                    style: function(feature) {
                        switch (feature.properties.LAKEBASIN) {
                            case 'Erie': return {color: colors(0),"weight": 1, "opacity": 1};
                            case 'Huron': return {color: colors(1),"weight": 1, "opacity": 1};
                            case 'Michigan': return {color: colors(2),"weight": 1, "opacity": 1};
                            case 'Ontario': return {color: colors(3),"weight": 1, "opacity": 1};
                            case 'St. Lawrence': return {color: colors(4),"weight": 1, "opacity": 1};
                            case 'Superior': return {color: colors(5),"weight": 1, "opacity": 1};
                            default: return {color: colors(Math.round(Math.random()*10)),"weight": 1};
                        }
                    },
                    onEachFeature: function (feature, layer) {
                        layer.bindPopup("<div class='" + self.layers.bindPopupClass + "'>"+feature.properties.LAKEBASIN+'</div>');
                    }
                });
                self.mapControls.addOverlay(self.basins, app.config.basins.title);
            }
        },

        render : function() {
            var self = this;

            var map = this.map; // FIXME
            this.sensorsfound.addTo(map);
            this.map.on('draw:created', function (e) {
                var type = e.layerType,
                    layer = e.layer;

                if ((type === 'polygon') || (type === 'rectangle')) {
                    self.eventBus.trigger("map:polygon:select", {'points': layer.getLatLngs()});
                }

                if (type === 'circle') {
                    self.eventBus.trigger("map:circle:select", {'latlng': layer.getLatLng(), 'radius': layer.getRadius()});
                }

                $('input[name=areaRadios]').prop("checked", false);
                // Do whatever else you need to. (save to db, add to map etc)
                e.layer.addTo(self.drawnItems);
            });

            map.on('draw:edited', function () {
                // Update db to save latest changes.
            });

            map.on('draw:deleted', function () {
                self.clearMarkers();
                self.resetButtons();
            });

            app.collection.sensors.each(function(sensor) {

                var tempGeojsonMarkerOptions = JSON.parse(JSON.stringify(self.geojsonMarkerOptions));
                if (sensor.get('online_status') && sensor.get('online_status')=="online"){
                    tempGeojsonMarkerOptions["color"] = "green";
                }

                var geoJsonLayer = L.geoJson(sensor.toJSON(), {
                    onEachFeature: function (feature, layer) {
                        layer.bindPopup("<div class='" + self.layers.bindPopupClass + "'>"+feature.name+'</div>');
                    },
                    pointToLayer: function (feature, latlng) {
                        return L.circleMarker(latlng, tempGeojsonMarkerOptions);
                    }
                }).addTo(self.map);
            });

            this.eventBus.on("centerMap", function() {
                app.event.eventBus.trigger("zoomOut");
                self.map.fitBounds(self.drawnItems.getBounds(), {
                    padding: [ 5, 5 ]
                });
            });

            this.eventBus.on("zoomOut", function() {
                self.map.fitBounds(self.map.maxBounds);
            });

            // draw default map
            if (app.config.views.search.map.maxBounds === undefined) {
                var bbox = new L.LatLngBounds();
                app.collection.sensors.each(function(sensor) {
                    bbox.extend([sensor.attributes.geometry.coordinates[1],
                        sensor.attributes.geometry.coordinates[0]]);
                });
                if (bbox.isValid()) {
                    app.config.views.search.map.maxBounds = bbox.pad(0.05);
                }
            } else {
                this.map.fitBounds(app.config.views.search.map.maxBounds);
            }

            this.map.invalidateSize();

            this.renderDates();
            this.renderAreas();
            this.renderSources();
            this.renderParameters();
            this.renderSensorViews();

        },

        // this is registered in the events up in the top of SearchView
        updateDownloadLink : function() {
            // if the user has drawn a area, this.coordinates will be populated
            // if the user hasn't drawn a area, we shouldn't filter by geocode
            var params = {};
            if (this.coordinates) {
                if (this.coordinates.radius) {
                    // the user drew a circle
                    var latlng = this.coordinates.latlng;
                    var radius = this.coordinates.radius;
                    params["geocode"] = latlng.lat + ',' + latlng.lng + ',' + (radius/1000);

                } else if (this.coordinates.points) {
                    // the user drew a polygon
                    params["geocode"] = this.coordinates.points.map(function(x) {
                        return x.lat + "," + x.lng;
                    }).join();
                }
            }

            // query the sources collection for models that have been checked, and return the id's in an array
            var sources = _.pluck(_.where(app.collection.sources.toJSON(), {checked: true}), 'id');
            if (sources) params["sources"] = sources;

            // get selected attributes from the collection
            var parameters = _.flatten(_.pluck(_.where(app.collection.parameters.toJSON(), {checked: true}), 'title'));
            if (parameters) {
                params["attributes"] = parameters;
                parameters = _.flatten(_.pluck(_.where(app.collection.parameters.toJSON(), {checked: true}), 'id'));
                if (parameters) params["attributes"] = _.union(params["attributes"], parameters);
            }

            var sites_value = document.getElementById("sites_value");

            // verify sites exist to download
            if ( (sites_value === null) || !(sites_value.innerHTML > 0) ) {
                this.resetButtons();
            }
            else {

                if (this.dataStartDate) params["since"] = this.dataStartDate.format(this.format);
                if (this.dataEndDate) params["until"] = this.dataEndDate.format(this.format);

                // create the url
                var url = app.datapoints.url + '?' + $.param(params, true);

                // update the DOM
                $(this.downloadButtons.json.id).attr('href', url + "&format=json");
                $(this.downloadButtons.json.id).removeClass('disabled');
                $(this.downloadButtons.csv.id).attr('href', url + "&format=csv");
                $(this.downloadButtons.csv.id).removeClass('disabled');
                $(this.downloadButtons.permalink.downloadID).removeClass('disabled');
                $(this.downloadButtons.visualize.id).removeClass('disabled');
            }
        },

        setPermalink : function() {
            var template = $(this.downloadButtons.permalink.template).html();
            $(this.downloadButtons.permalink.id).html(_.template(template,{url: $(this.downloadButtons.json.id).attr('href')}));
            $(this.downloadButtons.permalink.modalID).modal('show');
        },

        // this function is the equivalent to this.sensorsfound.clearLayers(), but works with app.collection.sensors
        // would be nice to keep track of the layer id and related sensors when drawing a area on the map
        // so that clearing a drawn area would only deselect the sensors underneath it. for now, we're clearing all selected sensors
        clearMarkers: function() {
            app.collection.sensors.uncheckAll();
        },

        /**
         * Clear all drawn layers. Similar to just calling this.drawnItems.clearLayers() in initialize or render,
         * but as a function, it can be called by the ResetMapButton
         */
        clearLayers: function() {
            // create a reference to this view as 'self'
            var self = app.view.searchView;
            if (self.drawnItems && (typeof self.drawnItems.clearLayers == 'function')) {
                self.drawnItems.clearLayers();
            }
            // clearMarkers unchecks all sensors, sources, parameters and areas
            self.clearMarkers();
        },

        resetSearch: function() {
            this.clearLayers();
            app.collection.sources.uncheckAll();
            app.collection.parameters.uncheckAll();
            this.coordinates = {};
            app.event.eventBus.trigger("zoomOut");
            this.resetButtons();
        },

        resetButtons: function() {
            $(this.downloadButtons.csv.id).removeAttr('href');
            $(this.downloadButtons.csv.id).addClass('disabled');
            $(this.downloadButtons.json.id).removeAttr('href');
            $(this.downloadButtons.json.id).addClass('disabled');
            $(this.downloadButtons.permalink.downloadID).addClass('disabled');
            $(this.downloadButtons.visualize.id).addClass('disabled');
        },

        renderAreas : function() {
            if (!app.view.areasView) {
                app.view.areasView = new app.view.AreasCollectionView({el: "div#areasView", collection: app.collection.areas});
            }
            app.view.areasView.render();
        },

        renderSources : function() {
            if (!app.view.sourcesView) {
                if (app.collection.sources.getSourcesWithSensors().length > 0) {
                    app.view.sourcesView = new app.view.SourcesCollectionView({
                        collection: app.collection.sources.getSourcesWithSensors()
                    });
                    app.view.sourcesView.render();
                }
            } else {
                app.view.sourcesView.render();
            }
        },

        renderParameters: function() {
            if (!this.parametersView) {
                this.parametersView = new app.view.ParametersCollectionView({
                    el: "table#parametersView",
                    collection: app.collection.parameters,
                    view: "searchView",
                    itemOptions: {
                        tagName: 'tr',
                        className: 'parameterView'
                    }
                });
            }
            this.parametersView.render();

        },

        checkParameter: function(options) {
            this.model = options.model;

            if (app.collection.sensors) var allSelectableSensors = app.collection.sensors.getSelectableSensors();
            var parameterSelectableSensors = this.model.getSelectableSensors();
            if (app.collection.areas) var areasChecked = app.collection.areas.getChecked();

            // we have to do this next step because if you look at the sensor.js file, each sensor's isChecked function
            // listens to areaChecked, sourceChecked or parameterChecked to determine if it should show its color marker
            // I'd rather not do this, because after you uncheck a parameter, the sensor's areaChecked doesn't go back to true
            // and the sensor won't draw its color marker again, even though the area has selected it, but I don't see any other way around this yet.
            if (areasChecked) {
                _.each(allSelectableSensors, function(sensor) {
                    sensor.set("areaChecked", false);
                });
            }

            if (this.model.get("checked")) {
                this.model.set("checked", false);
                // before you set parameterChecked to false, you need to see if all other parameters for this sensor are unchecked.
                _.each(parameterSelectableSensors, function(sensor) {
                    sensor.set("parameterChecked", false);
                });


            } else {
                this.model.set("checked", true);
                _.each(parameterSelectableSensors, function(sensor) {
                    sensor.set("parameterChecked", true);
                });
            }
            // always update the buttons when something gets checked
            this.updateDownloadLink();

        },

        updateDatesFromData: function(dateRange) {
            if (this.isRendering) return;
            this.isRendering = true;
            this.dataStartDate = dateRange.min;
            this.dataEndDate = dateRange.max;
            this.renderDates();
            this.isRendering = false;
        },

        renderDates: function() {
            var self = this;
            var sliderRange = $( self.dateRangeSelector.id );
            sliderRange.slider(
                {
                    range: true,
                    min: self.startDate.year(),
                    max: self.endDate.year(),
                    values: [self.dataStartDate.year(), self.dataEndDate.year()],
                    slide: function(event, ui)
                    {
                        $("#searchtimeSelectedStart").text(ui.values[ 0 ]);
                        $("#searchtimeSelectedStop").text(ui.values[ 1 ]);
                        self.dataStartDate = moment(ui.values[0].toString() + '-01-01 1:00:00', self.format);
                        self.dataEndDate = moment(ui.values[1].toString() + '-12-31 23:59:59', self.format);
                        self.resultsView.renderDates(self.dataStartDate, self.dataEndDate);
                        self.updateDownloadLink();
                    }
                });

            this.$("#searchtimeStart").text(self.startDate.year());
            this.$("#searchtimeStop").text(self.endDate.year());
            this.$("#searchtimeSelectedStart").text(sliderRange.slider("values", 0));
            this.$("#searchtimeSelectedStop").text(sliderRange.slider("values", 1));

        },

        renderSensorViews: function() {
            if (!app.view.sensors) {
                app.view.sensors = new app.view.SensorsCollectionView({collection: app.collection.sensors});
            }
            app.view.sensors.render();
        },

        visualizeResults: function() {
            this.resultsVisualized = !this.resultsVisualized;
            if (this.resultsVisualized) {
                this.resultsView.visualizeResults();
            } else {
                this.resultsView.hideVisualizations();
            }
        }

    });
}

// experimental view on the Search page. Shows the results of selected sensors and their properties (date, attributes, etc.)
if (app.config.useV3 == false) {
    app.view.ResultsView = Backbone.View.extend({

        id: "searchResults",

        initialize: function(options) {
            this.geostreamService = options.geostreamService;
            this.listenTo(app.collection.sensors, 'change:checked', this.render);
            this.listenTo(app.collection.parameters, 'change:checked', this.render);
            this.listenTo(app.collection.parameters, 'change:sourceChecked', this.render);
            this.listenTo(app.collection.sources, 'change:checked', this.render);

            // load sparkline visualization
            this.sparkline = app.graphs.sparkline().height('100px').width('175px');

            this.timeSeries = app.graphs.timeSeries().height('100px').width('175px').max(15).padding("30 10 50 60");

            this.parametersSelected = [];

            this.checked = {sensors: [], parameters: [], bounds: []};
        },

        render: function() {
            if (this.isRendering) return;
            this.isRendering = true;

            var checked = {sensors: [], parameters: [], bounds: []};

            checked.sensors = app.collection.sensors.getChecked();
            checked.sensors.forEach(function(sensor) {
                if (sensor.get('max_end_time')) {
                    var max = moment(sensor.get('max_end_time'));
                    if (checked.max === undefined || max > checked.max) checked.max = max;
                }
                if (sensor.get('min_start_time')) {
                    var min = moment(sensor.get('min_start_time'));
                    if (checked.min === undefined || min < checked.min) checked.min = min;
                }
            });

            var sourcesChecked = app.collection.sources.where({checked: true});
            var sourcesSelected = sourcesChecked;
            if ( (sourcesSelected && sourcesSelected.length == 0)) {
                sourcesSelected = app.collection.sources.where({selected: true});
            }

            var parametersChecked = app.collection.parameters.where({checked: true});
            parametersChecked = _.filter(parametersChecked, function(parameter) {
                return parameter.get("searchView") != "ignore";
            });
            var parametersSelected = parametersChecked;
            if ( parametersChecked && parametersChecked.length > 0) {
                parametersSelected = parametersChecked;
            } else if ( (parametersChecked && parametersChecked.length == 0) && (sourcesChecked && sourcesChecked.length == 0)) {
                parametersSelected = app.collection.parameters.where({selected: true});
            } else {
                parametersSelected = app.collection.parameters.where({sourceChecked: true});
            }
            parametersSelected = _.filter(parametersSelected, function(parameter) {
                return parameter.get("searchView") != "ignore";
            });

            var searchResultsDiv = $('#searchResults');

            // Verify that results will return with a Download action
            if (parametersChecked.length >= 1 && sourcesChecked.length >= 1) {
                var number_params_sources = 0;
                _.each(parametersChecked, function(parameter) {
                    _.each(sourcesChecked, function(sources) {
                        if (sources.get("ParametersIDs") && sources.get("ParametersIDs").includes(parameter.get("id"))) {
                            number_params_sources += 1;
                        }
                    });
                });

            }

            var number_of_sites = 0;

            var sites_count_search_from_sources = app.config.views.search.sites_count_search_from_sources;

            if (
                ((sites_count_search_from_sources == true) &&
                    ( (number_params_sources > 0) ||
                    (parametersChecked.length == 0 && sourcesChecked.length >= 1) ||
                    (parametersChecked.length >= 1 && sourcesChecked.length == 0) )
                ) ||
                (sites_count_search_from_sources == false)
            ){
                var theSensors = app.collection.sensors;

                if (parametersChecked.length >= 1 && sourcesChecked.length == 0) {
                    var theParameterSensors = [];
                        theSensors.filter(function(x){
                            parametersChecked.forEach(function(parameter) {
                            x.attributes.parameters.forEach(function(y) {
                                if ((parameter.id == y.id) && (theParameterSensors.indexOf(x.id) < 0)){
                                    theParameterSensors.push(x.id);
                                }
                            });
                        });
                    });
                    number_of_sites = theParameterSensors.length;

                } else if (parametersChecked.length >= 1 && sourcesChecked.length >= 1) {
                    var theSelectedSensors = [];
                    theSensors.filter(function(x){
                        sourcesChecked.forEach(function(source) {
                            if ((source.id == x.attributes.type.id) && (theSelectedSensors.indexOf(x.id) < 0)){
                                parametersChecked.forEach(function(parameter) {
                                    x.attributes.parameters.forEach(function(y) {
                                        if ((parameter.id == y.id) && (theSelectedSensors.indexOf(x.id) < 0)){
                                            theSelectedSensors.push(x.id);
                                        }
                                    });
                                });
                            }
                        });
                    });
                    number_of_sites = theSelectedSensors.length;

                } else {
                    number_of_sites = (
                        (app.collection.sensors.getChecked().length ||
                        app.collection.sensors.where({selected: true}).length)
                    );
                }
            }

            var help_text = '';
            if (number_of_sites == 0) {
                help_text = 'Please update your search criteria to enable downloads.'
            }

            searchResultsDiv.html(
                '<div class="row search-results-row">' +
                '<strong>' + help_text + '</strong><br/>' +
                '<strong>Sites:</strong> ' +
                '<span id="sites_value">' + number_of_sites+ '</span>' +
                '</div>'
            );

            if (sourcesSelected.length >= 1) {
                searchResultsDiv.append('<div class="row search-results-row"><strong>' + app.config.sources.title + ':</strong>');
                _.each(sourcesSelected, function(source, index) {
                    searchResultsDiv.append('<div class="badge">' + source.id + '</div>');
                    if (index <= (sourcesSelected.length - 2)) { searchResultsDiv.append(' OR '); }
                });
                searchResultsDiv.append('</div>');
            }

            // show Measurements if we have some
            if (parametersSelected.length >= 1) {
                searchResultsDiv.append('<div class="row search-results-row"><strong>' + app.config.parameters.title + ':<strong> </div>').html();
                _.each(parametersSelected, function(parameter, index) {
                    searchResultsDiv.append('<div class="badge">' + parameter.get("title") + '</div>').html();
                    if (index <= (parametersSelected.length - 2)) { searchResultsDiv.append(' OR '); }
                });
            }

            this.parametersSelected = parametersSelected;
            this.checked = checked;

            // show date range if it exists
            if (checked.min && checked.max) {
                this.renderDates(checked.min, checked.max);
                app.event.eventBus.trigger('dates:new', {min: checked.min, max: checked.max});
            }

            this.hideVisualizations();

            this.isRendering = false;

        },

        renderDates: function(start, end) {
            var searchResultsDates = $('#search-results-dates');
            if (searchResultsDates.length) {
                searchResultsDates.html('<strong>Dates Selected:</strong> ' + start.format('MMMM Do YYYY') + ' - ' + end.format('MMMM Do YYYY')).html();
            } else {
                $('#searchResults').append('<div id="search-results-dates" class="row search-results-row"><strong>Dates Available:</strong> ' + start.format('MMMM Do YYYY') + ' - ' + end.format('MMMM Do YYYY') + '</div>').html();
            }

        },

        visualizeResults: function() {

            var that = this;

            // draw graphs for each parameter and station
            if(this.parametersSelected.length > 0) {

                var searchResultsVisualizationsDiv = $('#searchResultsVisualizations');

                searchResultsVisualizationsDiv.append('<div><h3>Visualizations</h3></div>').html();

                _.each(this.parametersSelected, function(parameter) {


                    searchResultsVisualizationsDiv.append('<div><strong>' + parameter.get("title") + '</strong></div>').html();

                    // place divs on the page for all the sensors/parameters matches
                    _.each(that.checked.sensors, function(sensor) {
                        if (_.contains(parameter.get("sensors").pluck("id"), sensor.get("id"))) {
                            searchResultsVisualizationsDiv.append('<div class="searchResultStation">' +
                                '<div id="vis_' + sensor.get("id") +  '_' + parameter.get("id") + '"></div>').html();
                        }
                    });

                    // retrieve data by sensor and draw graphs
                    _.each(that.checked.sensors, function(sensor) {

                        // this.binningTime will be something like 'smart', 'semi', 'yearly', etc. It is how the datapoints
                        // are averaged before being drawn in the graphs.
                        // Projects can setup a filterFunction that accepts the current sensor (the Backbone Sensor Model)
                        // as an argument. From there, you can return 'smart', 'semi', or some other binning value
                        // based on a condition. For example: return (sensor.get('type')['id'] == 'epa') ? 'semi' : 'smart';
                        // would return 'semi' as the binningTime for epa sensors, all others would use 'smart' binning
                        var time = "";
                        if (app.config.binning.filterFunction) {
                            time = app.config.binning.filterFunction(sensor);
                        } else if (app.config.binning.time) {
                            time = app.config.binning.time;
                        } else {
                            time = "smart";
                        }

                        // If app.config.binning.time is 'smart', then determine aggregation by temporal range
                        if (time == 'smart') {
                            time = getAggregationBin(new Date(sensor.get('min_start_time')), new Date(sensor.get('max_end_time')));
                        }

                        // bin depth in one by of 1000 meters below the surface and by year
                        that.geostreamService.getBinnedData(time, 1000, sensor.get("id"), false, function(data) {
                            // console.log("Got data for " + sensor.get("id"));
                            // console.log(data);

                            if (_.contains(parameter.get("sensors").pluck("id"), sensor.get("id"))) {

                                console.log("Drawning graph for sensor " + sensor.get("id") + " and parameter " + parameter.get("id"));


                                var dataBySensor;
                                dataBySensor = data[0].properties[parameter.get("id")];
                                if (!dataBySensor) {
                                    while(!dataBySensor) {
                                        _.each(parameter.get('alternates'), function(alternate) {
                                            dataBySensor = data[0].properties[alternate];
                                        });
                                    }
                                }

                                // order by year
                                // dataBySensor = _.sortBy(dataBySensor, function(obj) { return obj.year });

                                var margin = {top: 20, right: 5, bottom: 20, left: 30},
                                    width = 175 - margin.left - margin.right,
                                    height = 100 - margin.top - margin.bottom,
                                    chart_id = "#vis_" + sensor.get("id") +  '_' + parameter.get("id");

                                // X scale
                                var x = d3.time.scale()
                                    .domain(d3.extent(dataBySensor, function(d) { return new Date(d.date); }))
                                    .range([0, width]);

                                // Y scale
                                var y = d3.scale.linear()
                                    .domain(d3.extent(dataBySensor, function(d) { return d.average; }))
                                    .range([height, 0]);

                                // x-axis
                                var xAxis = d3.svg.axis()
                                    .scale(x)
                                    .ticks(3)
                                    .orient("bottom");

                                // y-axis
                                var yAxis = d3.svg.axis()
                                    .scale(y)
                                    .ticks(2)
                                    .orient("left");

                                // main svg element
                                var graph = d3.select(chart_id)
                                    .append("svg:svg").attr("width", width + margin.left + margin.right).attr("height", height + margin.top + margin.bottom)
                                    .append("g")
                                    .attr("transform", "translate(" + margin.left + "," + margin.top + ")");

                                // draw x-axis
                                graph.append("g")
                                    .attr("class", "x axis")
                                    .attr("transform", "translate(0," + height + ")")
                                    .call(xAxis);

                                // draw y-axis
                                graph.append("g")
                                    .attr("class", "y axis")
                                    .call(yAxis)

                                // line object
                                var line = d3.svg.line()
                                    .x(function(d) { return x(new Date(d.date)); })
                                    .y(function(d) { return y(d.average); });

                                // path with data
                                graph.append("svg:path")
                                    .datum(dataBySensor)
                                    .attr("d", line)
                                    .attr("class", "sparklines");

                                // link to detail page
                                graph
                                    .append("svg:a").attr("xlink:href", function(d){ return window.location.origin + window.location.pathname + "#detail/location/" + sensor.get("name") + "/"})
                                    .append("svg:text")
                                    .text(function(d) { return sensor.get("name"); })
                                    .attr("y", - 5)
                                    .attr("x", - margin.left)
                                    .attr("text-anchor", "start");

                            }

                        });

                    });
                });
            }
        },

        hideVisualizations: function() {
            $('#searchResultsVisualizations').empty();
        }

    });
}

app.view.AboutView = Backbone.View.extend({
    id: "about-view",
    tag: "div",
    
    template: _.template($('#about-template').html()),

    initialize: function(options) {
        return this;
    },
    
    render: function() {
        this.$el.empty();
        this.$el.html(this.template({sources: app.collection.sources.getSourcesWithSensors().toJSON()}));
        return this;
    }
});
app.view.CompareView = Backbone.View.extend({
    id: "compare-view",
    tag: "div",

    template: _.template($('#compare-template').html()),

    events: {
        'change #compareDropdownList': 'renderSubViews'
    },

    initialize: function() {
        var self = this;
        app.collection.compareSelectedSensors = app.collection.compareSelectedSensors || new Backbone.Collection();
        this.collection = app.collection.compareSelectedSensors;

        this.collection.on('add', this.renderComparisonDescription, this);
        this.collection.on('remove', this.renderComparisonDescription, this);

        _.bindAll(this, "render", "renderSubViews");
        // define the subviews that appear on the CompareView
        // this sets up the relationship between the views for the controls and the graphs
        // and hands off to renderSubViews (below)
        if (app.config.views && app.config.views.compare) {
            this.subViews = app.config.views.compare.subviews;
        }

        app.view.compareSidebarView = new app.view.CompareSidebarView({
            // here we are passing an array of strings to the CompareSidebarView so it can display
            // a dropdown of our choices
            el: "#compare-sidebar",
            items: _.map(this.subViews, function(subview) { return subview.label; }),
            views: this.subViews
        });

        app.event.eventBus.on("sensors:refresh", function(){
            self.render();
        });

        return this;
    },

    render: function() {
        this.$el.html(this.template());
        app.view.compareSidebarView.setElement(this.$('#compare-sidebar')).render();
        this.renderSubViews();

        return this;
    },

    renderSubViews: function(view) {
        // the first time renderSubViews is called, there will be no view (view is actually an "event" sent by Backbone)
        // when a user clicks the dropdown, renderSubViews will contain the freeform text of the desired view (ie: "Lakes")
        // we match the text from the dropdown back to the label in this.subViews and render the appropriate subviews
        if (view && view.currentTarget) {
            // in this case, a view was passed, so map the text to an item in this.subViews
            // TODO: Check this. The tabViews should show up here.
            view = _.findWhere(this.subViews, {label: view.currentTarget.value });
        } else {
            // in this case, no view was passed, so just get the first item in this.subViews with a label
            view = _.find(this.subViews, function(subview) { return subview.label; });
        }

        // the variable "view" should now contain a text label and the correct templates for the sidebar and the graph

        // we don't have to empty $el, since that is handled by CompareSidebarControlsView
        // the initialize method in CompareSidebarControlsView calls render for us
        // CompareSidebarControlsView will insert this into div#compare-sidebar-controls
        // TODO: Check the multiple subview rendering here.
        if (!app.view["compareSidebarControlsView" + view.label]) {
            app.view["compareSidebarControlsView" + view.label] = new app.view.CompareSidebarControlsView({
                template: view.sidebar.template,
                label: view.label,
                clickableDOMItems: view.sidebar.clickableDOMItems
            });
        }
        this.$('#compare-sidebar-controls').append(app.view["compareSidebarControlsView" + view.label].render().el);


        // we don't have to empty $el, since that is handled by CompareGraphView
        // the initialize method in CompareGraphView calls render for us
        // CompareGraphView will insert this into div#compare-graph
        if (!app.view["compareGraphView" + view.label]) {
            app.view["compareGraphView" + view.label] = new app.view.CompareGraphView({
                template: view.graph.template
            });
        }
        app.view["compareGraphView" + view.label].setElement(this.$('#compare-graph')).render();
    },

    renderComparisonDescription: function() {
        var selectedSensors = app.collection.compareSelectedSensors.map(function(sensor) {
            return sensor.get('name');
        });

        var comparisonDescription = $('#comparison-description');
        var comparisonDescriptionItems = $('#comparison-description-items');

         if (selectedSensors.length == 0 ) {
            comparisonDescription.text("Compare Parameters");
            comparisonDescriptionItems.text('');
         } else if (selectedSensors.length > 0) {
            comparisonDescriptionItems.text(selectedSensors.join(" & "));
         }

         if (selectedSensors.length == 1) {
            comparisonDescription.text("Showing Parameters for ");
         } else if (selectedSensors.length > 1) {
            comparisonDescription.text("Comparing Parameters at ");
         }

         if (selectedSensors.length > 3) {
            comparisonDescriptionItems.addClass("small");
         } else {
           comparisonDescriptionItems.removeClass("small");
         }
    }
});

app.view.CompareSidebarView = Backbone.View.extend({

    template: _.template($('#compare-sidebar-template').html()),

    initialize: function(options) {
        var self = this;
        _.bindAll(this, "render", "renderMap");
        this.items = options.items;
        this.miniMap = app.config.views.compare.miniMap;

        app.collection.compareSelectedSensors = app.collection.compareSelectedSensors || new Backbone.Collection();
        this.collection = app.collection.compareSelectedSensors;

        this.collection.on('add', this.renderMap, this);
        this.collection.on('remove', this.renderMap, this);

        app.collection.onHoverSensors = app.collection.onHoverSensors || new Backbone.Collection();
        this.onHoverSensors = app.collection.onHoverSensors;
        this.onHoverSensors.on('add', this.renderMap, this);
        this.onHoverSensors.on('remove', this.renderMap, this);

        return this;
    },

    render: function() {
        this.$el.html( this.template() );
        this.map = L.map(self.$('#compare-sidebar-minimap')[0], {
            zoomControl: false,
            attributionControl: false,
            dragging: true,
            touchZoom: false,
            scrollWheelZoom: true,
            doubleClickZoom: false,
            boxZoom: false
        }).setView(this.miniMap.config.mapOptions.center, this.miniMap.config.mapOptions.zoom);
        this.renderMap();
        return this;
    },

    renderMap: function() {
      var self = this;

      var activeSensors = (app.collection.compareSelectedSensors) ? app.collection.compareSelectedSensors.toJSON() : [];

      if (self.geoJsonLayer) {
        self.map.removeLayer(self.geoJsonLayer);
      }

      var onHoverSensors = (app.collection.onHoverSensors) ? app.collection.onHoverSensors.toJSON() : [];
      if(self.onHoverLayer) {
        self.map.removeLayer(self.onHoverLayer)
      }
      self.onHoverLayer = L.geoJson(onHoverSensors, {
        pointToLayer: function(feature, latlng) {
          var badge = L.divIcon({className: 'badger-outer', html: '<div class="badger-inner-hover"><p class="badger-map-badge"> * </p></div>'});
          return L.marker(latlng, {icon: badge})
        }
      });

      self.onHoverLayer.addTo(self.map);
      self.geoJsonLayer = L.geoJson(activeSensors, {
        pointToLayer: function (feature, latlng) {
          var badge = L.divIcon({className: 'badger-outer', html: '<div class="badger-inner"><p class="badger-map-badge">'+ ( _.indexOf(activeSensors, feature) + 1) + '</p></div>'});
          return L.marker(latlng, {icon: badge});
        }
      });

      self.geoJsonLayer.addTo(self.map);

      

      L.tileLayer(self.miniMap.config.mapOptions.mapTileSource, {
          maxZoom: 18
      }).addTo(self.map);

      self.$("#" + this.miniMap.id).html(self.map.el);

    }
});

app.view.CompareSidebarControlsView = Backbone.View.extend({
    el: "div#compare-sidebar-controls",
    // required arguments:
    // template: the script id for the template this will use
    // label: a string or variable that resolves to a string that is used to show in the dropdown
    // ie: new app.view.CompareByTypeView({
    //      template: "#compare-sidebar-lakes-template
    //      label: app.config.areas.title
    // });
    // this view should be called after it's parent is rendered

    initialize: function(options) {
        this.label = options.label;
        this.clickableDOMItems = options.clickableDOMItems;
        this.template = _.template($(options.template).html());
        // unbind click prevents the duplicate "clicking" of the event
        this.$el.unbind('click');

        app.collection.compareSelectedSensors = app.collection.compareSelectedSensors || new Backbone.Collection();
        this.collection = app.collection.compareSelectedSensors;

        app.collection.onHoverSensors = app.collection.onHoverSensors || new Backbone.Collection();
        
        // this.collection.on('add', this.render, this);
        // this.collection.on('remove', this.render, this);

        return this;
    },

    render: function() {
        this.$el.html(
            this.template({
                label: this.label,
                sources: app.collection.sources.getAreas(),
                activeItems: app.collection.compareSelectedSensors.pluck('id')
            })
        );

        // we could have setup the defaults "events" object, but this allows us to store in app.config what we want to be clickable
        this.$(this.clickableDOMItems).on('click', this.clickItem);
        this.$(this.clickableDOMItems).on('mouseenter', this.mouseEnter);
        this.$(this.clickableDOMItems).on('mouseleave', this.mouseLeave);
        this.$('.nodata-wrapper').tooltip({delay: { show: 150, hide: 100 }});
        this.$('.showHide').on('click', this.toggleButton);
        return this;

    },

    toggleButton: function() {
        if(this.innerHTML.indexOf("+") >=0) {
            this.innerHTML= "-";
        } else {
            this.innerHTML="+";
        }
    },
    mouseEnter: function() {
        event.preventDefault();
        
        //The id of the sensor
        var sensor = app.collection.sensors.findWhere({name: event.currentTarget.value});
        app.collection.onHoverSensors.add(sensor);
        var clickedOrder = _.indexOf(app.collection.onHoverSensors.models, sensor);
        if (clickedOrder > -1) {
          $(this).append('<div class="badger-outer-hover" id="Badger_'+clickedOrder+'"><div class="badger-inner-hover"><p class="badger-badge" id="Badger_'+clickedOrder+'_badge">*</p></div></div>');
        } 
    },
    mouseLeave: function() {
        event.preventDefault();
        $(this).find('.badger-outer-hover').remove();
        var sensor = app.collection.sensors.findWhere({name: event.currentTarget.value});
        app.collection.onHoverSensors.remove(sensor); 
    },

    clickItem: function(event) {
        // preventDefault ensures that the button doesn't do its default (ie: we control what it should do)
        event.preventDefault();

        // start the loading spinner
        app.event.eventBus.trigger("compare:spinner:start");

        // if the sensor is already active when this click begins, this is an "unclick"
        if ($(this).hasClass('active')) {
          $(this).find('.badger-outer').remove();
        }
        
        $(this).toggleClass('active');
        
        // the name of the sensor:
        // console.log(event.currentTarget.value);

        // the id of the sensor (in case we'd want to directly query the datapoints endpoint later:
        // console.log(event.currentTarget.getAttribute('data-id'));
        // or it's jQuery equivalent:
        // console.log($(event.target).data('id'));
        var sensor = app.collection.sensors.findWhere({name: event.currentTarget.value});

        if (sensor) {
            // if the clicked sensor was already selected, we will remove it immediately
            if (app.collection.compareSelectedSensors.contains(sensor)) {
                app.collection.compareSelectedSensors.remove(sensor);

                // now we need to determine if we can remove any of this sensor's parameters from the selection
                // other sensors might still be selected and they might offer the same parameters as this sensor
                // we will look at the remaining sensors to determine parameters that should still be selected
                var remainingParameters = [];
                app.collection.compareSelectedSensors.each(function(s){
                    s.get('parameters').each(function(p) {
                        remainingParameters.push(p.id);
                    });
                });

                remainingParameters = _.uniq(remainingParameters);

                // if there are no more parameters available,
                // then we can infer that all of the sensors have been unclicked, so reset everything
                if (!remainingParameters.length) {
                    app.collection.parameterBins.reset();
                    app.collection.compareSelectedDates.reset();
                    app.collection.compareSelectedSensors.reset();
                    app.collection.compareSelectedParameters.reset();
                } else {
                    // in this case, we have unchecked a sensor, but there are other parameters available,
                    // so we need to remove only the parameters that were unique to this sensor
                    sensor.get('parameters').each(function(parameter){
                        if (!_.contains(remainingParameters, parameter.get('id'))) {
                            app.collection.compareSelectedParameters.remove(parameter);
                        }
                    });
                }

                // stop the loading spinner
                app.event.eventBus.trigger("compare:spinner:stop");
                return this;
            } else {
                // the user is clicking this sensor for the first time
                app.collection.compareSelectedSensors.add(sensor);
            }
        }

        // this.binningTime will be something like 'smart', 'semi', 'yearly', etc. It is how the datapoints
        // are averaged before being drawn in the graphs.
        // Projects can setup a filterFunction that accepts the current sensor (the Backbone Sensor Model)
        // as an argument. From there, you can return 'smart', 'semi', or some other binning value
        // based on a condition. For example: return (sensor.get('type')['id'] == 'epa') ? 'semi' : 'smart';
        // would return 'semi' as the binningTime for epa sensors, all others would use 'smart' binning
        this.binningTime = "";
        if (app.config.binning.filterFunction) {
          this.binningTime = app.config.binning.filterFunction(app.collection.sensors.findWhere({name: event.currentTarget.value}));
        } else if (app.config.binning.time) {
          this.binningTime = app.config.binning.time;
        } else {
          this.binningTime = 'smart';
        }

        // If this.binningTime is 'smart', then determine aggregation by temporal range
        if (this.binningTime == 'smart') {
            // getAggregationBin is a global function in DetailView - that should probably change, but it works ok
            // this will just tell us if we should bin by year, month, day, etc.
            this.binningTime = getAggregationBin(new Date(sensor.get('min_start_time')),
              new Date(sensor.get('max_end_time')));
        }

        // request the bin endpoint
        app.model.geoStreamService.getBinnedData(this.binningTime, 1, sensor.get('id'), true, function(data) {
            // the bin endpoint will return a bunch of parameters in the "properties" object
            // each parameter uses an "id" format, but it can also be an original formatted string, as it came
            // from the source, so it might be one of the alternate spellings found in the "alternates"
            // array for a parameter
            _.each(data[0]["properties"], function(values, parameterID) {

                // if the parameter contains data...
                if (data[0].properties[parameterID].length) {

                    // search for this parameter against the collection by id
                    var parameterModel = app.collection.parameters.findWhere({id: parameterID});

                    // if it wasn't found by id, check to see if it matches one of the parameters alternate spellings
                    // if no match is found, we can go on to the next parameter
                    if (_.isUndefined(parameterModel)) {
                        parameterModel = app.collection.parameters.filter(function(p) {
                            return _.contains(p.get('alternates'), parameterID);
                        });
                        if (parameterModel.length) {
                            parameterModel = parameterModel[0];
                        } else {
                            console.log("CompareSidebarControlsView:clickItem - parameterModel was not found for " + parameterID);
                            return;
                        }
                    }

                    // make sure we aren't using a parameter that is either ignored or a depth-based parameter
                    if (parameterModel.get('detailView') == 'time') {
                        // adding to the compareSelectedParameters collection will trigger an event internally
                        // this collection is listened to by views and will take care of updating lists or graphs
                        // whenever this changes
                        app.collection.compareSelectedParameters.add(parameterModel.toJSON());
                    }

                    // a parameterBin is a way of organizing data so that we can compare multiple
                    // sensors for the same parameter. Since these are two separate calls to the API, we persist
                    // them in a collection. A parameterBin is organized like this:
                    //   id: the parameter id. If an alternate was used, we conform it to the ID above as parameterModel
                    //   dates: a Backbone Collection.
                    //         - each model in this collection uses the unique date string as it's ID
                    //         - each sensor that has a parameter on this date will be an attribute on this model.
                    //         - ie: sensor 1 will show up as an attribute: "1: 0.5", where 1 is the sensor's ID
                    //               and 0.5 is the value returned by the bin endpoint for this parameter and parameter

                    // the "add" method on a collection won't duplicate a unique ID.
                    var parameterBin = app.collection.parameterBins.add({id: parameterModel.get('id')});
                    // create the dates collection if it doesn't already exist
                    if (!parameterBin.get('dates')) {
                        parameterBin.set('dates', new Backbone.Collection());
                    }

                    // inside the response from the bin endpoint, this parameter will contain several values and metadata
                    // we are interested in the "date" and "average" values
                    for (var i = 0; i < data[0]["properties"][parameterID].length; i++) {
                        var parameterBinDatesCollection = parameterBin.get('dates');

                        // add this date as a unique ID in the parameterBin's "dates" collection
                        var selectedDate = parameterBinDatesCollection.add({
                            id: data[0]["properties"][parameterID][i]['date']
                        });

                        // also add this to the compareSelectedDates collection
                        // so that our slider range gets updated
                        app.collection.compareSelectedDates.add({id: data[0]["properties"][parameterID][i]['date']});

                        // set the value of the "average" on this date: {1: 0.5}
                        // any additional sensors with measurements of this parameter at this time will get added here
                        selectedDate.set(sensor.get('id'), data[0]["properties"][parameterID][i]['average']);
                    }

                }
            });
            // if we listen directly to the parameterBins collection, it would fire events too aggressively, even before
            // we are done assessing the data. Instead, wait to notify until after all of the parameters have been parsed above.
            app.event.eventBus.trigger("parameterBins:loaded");

            // stop the loading spinner
            app.event.eventBus.trigger("compare:spinner:stop");
        });

        var clickedOrder = _.indexOf(app.collection.compareSelectedSensors.models, sensor);
        if (clickedOrder > -1) {
          clickedOrder++;
          $(this).append('<div class="badger-outer" id="Badger_'+clickedOrder+'"><div class="badger-inner"><p class="badger-badge" id="Badger_'+clickedOrder+'_badge">'+clickedOrder+'</p></div></div>');
        }
    }
});

app.view.CompareGraphView = Backbone.View.extend({
    className: "compare-graph",
    // template must be passed in when creating an instance of this view
    // ie: new app.view.CompareGraphView({template: "#compare-graph-lakes-template});
    // this view should be called after it's parent is rendered

    initialize: function(options) {
        var self = this;
        this.template = _.template($(options.template).html());

        // this view will listen to the compareSelectedSensors collection
        app.collection.compareSelectedSensors = app.collection.compareSelectedSensors || new Backbone.Collection();
        this.collection = app.collection.compareSelectedSensors;

        // create the three parameter dropdowns
        // they will listen to changes in the compareSelectedParameters collection
        this.parameterDropdown1 = new app.view.SelectCollectionView({
          id: "compare-parameter-1",
          className: "span4 margin21R",
          trigger: "change:compare:parameter:1",
          collection: app.collection.compareSelectedParameters
        });
        this.parameterDropdown2 = new app.view.SelectCollectionView({
          id: "compare-parameter-2",
          className: "span4 margin21R",
          trigger: "change:compare:parameter:2",
          placeholder: "Additional Parameter",
          collection: app.collection.compareSelectedParameters
        });
        this.parameterDropdown3 = new app.view.SelectCollectionView({
          id: "compare-parameter-3",
          className: "span4",
          trigger: "change:compare:parameter:3",
          placeholder: "Additional Parameter",
          collection: app.collection.compareSelectedParameters
        });

        // when a parameter changes, update the corresponding graph
        app.event.eventBus.on('change:compare:parameter:1', function(data) {
          if (data && data.target && data.target.value) {
            self.graph1.update(data.target.value);
          }
        });
        app.event.eventBus.on('change:compare:parameter:2', function(data) {
            if (data && data.target && data.target.value) {
              self.graph2.update(data.target.value);
            }
        });
        app.event.eventBus.on('change:compare:parameter:3', function(data) {
            if (data && data.target && data.target.value) {
              self.graph3.update(data.target.value);
            }
        });

        // when a sensor is unclicked, update each graph based on the selected parameter
        this.collection.on('remove', function() {
          self.graph1.update($("#compare-parameter-1").val());
          self.graph2.update($("#compare-parameter-2").val());
          self.graph3.update($("#compare-parameter-3").val());
        }, this);


        // on a pristine page, if you click a sensor, this will load the graph for the first parameter
        app.event.eventBus.on("parameterBins:loaded", function() {
          self.graph1.update($("#compare-parameter-1").val());
          self.graph2.update($("#compare-parameter-2").val());
          self.graph3.update($("#compare-parameter-3").val());
        });

        // setup a loading spinner we can turn on and off
        var spinner = app.config.views.compare.spinnerOptions || {
            lines: 13 // The number of lines to draw
            , length: 28 // The length of each line
            , width: 14 // The line thickness
            , radius: 42 // The radius of the inner circle
            , scale: 1 // Scales overall size of the spinner
            , corners: 1 // Corner roundness (0..1)
            , color: '#000' // #rgb or #rrggbb or array of colors
            , opacity: 0.25 // Opacity of the lines
            , rotate: 0 // The rotation offset
            , direction: 1 // 1: clockwise, -1: counterclockwise
            , speed: 1 // Rounds per second
            , trail: 60 // Afterglow percentage
            , fps: 20 // Frames per second when using setTimeout() as a fallback for CSS
            , zIndex: 2e9 // The z-index (defaults to 2000000000)
            , className: 'spinner' // The CSS class to assign to the spinner
            , top: '60%' // Top position relative to parent
            , left: '57%' // Left position relative to parent
            , shadow: false // Whether to render a shadow
            , hwaccel: false // Whether to use hardware acceleration
            , position: 'absolute'
          };
        this.spinner = new Spinner(spinner);

        // the spinner isn't appended to the DOM until the first time it gets called.
        app.event.eventBus.on("compare:spinner:start", function() {
          $("#compare-parameter-graph-1").append(self.spinner.spin().el);
        });
        // use the eventBus to stop the spinner from anywhere
        app.event.eventBus.on("compare:spinner:stop", function() {
          self.spinner.stop();
        });

        // compareSelectedDates keeps track of the date range available to the graphs
        // whenever those dates change, update the date slider
        app.collection.compareSelectedDates.on('all', function() {
          var slider = $("#slider-range-stations");
          var minBounds = new Date(new Date().getFullYear() - 44, new Date().getMonth(), new Date().getDate());
          var minSelected = new Date(new Date().getFullYear() - 10, new Date().getMonth(), new Date().getDate());
          var last = new Date();
          // if compareSelectedDates has models, then we have data to look at and graph.
          // set the bounds to that of the compareSelectedDates collection and move the selection to the bounds too
          if (app.collection.compareSelectedDates.length) {
            minBounds = minSelected = new Date(app.collection.compareSelectedDates.first().get('id'));
            last = new Date(app.collection.compareSelectedDates.last().get('id'));
          }
          // bounds: the range of available dates
          slider.dateRangeSlider("bounds", minBounds, last);
          // values: the selected start and end times
          slider.dateRangeSlider("values", minSelected, last);

        });

        return this;
    },

    render: function() {
        this.$el.empty();
        this.$el.append( this.template() );
        if (app.config.views.compare.removeBinDropdown) {
            this.$('#compare-season-dropdown').remove();
        }
        this.renderParameterDropdowns(this);

        // create a dateRangeSlider, setting the bounds fairly large, and selecting the last year.
        // once data starts getting selected, this will get udpated
        var sliderRange = $( "#slider-range-stations" );
        sliderRange.dateRangeSlider({
          bounds: {
            min: new Date(new Date().getFullYear() - 44, new Date().getMonth(), new Date().getDate()),
            max: new Date()
          },
          defaultValues: {
            min: new Date(new Date().getFullYear() - 10, new Date().getMonth(), new Date().getDate()),
            max: new Date()
          },
          step: {
            days: 1
          },
          arrows: false
        });

        // when the slider range changes, data contains data.values.min and data.values.max
        sliderRange.on("userValuesChanged", function(e, data) {
          app.event.eventBus.trigger("compare:date:changed", data);
        });

        // create the three graphs in their empty state and render them
        this.graph1 = new app.view.CompareGraphMGTimeSeriesView({id: "#compare-parameter-graph-1"});
        this.graph2 = new app.view.CompareGraphMGTimeSeriesView({id: "#compare-parameter-graph-2"});
        this.graph3 = new app.view.CompareGraphMGTimeSeriesView({id: "#compare-parameter-graph-3"});
        this.graph1.render();
        this.graph2.render();
        this.graph3.render();

        return this;
    },

    renderParameterDropdowns: function(self) {
        var container = this.$('#availableParametersDefaultTitle');

        container.append(self.parameterDropdown1.render().el);
        container.append(self.parameterDropdown2.render().el);
        container.append(self.parameterDropdown3.render().el);

        self.$('#compare-parameter-1').on('change', function(event) {
          self.parameterDropdown1.setSelected(event.target.value);
          app.event.eventBus.trigger('change:compare:parameter:1', event);
        });
        self.$('#compare-parameter-2').on('change', function(event) {
          self.parameterDropdown2.setSelected(event.target.value);
          app.event.eventBus.trigger('change:compare:parameter:2', event);
        });
        self.$('#compare-parameter-3').on('change', function(event) {
          self.parameterDropdown3.setSelected(event.target.value);
          app.event.eventBus.trigger('change:compare:parameter:3', event);
        });
      return self;

    }
});

app.view.CompareGraphTimeSeriesView = Backbone.View.extend({
//    el: "div#compare-graph",
    // template must be passed in when creating an instance of this view
    // ie: new app.view.CompareGraphView({template: "#compare-graph-lakes-template});
    // this view should be called after it's parent is rendered

    initialize: function(options) {
        var self = this;
        this.template = _.template('<h4><%= name %></h4>');
        _.bindAll(this, "render", "setData", "getData");
        this.timeSeriesView = new app.view.TimeSeriesView({
            parentView : this
        });
        app.event.eventBus.on("compareGraph:data:" + this.model.id, this.setData);
        app.event.eventBus.on("change:compare:parameter", function(event) {
            self.setData(self.model, event);
        });

        $("#compare-hide-box-plot").on('click', function() {
            $(".box-whisker-chart").toggle();
        });

		    $("#compare-season-dropdown").on('change', function() {
			      self.setData(self.model, null, $(this).val());
		    });

        $("#slider-range-stations").on('slidechange', function() {
            self.setData(self.model);
        });


        return this;
    },

    render: function() {

        this.$el.empty();
        this.$el.html( this.template({name: this.model.get('popupContent') }) );
        this.getData(this.model);

        this.modals = _.template($("#box-whisker-modal-template").html())();

        this.$el.append(this.modals);
        return this;
    },

    append: function() {
      this.$el.append(this.timeSeriesView.render().el);

    },

    getData: function(model) {
        var self = this;
        if (!self.data) {
          app.model.geoStreamService.getByLocation(model.toJSON(), function(data) {
              self.data = data;
              app.event.eventBus.trigger("compareGraph:data:" + model.id, model);
          });
        } else {
          app.event.eventBus.trigger("compareGraph:data:" + model.id, model);
        }
    },

    setData: function(model, parameter, season) {
        season = season || $("#compare-season-dropdown").val();
        var self = this;
        if (model.id != this.model.id) return;
        if (!this.data) return;

        var parameter1 = $('.compare-parameter-1').val();
        var parameter2 = $('.compare-parameter-2').val();
		var parameter3 = $('.compare-parameter-3').val();

        var parameters = [];
        _.each([parameter1, parameter2, parameter3], function(parameter) {
          if (parameter && parameter.length) {
            parameters.push(parameter);
          }
        });

	    var startTime = new Date($("#slider-range-stations").slider('values')[0], null);
        var endTime = new Date($("#slider-range-stations").slider('values')[1], 11, 31, 23, 59, 59);

        // create time series values
        // 'data' is the original data from the API. Here we're just filtering it down to just the data with "detailView" of "time"
        var time_series_data = _.where(this.data, {detailView: "time"});
        if (time_series_data) {
            // convert data to following data structure. We need two
            // of these structures in summer, one with all values for
            // box-whisker plot and one with only EP for time series.
            // time-series data: [ {
            //   key: "0",
            //   values: [ {
            //     color: "red",
            //     key: "parameter name",
            //     sources: [ sources ],
            //     values: [ {
            //       x: date,
            //       y: value
            //     }]
            //   }]
            // }]

            // get a unique list of the parameters found in the time data
            var time_series_params = _.unique(_.pluck(_.where(time_series_data, {detailView: "time"}), "parameter"));

            // if a parameter is selected, but this sensor doesn't have that parameter, omit it
            _.each(parameters, function(parameter) {
                if (!_.contains(time_series_params, parameter)) {
                  parameters = _.without(parameters, parameter);
                }
            });

            var parameterTitles = app.collection.parameters.where({detailView: "time"});
            parameterTitles = _.pluck(parameterTitles, "id");
            // use d3 to create colors for each of the unique parameters
            var parameters_colors = parameterTitles.length > 10 ? d3.scale.category20().domain(parameterTitles) : d3.scale.category10().domain(parameterTitles);

            var time_season_data = this.data;
            if (!_.isUndefined(season) && (season != null) && (season != "all") && (season != "")) {
                time_season_data = _.where(this.data, {season: season});
            }

            // alldata is where we'll stuff all the time_series_data as we iterate through the time_series_params
            // summerepdata is where we'll add all spring data, but only summer ep data
            var alldata = [], summerEPdata = [];

            // sources is where a list of sources are kept, pointing back to clowder
            var sources = [];


          // if no start or endtime is given compute start/end time
            if (_.isUndefined(startTime) || _.isUndefined(endTime)) {
                _.each(this.data, function(d) {
                    if (_.isUndefined(startTime) || (startTime > d.date)) startTime = d.date;
                    if (_.isUndefined(endTime) || (endTime < d.date)) endTime = d.date;
                });
            }


            var filterWrongDates = function(dataset, startTime, endTime) {
                // filter any wrong date information
                if (!_.isUndefined(startTime) || !_.isUndefined(endTime)) {
                    dataset = _.filter(dataset, function (x) {
                        if (!_.isUndefined(startTime)) {
                            if (startTime.getUTCFullYear() > x.year) {
                                return false;
                            }
                            if (startTime.getUTCFullYear() == x.year) {
                                if (!_.isUndefined(x.month)) {
                                    if (startTime.getUTCMonth() > x.month) {
                                        return false;
                                    }
                                    if (startTime.getUTCMonth() == x.month) {
                                        if (!_.isUndefined(x.day)) {
                                            if (startTime.getUTCDate() > x.day) {
                                                return false
                                            }
                                            if (startTime.getUTCDate() == x.day) {
                                                if (!_.isUndefined(x.hour)) {
                                                    if (startTime.getUTCHours() > x.hour) {
                                                        return false;
                                                    }
                                                    if (startTime.getUTCHours() == x.hour) {
                                                        if (!_.isUndefined(x.minute) && startTime.getUTCMinutes() > x.minute) {
                                                            return false;
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                        if (!_.isUndefined(endTime)) {
                            if (endTime.getUTCFullYear() < x.year) {
                                return false;
                            }
                            if (endTime.getUTCFullYear() == x.year) {
                                if (!_.isUndefined(x.month)) {
                                    if (endTime.getUTCMonth() < x.month) {
                                        return false;
                                    }
                                    if (endTime.getUTCMonth() == x.month) {
                                        if (!_.isUndefined(x.day)) {
                                            if (endTime.getUTCDate() < x.day) {
                                                return false
                                            }
                                            if (endTime.getUTCDate() == x.day) {
                                                if (!_.isUndefined(x.hour)) {
                                                    if (endTime.getUTCHours() < x.hour) {
                                                        return false;
                                                    }
                                                    if (endTime.getUTCHours() == x.hour) {
                                                        if (!_.isUndefined(x.minute) && endTime.getUTCMinutes() < x.minute) {
                                                            return false;
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                        return true;
                    });
                }
                return [dataset, startTime, endTime];
            };

          var data_filtered_for_dates = filterWrongDates(time_season_data, startTime, endTime);
          startTime = data_filtered_for_dates[1];
          endTime = data_filtered_for_dates[2];
          data_filtered_for_dates = data_filtered_for_dates[0];

          // iterate over each of the unique parameters
            var foundEP = false;
            for (var i = 0; i < parameters.length; i++) {
                // 'parameters' is what gets passed in via the URL (ie: the Backbone router gives us these)
                // if there are parameters in the URL, but the param we are on isn't one of them, skip it
//                if (!_.isEmpty(parameters) && (_.contains(parameters, time_series_params[i]))) {
//                    parameters = [time_series_params[i]];
//                }

                // create a 'valuesAll' object. It will filter the time_series_data to get this one param we are on,
                // creating a sum and count of the number of datapoints so we can create an average. The same is done
                // for the 'valuesEPsummer' however in this case all values in the summer that have depthcode that is
                // NOT EP will be ignored.
                var valuesAll = [], valuesEPsummer = [];
                _.each(_.where(data_filtered_for_dates, {parameter: parameters[i]}), function (x) {
                    var countAll = 0, countEPdata = 0;
                    var sumAll = 0, sumEPdata = 0;
                    var rawAll = [], rawEP = [];
                    _.each(x.values, function (v) {
                        countAll += v.count;
                        sumAll += v.value;
                        rawAll.push(v.raw);
                        sources.push(v.source);
                        if (x.season == "summer" && !_.isUndefined(v.depthcode) && (v.depthcode == "EP")) foundEP = true;
                        if ((x.season != "summer") || _.isUndefined(v.depthcode) || (v.depthcode == "EP") || (v.depthcode == "NA")) {
                            countEPdata += v.count;
                            sumEPdata += v.value;
                            rawEP.push(v.raw);
                        }
                    });
                    valuesAll.push({ x: x.date, y: sumAll / countAll, label: x.label, raw: _.flatten(rawAll) });
                    if (countEPdata != 0) {
                        valuesEPsummer.push({ x: x.date, y: sumEPdata / countEPdata, label: x.label, raw: _.flatten(rawEP) });
                    }
                });
                var yrange = d3.extent(valuesAll.concat(valuesEPsummer).concat({ y: 0}), function (d) {
                    return d.y;
                });
                var xrange = [startTime, endTime];

                // push the computed values into alldata/summerepdata
                alldata.push({
                    key: i.toString(),
                    values: [
                        {
                            color: parameters_colors(parameters[i]),
                            key: parameters[i],
                            xrange: xrange,
                            yrange: yrange,
                            values: valuesAll,
                            sources: _.uniq(_.flatten(sources)),
                            unit: ((app.collection.parameters.findWhere({id: parameters[i]})) ? (app.collection.parameters.findWhere({id: parameters[i]})).get("unit") : 'unit')
                        }
                    ]
                });
                if (!_.isEmpty(valuesEPsummer)) {
                    summerEPdata.push({
                        key: i.toString(),
                        values: [
                            {
                                color: parameters_colors(parameters[i]),
                                key: parameters[i],
                                xrange: xrange,
                                yrange: yrange,
                                values: valuesEPsummer,
                                unit: ((app.collection.parameters.findWhere({id: parameters[i]})) ? (app.collection.parameters.findWhere({id: parameters[i]})).get("unit") : 'unit')
                            }
                        ]
                    });
                }
            }

            // sends the formatted data to generate the graphs
            if ((season == "spring") || !foundEP) {
                self.timeSeriesView.setData(alldata, undefined);
            } else {
                self.timeSeriesView.setData(alldata, summerEPdata);
            }


            self.append();
//                self.controlsView.setParameters(parameters, _.isEmpty(parameters) ? time_series_params : parameters, time_series_params_colors);

        }

    }
});

app.view.CompareGraphMGTimeSeriesView = Backbone.View.extend({
//    el: "div#compare-graph",
    // template must be passed in when creating an instance of this view
    // ie: new app.view.CompareGraphView({template: "#compare-graph-lakes-template});
    // this view should be called after it's parent is rendered

    initialize: function(options) {
        var self = this;
        // the MG graph below will reference the "result" and "legend" classes to insert the graph
        this.template = _.template('<div class="result"></div><div class="legend"></div>');
        _.bindAll(this, "render");

	    var timeFormats = [
		    [d3.time.format("%Y"), function() {
			    return true;
		    }],
		    [d3.time.format("%B"), function(d) {
			    return d.getMonth();
		    }],
		    [d3.time.format("%b %d"), function(d) {
			    return d.getDate() != 1;
		    }],
		    [d3.time.format("%a %d"), function(d) {
			    return d.getDay() && d.getDate() != 1;
		    }],
		    [d3.time.format("%I %p"), function(d) {
			    return d.getHours();
		    }],
		    [d3.time.format("%I:%M"), function(d) {
			    return d.getMinutes();
		    }],
		    [d3.time.format(":%S"), function(d) {
			    return d.getSeconds();
		    }],
		    [d3.time.format(".%L"), function(d) {
			    return d.getMilliseconds();
		    }]
	    ];
	    var timeFormatPicker = function (formats) {
		    return function (date) {
			    var i = formats.length - 1, f = formats[i];
			    while (!f[1](date)) {
				    f = formats[--i];
			    }
			    return f[0](date);
		    };
	    };

	    var xax_format = timeFormatPicker(timeFormats);

        // default options to show an intentionally empty graph.
        // This indicates to the user that no selection has been made.
        this.graphOptions = {
            title: 'Parameter',
            width: 900,
            height: 400,
            target: this.id,
            missing_text: "Click a " + ((app.config.sensors.title) ? app.config.sensors.title.toLowerCase().substring(0, app.config.sensors.title.length - 1) : "sensor") + " to generate a graph" ,
            y_label: "Average",
            y_extended_ticks: true,
            x_accessor: 'date',
            show_secondary_x_label:false,
	        xax_count: 10,
            xax_format: xax_format,
            legend_target: this.id + "-legend",
            chart_type: 'missing-data',
            aggregate_rollover: true
        };

        // this gets fired when the sliders are either moved by a user or reset by the app
        // if a user clicks on a sensor, then the dates get updated as we change the bounds
        app.event.eventBus.on("compare:date:changed", function(data) {
            // here we are calling update(parameterID, min, max)
            // since the eventBus doesn't pass in the value of this parameter, we need to get it from the DOM
            // this view's ID is "#compare-parameter-graph-1" (or 2 or 3), so we extract the number to create
            // "#compare-parameter-1" so we can get that value from the DOM
            self.update($("#compare-parameter-" + self.id.substr(self.id.length - 1, 1)).val(), data.values.min, data.values.max);
        });

        return this;
    },

    render: function() {
        // render is intentionally pretty sparse. This uses the MetricsGraphics library to call data_graphic.
        // all that does is inserts the graph into the DOM using the options we specified in the initialize function.
        // anytime we re-render this graph, it will default to this "no data" view.
        MG.data_graphic(this.graphOptions);

        return this;

    },

    update: function(parameterID, min, max) {
        // parameterID should be the ID of the parameterModel, but it can also be one of the alternate strings
        // min and max are date objects
        var self = this;
        var compareDateRangeSlider = $( "#slider-range-stations" );
        // if min or max isn't passed, get the values directly from the slider's built-in functions ("min", "max")
        min = min || compareDateRangeSlider.dateRangeSlider("min");
        max = max || compareDateRangeSlider.dateRangeSlider("max");

        // if we don't have a parameterID, then there is nothing to graph
        if (!parameterID) return self.render();

        // rendering begins here
        this.$el.html( this.template() );

        // find a model for this parameter. If ID doesn't find it, check the alternates, otherwise exit.
        var parameterModel = app.collection.parameters.findWhere({id: parameterID});
        if (_.isUndefined(parameterModel)) {
            parameterModel = app.collection.parameters.filter(function(p) {
                return _.contains(p.get('alternates'), parameterID);
            });
            if (parameterModel.length) {
                parameterModel = parameterModel[0];
            } else {
                return;
            }
        }

        // parameterBins are created when you click a sensor in CompareSidebarControlsView
        // each parameterBin uses the parameter ID as it's unique ID
        var parameterBin = app.collection.parameterBins.findWhere({id: parameterModel.get('id')});

        // we have the desired parameter, but not all sensors will have this parameter
        // if we don't filter out the sensors without the parameter, they will still be in the list
        // and they will show up in the legend, and may show the graph from the previously selected parameter
        var sensorsWithTheSelectedParameter = app.collection.compareSelectedSensors.filter(function(sensor) {
            return sensor.get('parameters').findWhere({id: parameterBin.get('id') });
        });

        // a parameterBin keeps track of all data for a parameter, from multiple sensors across a range of dates
        // we only want to graph sensors that are still selected, and have data for the selected parameter
        // so we will create an array of names and IDs that we can filter against below
        var selectedSensorNames = _.map(sensorsWithTheSelectedParameter, function(sensor) {
            return sensor.get('name');
        });

        var selectedSensorIDs = _.map(sensorsWithTheSelectedParameter, function(sensor) {
            return sensor.get('id');
        });

        // we will store the data from the parameterBin's dates collection in a local variable
        // these are all the values for each sensor, and we will format them before giving them to
        // MetricsGraphics to create the graph
        var data = [];
        if (!parameterBin || !parameterBin.get('dates')) {
            // if we never found a parameterBin for the parameter passed in, or it has no dates (ie: no data)
            // reset this graph and exit
            self.render();
            return this;
        }

        // the parameter will have a dates collection, but as the slider moves, we want to filter out those dates
        parameterBin.get('dates').each(function (bin) {
            var binDate = new Date(bin.get('id'));
            // only use dates if they are within the slider range
            if (min && max && ((min < binDate) && (binDate < max))) {

                app.collection.compareSelectedDates.add({id: bin.get('id')});

                var response = {"date": binDate};
                _.each(selectedSensorIDs, function(sensorID) {
                    if (bin.get(sensorID)) {
                        response[sensorID] = bin.get(sensorID);
                    }
                });
                if (response.date && (Object.keys(response).length > 1)) {
                    data.push(response);
                }
            }
        });

        var graphOptions = _.clone(self.graphOptions);

        if (data.length > 1) {
            graphOptions.title = parameterModel.get('title') + " " + parameterModel.get('unit');
            graphOptions.chart_type = app.config.graphs.compareGraphs.chartType;
            graphOptions.point_size = app.config.graphs.compareGraphs.pointSize;
            graphOptions.interpolate = 'linear';
            graphOptions.data = data;
            graphOptions.y_accessor = selectedSensorIDs;
            graphOptions.legend = selectedSensorNames;
            graphOptions.show_points_on_line_graphs = app.config.graphs.compareGraphs.showPointsOnLineGraphs;
            graphOptions.transition_on_update = !app.config.graphs.compareGraphs.showPointsOnLineGraphs;
        } else {
            // if no data, render this graph with the default options and exit
            // the default options are placeholder options that say 'no data'
            return self.render();
        }

        MG.data_graphic(graphOptions);

        var showPointsCheckbox = document.getElementById('show-points');

        if (showPointsCheckbox) {
            showPointsCheckbox.addEventListener('click', clickedShowPointsCheckbox);
            clickedShowPointsCheckbox();
        }

        function clickedShowPointsCheckbox(){
            var pointOnGraphs = document.getElementsByTagName('circle');
            if (showPointsCheckbox) {
                if (showPointsCheckbox.checked && pointOnGraphs) {
                    for (var i = 0; i < pointOnGraphs.length; i++) {
                        pointOnGraphs[i].style.visibility = "visible";
                    }
                }
                else if (pointOnGraphs) {
                    for (var j = 0; j < pointOnGraphs.length; j++) {
                        pointOnGraphs[j].style.visibility = "hidden";
                    }
                }
            }
        }

        return this;

    }

});

app.view.FooterView = Backbone.View.extend({
    el: "#footer-container",
    
    initialize: function(options) {
        this.template = _.template($('#footer-template').html());
        this.render();
        return this;
    },
    
    render: function() {
        this.$el.empty();
        this.$el.html(this.template);
        return this;
    }
});
app.view.NavBarView = Backbone.View.extend({
    el: "#navigation",

    initialize: function() {

        this.template = _.template("<li><a href='<%= link %>'><%= title %></a></li>");

        this.dropdownTemplate = _.template(
            "<li>" +
                "<div class='dropdown'>" +
                    "<a class='dropdown-toggle' data-toggle='dropdown' href='<%= link %>'><%= title %> " +
                        "<b class='caret'></b>" +
                    "</a>" +
                    "<ul class='dropdown-menu' role='menu' aria-labelledby='dLabel'>" +
                        "<% if(title_link == null) {%> "+
                            "<li><a href='<%= link %>'><%= title %></a></li>" +
                        "<%};%>" +
                        "<% _.each(children, function(item) { %>" +
                            "<li>" +
                                "<a href='<%= link %>/<%= item.link.replace('#', '') %>'>" +
                                    "<%= item.title.toUpperCase() %></a>" +
                            "</li>" +
                        "<% }); %>" +
                    "</ul>" +
                "</div>" +
            "</li>");
    },

    render: function() {
        var self = this;

        _.each(app.config.views, function(item) {
            if (item.title && item.link) {
                if (item.children) {
                    self.$el.append(self.dropdownTemplate({
                        title: item.title.toUpperCase(),
                        link: item.link,
                        children: item.children,
                        title_link: item.title_link
                    }));
                } else {
                    self.$el.append(self.template({
                        title: item.title.toUpperCase(),
                        link: item.link
                    }));
                }

            }
        });
    }

});
app.view.PageView = Backbone.View.extend({
    initialize: function(options) {
      this.config = options.config ? options.config : options;
      if (this.config.title) this.id = this.config.title.toLowerCase().replace(/ /g, '-') + "view";
      this.template = _.template($(this.config.template).html());
      return this;
    },
    
    render: function() {
        this.$el.empty();
        this.$el.html(this.template());
        return this;
    }
});
app.view.StackedBarView = Backbone.View.extend({
    tagName: 'div',
    id: 'biology-area',

    initialize: function(options) {
        this.render = _.bind(this.render, this);
        this.scale = options.scale;
        this.graphId = options.id;
        this.data = options.data;
        this.title = options.title;
        this.scaleNames = options.scaleNames;
        this.z = options.z;
        this.unit = options.unit;
    },

    render: function() {
        this.$el.empty();
        var margin = {top: 50, right: 30, bottom: 50, left: 70},
            width = 850 - margin.left - margin.right,
            height = 500 - margin.top - margin.bottom;

        var x = d3.scale.ordinal()
            .rangeRoundBands([0, width-160], .1);

        var y = d3.scale.linear()
            .rangeRound([height, 0]);

        var color = this.z;

        var xAxis = d3.svg.axis()
            .scale(x)
            .orient("bottom")
            .ticks(3)
            .tickFormat(d3.time.format("%Y"));

        var yAxis = d3.svg.axis()
            .scale(y)
            .orient("left");

        var varNames = this.scaleNames;

        var nestFunction = d3.nest().key(function(d) { return d.date;});

        var data = nestFunction.entries(this.data);

        data.forEach(function(d) {
            var y0 = 0;
            var length = d.values.length;

            d.mapping = varNames.map(function(name) {
                var temp = 0;
                d.values.forEach(function(k) {
                    temp +=k[name];
                });
                return {
                    name: name,
                    label: new Date(d.key),
                    y0: y0,
                    y1: y0 += temp/length
                };
            });
            d.date = new Date(d.key);
            d.total = d.mapping[d.mapping.length-1].y1;
        });

        x.domain(data.map(function(d) {return d.date;}));
        y.domain([0, d3.max(data, function(d) {return d.total; })]);

        var svgBiology = d3.select("#"+this.graphId)
            .attr("width", width + margin.left + margin.right)
            .attr("height", height + margin.top + margin.bottom)
            .attr("class", "graphs-biology")
            .append("g")
            .attr("transform", "translate(" + margin.left + "," + margin.top + ")");

        var selection = svgBiology.selectAll(".series")
            .data(data)
            .enter().append("g")
            .attr("class", "series, graphs-listener-biology")
            .attr("x", function(d) {return  x(d.date);})
            .attr("transform", function(d) {
                return "translate(" + x(d.date) + ",0)";
            })
            .style("stroke", "grey")
            .style("stroke-width", 0.2);

        selection.selectAll("rect")
            .data(function(d) {return d.mapping;})
            .enter().append("rect")
            .attr("width", x.rangeBand())
            .attr("y", function(d) {return y(d.y1);})
            .attr("x", function(d) {return  x(d.date);})
            .attr("height", function(d) {return y(d.y0) - y(d.y1);})
            .style("fill", function(d) {return color(d.name); })
            .style("stroke", "grey")
            .style("stroke-width", 0.2);

        // Adding Legend
        var legend = svgBiology.selectAll(".legend")
            .data(varNames.slice().reverse())
            .enter().append("g")
            .attr("class", "legend")
            .attr("transform", function (d, i) {
                return "translate(25, "  + (10 + i * 20) + ")";
            });

        legend.append("rect")
            .attr("x", width - 175)
            .attr("width", 10)
            .attr("height", 10)
            .style("fill", color);

        legend.append("text")
            .attr("x", width - 163)
            .attr("y", 6)
            .attr("dy", ".35em")
            .text(function (d) { return d; });

        svgBiology.append("g")
            .attr("class", "graphs-x-axis")
            .attr("transform", "translate(0," + height + ")")
            .call(xAxis)
            .append("text")
            .style("text-anchor", "end");

        svgBiology.append("g")
            .attr("class", "graphs-y-axis")
            .call(yAxis)
            .append("text")
            .attr("transform", "rotate(-90)")
            .attr("y", 6)
            .style("text-anchor", "end");

        // Adding Title
        svgBiology.append("text")
            .attr("x", 0)
            .attr("y", 0 - (margin.top / 2))
            .attr("text-anchor", "left")
            .style("font-size", "16px")
            .attr("class", "graphs-title")
            .text(this.title);

        //Adding labels
        var unit = this.unit;
        svgBiology.append("text")      // text label for the x axis
            .attr("x", width/2 - margin.left - 10)
            .attr("y",  height + 40)
            .attr("class", "graphs-xAxisLabel")
            .style("text-anchor", "middle")
            .text("Date");

        svgBiology.append("text")
            .attr("transform", "rotate(-90)")
            .attr("x", -height/2)
            .attr("y", -55)
            .attr("class", "graphs-yAxisLabel")
            .style("text-anchor", "middle")
            .text(unit);

        //Adding on Mouseover handle
        var popupBiologyDiv = d3.select('graphs-tooltip').data([0]);
        popupBiologyDiv.enter()
            .append("div")
            .attr("class", "graphs-tooltip")
            .style("opacity", "0");
        popupBiologyDiv.exit().remove();

        // TODO: Update when changed to seasons to be year - spring/summer
        var dateFormat = d3.time.format("%b-%y");

        svgBiology.selectAll(".graphs-listener-biology")
            .on("mouseover", function(d){

                var xPos = parseFloat(d3.select(this).attr("x"));
                var yPos = parseFloat(d3.select(this.children[this.children.length-1]).attr("y"));
                var valueToPrint = "<b>Date</b>: " + dateFormat(d.date) + "<br/>";
                for(x in d.mapping) {
                    var temp = d.mapping[x];
                    var curValue = Math.round(temp.y1 - temp.y0);
                    valueToPrint += "<b>" + temp.name + "</b>: " + curValue  + " (" + unit + ") Avg. <br/>";
                    d3.select(this.children[x]).style("stroke", "black").style("stroke-width", 2)
                }

                var topMargin = Math.min(yPos, 280);
                popupBiologyDiv.html(valueToPrint)
                    .style("left",this.parentElement.getBoundingClientRect().left + margin.left + xPos + "px")
                    .style("top", this.parentElement.getBoundingClientRect().top + margin.top + topMargin + "px");
                popupBiologyDiv.transition().style("opacity", 0.9);

            })
            .on("mouseout",function(d){
                for(x in d.mapping) {
                    d3.select(this.children[x]).style("stroke", "grey").style("stroke-width", 0.2);
                }
                popupBiologyDiv.transition().style("opacity", 0);

            });

    }
});
app.view.WelcomeView = Backbone.View.extend({
    id: "welcome-view",
    tag: "div",

    template: _.template($('#welcome-template').html()),

    initialize: function(options) {
        return this;
    },

    render: function() {

        this.$el.empty();

        this.$el.html(this.template(
            {sources: app.collection.sources.getSourcesWithSensors().toJSON()}
        ));

        return this;
    }

});
app.view.StackedLineView = Backbone.View.extend({
	tagName: 'div',
	id: 'stacked-line',

	initialize: function(options) {
		this.render = _.bind(this.render, this);
		this.data = options.data;
		this.color = options.color; 
		this.graphId = options.id;
		this.units = options.unit;
		this.title = options.title;
	},

	render: function() {
		this.$el.empty();
		var self = this;
		var data = this.data;
		var color = this.color;
		var margin = {top: 50, right: 200, bottom: 50, left: 200},
			width = 1170 - margin.left - margin.right,
			height = 500 - margin.top - margin.bottom;

		var parseDate = d3.time.format("%Y-%m-%d").parse;
		var x = d3.time.scale().range([0, width]);
		var y = d3.scale.linear()
			.range([height, 0]);

		var xAxis = d3.svg.axis()
			.scale(x)
			.orient("bottom");

		var yAxis = d3.svg.axis()
			.scale(y)
			.orient("left");

		var line = d3.svg.line()
			.defined(function(d) {return !isNaN(d.depth);})
			.interpolate("linear")
			.x(function(d) { return x(d.date); })
			.y(function(d) { return y(d.depth); });

		color.domain(d3.keys(this.data[0].values));

		data.forEach(function(d) {
			d.parsedDate = parseDate(d.date);
		});

		var svgMultiLineGraph = d3.select("#"+this.graphId)
			.attr("width", width + margin.left + margin.right)
			.attr("height", height + margin.top + margin.bottom)
			.attr("class", "graphs-dissolved-oxygen")
			.append("g")
			.attr("transform", "translate(" + margin.left + "," + margin.top + ")");

		var graphData  = this.color.domain().map(function(temperatureLevel) {
			return {
				name: temperatureLevel,
				values: data.map(function(d) {
					return{date: d.parsedDate, depth: +d.values[temperatureLevel]}
				})
			};
		});

		x.domain(d3.extent(data, function(d) {return d.parsedDate; }));

		y.domain([
			d3.max(graphData, function(c) { return d3.max(c.values, function(v) { return v.depth; }); }),
			d3.min(graphData, function(c) { return d3.min(c.values, function(v) { return v.depth; }); })

		]);

		// Adding axis and labels
		svgMultiLineGraph.append("g")
			.attr("class", "graphs-x-axis")
			.attr("transform", "translate(0," + height + ")")
			.call(xAxis).append("text");

		svgMultiLineGraph.append("g")
			.attr("class", "graphs-y-axis")
			.call(yAxis);

		// Adding Labels
		svgMultiLineGraph.append("text")
			.attr("x", width/2)
			.attr("y",  height + 40)
			.attr("class", "graphs-xAxisLabel")
			.style("text-anchor", "middle")
			.text("Date");

		svgMultiLineGraph.append("text")
			.attr("transform", "rotate(-90)")
			.attr("x", -height/2)
			.attr("y", -35)
			.attr("class", "graphs-yAxisLabel")
			.style("text-anchor", "middle")
			.text("Meters");

		// Adding lines
		var lines = svgMultiLineGraph.selectAll(".doline")
			.data(graphData)
			.enter().append("g")
			.attr("class", "doline, graphs-listener-multiline");

		lines.append("path")
			.attr("class", "graphs-line")
			.attr("d", function(d) {return line(d.values);})
			.style("stroke", function(d) {return color(d.name);});

		var circles = lines.append("g").selectAll("circle")
			.data(function(d){return d.values})
			.enter()
			.append("circle")
			.filter(function(d) {return !isNaN(d.depth)})
			.attr("r", 2)
			.attr("cx", function(d) {return x(d.date)})
			.attr("cy", function(d) {return y(d.depth)})
			.attr("fill", function(d) {return color(this.parentNode.__data__.name)})
			.attr("stroke", function(d) {return color(this.parentNode.__data__.name)});

		// Adding Title
		svgMultiLineGraph.append("text")
			.attr("x", 0)
			.attr("y", 0 - (margin.top / 2))
			.attr("text-anchor", "left")
			.style("font-size", "16px")
			.attr("class", "graphs-title")
			.text(this.title);

		// Adding Legend
		svgMultiLineGraph.append("g")
			.attr("transform", "translate(25,10)")
			.text("Temperature");
		var legend = svgMultiLineGraph.selectAll(".legend")
			.data(color.domain())
			.enter().append("g")
			.attr("class", "legend")
			.attr("transform", function (d,i) {
				return "translate( 25, " + (10 + i * 20) + ")";
			});

		// TODO: Try to add a title to the legend
		// legend.append("text")
		// 	.attr("x", width - 50)
		// 	.attr("y", 6)
		// 	.attr("dy", ".35em")
		// 	.text("Dissolved Oxygen Level");

		legend.append("rect")
			.attr("x", width - 20)
			.attr("width", 10)
			.attr("height", 10)
			.style("fill", color);

		legend.append("text")
			.attr("x", width + 5)
			.attr("y", 6)
			.attr("dy", ".35em")
			.text(function (d) { return d + " " + self.units; });


		// Adding on Mouseover handle
		// TODO: Update when changed to seasons to be year - spring/summer
		var dateFormat = d3.time.format("%b-%y");
		var popupMultiLineDiv = d3.select('graphs-tooltip').data([0]);
		popupMultiLineDiv.enter()
			.append("div")
			.attr("class", "graphs-tooltip")
			.style("opacity", "0");
		popupMultiLineDiv.exit()
			.remove();

		var g = svgMultiLineGraph.append("g");

		var points = lines.append("g").selectAll('.points')
			.data(function(d){return d.values})
			.enter()
			.append('g')
			.filter(function(d) {return !isNaN(d.depth)})
			.attr('class', 'points')
			.append('text');

		var focus = g.append('g')
			.attr('class', 'focus')
			.style('display', 'none');

		focus.append('line')
			.attr('class', 'x-hover-line hover-line')
			.attr('y1' , 0)
			.attr('y2', height);
		svgMultiLineGraph.append('rect')
			.attr("class", "overlay")
			.attr("width", width)
			.attr("height", height)
			.on("mouseover", mouseover)
			.on("mouseout", mouseout)
			.on("mousemove", mousemove);

		var timeScales = data.map(function(d) {return x(d.parsedDate)});

		function mouseover() {
			focus.style("display", null);
			d3.selectAll('.points text').style("display", null);
		}
		function mouseout() {
			focus.style("display", "none");
			popupMultiLineDiv.transition().style("opacity", 0);
			d3.selectAll('.points text').style("display", "none");
		}
		function mousemove() {
			var i = d3.bisect(timeScales, d3.mouse(this)[0], 1);
			var di = data[i-1];
			focus.attr("transform", "translate(" + x(di.parsedDate) + ",0)");
			var valueToPrint = "<b>Date</b>: " + dateFormat(di.parsedDate) + "</br>";
			for(var k in di.values) {
				if(di.values[k] != "NA") {
					valueToPrint += "<b>" + k + " (" + self.units + ") </b>: " + di.values[k] + " (meters) <br/>";
				}
			}
			popupMultiLineDiv.html(valueToPrint)
				.style("left", this.parentElement.getBoundingClientRect().left + x(di.parsedDate) + 60 + "px")
				.style("top", this.parentElement.getBoundingClientRect().top + margin.top + 0 + "px");
			popupMultiLineDiv.transition().style("opacity", 0.9);
		}

	}

});
(function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
(i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
})(window,document,'script','//www.google-analytics.com/analytics.js','ga');

ga('create', app.config.googleAnalytics, 'auto');

})(jQuery, Backbone, window);